@@ -14,7 +14,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -35,6 +35,9 @@
 $pag = "aggiorna.php";
 error_reporting(E_ALL ^ E_NOTICE);
 
+$var_pag = array();
+$n_var_pag = 0;
+
 include("./costanti.php");
 
 
