@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2017-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,11 +23,30 @@
 $pag = "api.php";
 $titolo = "HotelDruid: API";
 
+$var_pag = array();
+$var_pag[0] = 'doc';
+$var_pag[1] = 'pass';
+$var_pag[2] = 'res_year';
+$var_pag[3] = 'res_num';
+$var_pag[4] = 'res_from';
+$var_pag[5] = 'res_to';
+$var_pag[6] = 'res_ins_from';
+$var_pag[7] = 'res_ins_to';
+$var_pag[8] = 'res_arr';
+$var_pag[9] = 'res_dep';
+$var_pag[10] = 'clients';
+$var_pag[11] = 'cashbox';
+$var_pag[12] = 'session_data';
+$var_pag[13] = 'cli_id';
+$var_pag[14] = 'priv_r';
+$n_var_pag = 15;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include("./includes/funzioni.php");
+include("./includes/funzioni_email.php");
 $tableutenti = $PHPR_TAB_PRE."utenti";
 $tablesessioni = $PHPR_TAB_PRE."sessioni";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
@@ -55,7 +74,7 @@ $tablecasse = $PHPR_TAB_PRE."casse";
 
 
 # API Documenti
-if ($doc) {
+if (!empty($doc)) {
 $session_data = "";
 $id_sessione = "";
 $numero_contratto = aggslashdb((int) $doc);
@@ -99,7 +118,7 @@ if ($raggiunto_limite) echo "REACHED LIMIT IN LAST MINUTE (".C_LIMITE_CHIAMATE_A
 else {
 
 
-if ($res_year) {
+if (!empty($res_year)) {
 if (preg_match("/[0-9]{4,4}/",$res_year)) {
 if (@is_file(C_DATI_PATH."/selectperiodi$res_year.1.php")) $anno = $res_year;
 else {
@@ -108,7 +127,7 @@ else $res_year = "";
 } # fine else if (@is_file(C_DATI_PATH."/selectperiodi$res_year.1.php"))
 } # fine if (preg_match("/[0-9]{4,4}/",$res_year))
 else $res_year = "";
-} # fine if ($res_year)
+} # fine if (!empty($res_year))
 
 $anno_esist = 1;
 # Se ci troviamo dopo il periodo di creazione dell'anno ma questo non è stato ancora creato
@@ -124,6 +143,7 @@ if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+$prendi_gruppi = "";
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
 $anno_utente_attivato = "SI";
@@ -254,7 +274,7 @@ $lista_prenota = 0;
 $sec_oggi = time() + (C_DIFF_ORE * 3600);
 
 
-if ($res_from or $res_to) {
+if (!empty($res_from) or !empty($res_to)) {
 if ($res_from == "today") $res_from = date("Y-m-d",$sec_oggi);
 if ($res_from == "tomorrow") $res_from = date("Y-m-d",($sec_oggi + 86400));
 if ($res_from == "yesterday") $res_from = date("Y-m-d",($sec_oggi - 86400));
@@ -285,9 +305,9 @@ $query_prenota .= " order by iddatainizio";
 } # fine if ($primo_periodo)
 } # fine if (!$res_from or !$res_to or $res_from <= $res_to)
 if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
-} # fine if ($res_from or $res_to)
+} # fine if (!empty($res_from) or !empty($res_to))
 
-if ($res_num and !$query_prenota) {
+if (!empty($res_num) and !$query_prenota) {
 $prenota_in_lista = array();
 $res_num = explode(",",$res_num);
 $num_res = count($res_num);
@@ -309,10 +329,10 @@ else $fine_for = 0;
 } # fine if (!$res_fine)
 else $fine_for = $res_fine;
 for ($num2 = $ini_for ; $num2 <= $fine_for ; $num2++) {
-if (!$prenota_in_lista[$num2]) {
+if (empty($prenota_in_lista[$num2])) {
 $prenota_in_lista[$num2] = 1;
 $query_prenota .= ",$num2";
-} # fine if (!$prenota_in_lista[$num2])
+} # fine if (empty($prenota_in_lista[$num2]))
 } # fine for $num2
 } # fine if (!$res_ini or !$res_fine or $res_fine >= $res_ini)
 } # fine if (str_replace("-","",$num_pren) != $num_pren)
@@ -325,9 +345,9 @@ $query_prenota .= ",$num_pren";
 } # fine for $num1
 if ($query_prenota) $lista_prenota = 1;
 else $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
-} # fine if ($res_num and !$query_prenota)
+} # fine if (!empty($res_num) and !$query_prenota)
 
-if (($res_ins_from or $res_ins_to) and !$query_prenota) {
+if ((!empty($res_ins_from) or !empty($res_ins_to)) and !$query_prenota) {
 if ($res_ins_from == "today") $res_ins_from = date("Y-m-d",$sec_oggi);
 if ($res_ins_from == "tomorrow") $res_ins_from = date("Y-m-d",($sec_oggi + 86400));
 if ($res_ins_from == "yesterday") $res_ins_from = date("Y-m-d",($sec_oggi - 86400));
@@ -344,9 +364,9 @@ $query_prenota = "select idprenota from $tableprenota where datainserimento >= '
 } # fine if ($res_ins_from <= $res_ins_to)
 } # fine if ($res_ins_from or $res_ins_to)
 if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
-} # fine if (($res_ins_from or $res_ins_to) and !$query_prenota)
+} # fine if ((!empty($res_ins_from) or !empty($res_ins_to)) and !$query_prenota)
 
-if ($res_arr and !$query_prenota) {
+if (!empty($res_arr) and !$query_prenota) {
 if ($res_arr == "today") $res_arr = date("Y-m-d",$sec_oggi);
 if ($res_arr == "tomorrow") $res_arr = date("Y-m-d",($sec_oggi + 86400));
 if ($res_arr == "yesterday") $res_arr = date("Y-m-d",($sec_oggi - 86400));
@@ -360,9 +380,9 @@ $query_prenota = "select idprenota from $tableprenota where iddatainizio = '$arr
 } # fine if (numlin_query($arrivo))
 } # fine if (preg_match("/[0-9]{4,4}-[0-9]{2,2}-[0-9]{2,2}/",$res_arr))
 if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
-} # fine if ($res_arr and !$query_prenota)
+} # fine if (!empty($res_arr) and !$query_prenota)
 
-if ($res_dep and !$query_prenota) {
+if (!empty($res_dep) and !$query_prenota) {
 if ($res_dep == "today") $res_dep = date("Y-m-d",$sec_oggi);
 if ($res_dep == "tomorrow") $res_dep = date("Y-m-d",($sec_oggi + 86400));
 if ($res_dep == "yesterday") $res_dep = date("Y-m-d",($sec_oggi - 86400));
@@ -376,20 +396,20 @@ $query_prenota = "select idprenota from $tableprenota where iddatafine = '$parte
 } # fine if (numlin_query())
 } # fine if (preg_match("/[0-9]{4,4}-[0-9]{2,2}-[0-9]{2,2}/",$res_dep))
 if (!$query_prenota) $query_prenota = "select idprenota from $tableprenota where iddatainizio < '-3' ";
-} # fine if ($res_dep and !$query_prenota)
+} # fine if (!empty($res_dep) and !$query_prenota)
 
-if ($clients and !$query_prenota) {
+if (!empty($clients) and !$query_prenota) {
 if ($clients == "all") $query_clienti = "select idclienti from $tableclienti where max_num_ordine = '1' order by cognome ";
 if ($clients == "guests") $query_clienti = "select idclienti from $tableclienti order by cognome ";
 if (!$query_clienti) $query_clienti = "select idclienti from $tableclienti where idclienti < '-3'";
-} # fine if ($clients and !$query_prenota)
+} # fine if (!empty($clients) and !$query_prenota)
 
-if (strcmp($cashbox,"") and !$query_prenota and !$query_clienti) {
+if (isset($cashbox) and strcmp((string) $cashbox,"") and !$query_prenota and !$query_clienti) {
 $query_cassa = "select idcasse from $tablecasse where nome_cassa = '".aggslashdb($cashbox)."' ";
-} # fine if (strcmp($cashbox,"") and !$query_prenota and !$query_clienti)
+} # fine if (isset($cashbox) and strcmp((string) $cashbox,"") and !$query_prenota and !$query_clienti)
 
 if (!$query_prenota and !$query_clienti and !$query_cassa) {
-if (!$res_year) $res_year = $anno;
+if (empty($res_year)) $res_year = $anno;
 $primo_periodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '$res_year-01-01' ");
 if (numlin_query($primo_periodo)) {
 $primo_periodo = risul_query($primo_periodo,0,'idperiodi');
@@ -397,7 +417,7 @@ $ultimo_periodo = esegui_query("select max(idperiodi) from $tableperiodi where d
 $ultimo_periodo = risul_query($ultimo_periodo,0,0);
 $query_prenota = "select idprenota from $tableprenota where iddatafine >= '$primo_periodo' and iddatainizio <= '$ultimo_periodo' order by iddatainizio";
 } # fine if (numlin_query($primo_periodo))
-} # fine if (!$query_prenota and !$query_clienti)
+} # fine if (!$query_prenota and !$query_clienti and !$query_cassa)
 
 
 if ($query_prenota or $query_clienti or $query_cassa) {
@@ -528,19 +548,14 @@ $pag = $pag_orig;
 } # fine else if ($raggiunto_limite)
 } # fine if ($pass == $pass_api)
 else {
-$versione_transazione = prendi_numero_versione($tabletransazioniweb,"idtransazioni","anno");
-$adesso = date("YmdHis");
-list($usec, $sec) = explode(' ', microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
-$val_casuale = mt_rand(100000,999999);
-$id_transazione = $adesso.$val_casuale.$versione_transazione;
+$id_transazione = crea_id_sessione("",$tabletransazioniweb,16,0,"idtransazioni","anno");
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tabletransazioniweb (idtransazioni,tipo_transazione,dati_transazione1,dati_transazione2,ultimo_accesso) values ('$id_transazione','api_l','doc$numero_contratto','$REMOTE_ADDR','$ultimo_accesso')");
 } # fine else if ($pass == $pass_api)
 
 } # fine else if ($login_sbagliati >= $max_log_sbagliati)
 } # fine if (numlin_query($api_esistente))
-} # fine if ($doc)
+} # fine if (!empty($doc))
 
 
 
@@ -552,13 +567,14 @@ if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1")) {
 $cli_pass = 0;
 $cli_presfut = 0;
+$cli_id = fixstr($cli_id);
 # Non fare lock in scrittura sulle stesse tabelle dalle funzioni delle interconnessioni, altrimenti si blocca quando si attiva cc_hd_token
-if ($tweb) $tabelle_lock = array($tabletransazioniweb);
+if (!empty($tweb)) $tabelle_lock = array($tabletransazioniweb);
 else {
 if (strstr($cli_id,",")) $tabelle_lock = array($tablesessioni,$tabletransazioni);
 else $tabelle_lock = array($tablesessioni);
-} # fine else if ($tweb)
-if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb) {
+} # fine else if (!empty($tweb))
+if (($cli_id == "pass" or $cli_id == "pres_fut") and empty($tweb)) {
 $anni_esist = esegui_query("select * from $tableanni order by idanni");
 $num_anni = numlin_query($anni_esist);
 unset($anni);
@@ -601,11 +617,11 @@ $num_lock++;
 $altre_tab_lock[$num_lock] = $tableprivilegi;
 $num_lock++;
 $altre_tab_lock[$num_lock] = $tablerelgruppi;
-} # fine if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb)
+} # fine if (($cli_id == "pass" or $cli_id == "pres_fut") and empty($tweb))
 else {
-if ($cli_id or $priv_r) $altre_tab_lock = array($tableclienti,$tablepersonalizza,$tableprivilegi,$tablerelgruppi);
+if ($cli_id or !empty($priv_r)) $altre_tab_lock = array($tableclienti,$tablepersonalizza,$tableprivilegi,$tablerelgruppi);
 else $altre_tab_lock = array($tablepersonalizza);
-} # fine else if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb)
+} # fine else if (($cli_id == "pass" or $cli_id == "pres_fut") and empty($tweb))
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $sessione_trovata = 0;
 if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC and $cli_id == "pres_fut") $sessione_trovata = 1;
@@ -613,16 +629,16 @@ else {
 $minuti_durata_sessione = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_sessione' and idutente = '1'");
 $minuti_durata_sessione = risul_query($minuti_durata_sessione,0,'valpersonalizza_num');
 $limite_sessioni_vecchie = date("Y-m-d H:i:s",(time() - ($minuti_durata_sessione * 60) + (C_DIFF_ORE * 3600)));
-if ($tweb) {
+if (!empty($tweb)) {
 esegui_query("delete from $tabletransazioniweb where tipo_transazione = 'pay_c' and ultimo_accesso <= '$limite_sessioni_vecchie'");
 $sessione = esegui_query("select * from $tabletransazioniweb where tipo_transazione = 'pay_c' and idtransazioni = '".aggslashdb($id_sessione)."' ");
 $sessione_trovata = numlin_query($sessione);
-} # fine if ($tweb)
+} # fine if (!empty($tweb))
 else {
 esegui_query("delete from $tablesessioni where ultimo_accesso <= '$limite_sessioni_vecchie'");
 $sessione = esegui_query("select * from $tablesessioni where idsessioni = '$id_sessione'");
 $sessione_trovata = numlin_query($sessione);
-} # fine else if ($tweb)
+} # fine else if (!empty($tweb))
 } # fine else if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC and $cli_id == "pres_fut")
 if ($sessione_trovata) {
 
@@ -630,11 +646,11 @@ if ($sessione_trovata) {
 @include(C_DATI_PATH."/tema.php");
 if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC) $id_utente = 1;
 else {
-if ($tweb) {
+if (!empty($tweb)) {
 $id_utente = "t";
 $lingua[$id_utente] = $lingua[1];
 $tema[$id_utente] = $tema[1];
-} # fine if ($tweb)
+} # fine if (!empty($tweb))
 else $id_utente = risul_query($sessione,0,'idutente');
 } # fine else if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC)
 echo "<user_id>$id_utente<user_id>
@@ -644,8 +660,10 @@ if (defined('C_FILE_CSS_PERS') and C_FILE_CSS_PERS != "" and @is_file(C_FILE_CSS
 if (defined('C_FILE_MOB_CSS_PERS') and C_FILE_MOB_CSS_PERS != "" and @is_file(C_FILE_MOB_CSS_PERS)) echo "<mob_css_pers>".C_FILE_MOB_CSS_PERS."</mob_css_pers>";
 $idclienti = aggslashdb($cli_id);
 
-if ($priv_r or ($cli_id and $id_utente != 1 and !$tweb)) {
+if (!empty($priv_r) or ($cli_id and $id_utente != 1 and empty($tweb))) {
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+$prendi_gruppi = "";
+$priv_gest_pass_cc = "";
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
 $anno_utente_attivato = "SI";
@@ -674,9 +692,9 @@ $num_utenti_gruppo = numlin_query($utenti_gruppo);
 for ($num2 = 0 ; $num2 < $num_utenti_gruppo ; $num2++) $utenti_gruppi[risul_query($utenti_gruppo,$num2,'idutente')] = 1;
 } # fine for $num1
 } # fine if ($prendi_gruppi == "SI")
-} # fine if ($priv_r or ($cli_id and $id_utente != 1 and !$tweb))
+} # fine if (!empty($priv_r) or ($cli_id and $id_utente != 1 and empty($tweb)))
 
-if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb) {
+if (($cli_id == "pass" or $cli_id == "pres_fut") and empty($tweb)) {
 if ($cli_id == "pass") $cli_pass = 1;
 if ($cli_id == "pres_fut") $cli_presfut = 1;
 $cli_id = "";
@@ -688,7 +706,7 @@ foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condiz
 $condizione_utente_canc .= " )";
 } # fine if ($id_utente != 1 and ($modifica_clienti == "PROPRI" or $modifica_clienti == "GRUPPI"))
 else $condizione_utente_canc = "";
-} # fine if (($cli_id == "pass" or $cli_id == "pres_fut") and !$tweb)
+} # fine if (($cli_id == "pass" or $cli_id == "pres_fut") and empty($tweb))
 
 if ($cli_id and $id_utente != 1) {
 $cli_priv = 0;
@@ -760,7 +778,7 @@ $num_clienti = numlin_query($clienti);
 $lista_clienti_canc = "";
 for ($num1 = 0; $num1 < $num_clienti; $num1++) {
 $idclienti = risul_query($clienti,$num1,'idclienti');
-if (!$cliente_attivo[$idclienti]) $lista_clienti_canc .= ",$idclienti";
+if (empty($cliente_attivo[$idclienti])) $lista_clienti_canc .= ",$idclienti";
 } # fine for $num1
 echo "<cli_pass>".substr($lista_clienti_canc,1)."</cli_pass>";
 } # fine if ($cli_pass)
@@ -771,11 +789,11 @@ echo "<cli_presfut>".substr($lista_clienti_att,1).";</cli_presfut>";
 } # fine if ($cli_presfut)
 } # fine if ($cli_pass or $cli_presfut)
 
-if ($priv_r) {
+if (!empty($priv_r)) {
 $val_priv_r = "";
 if ($priv_r == "priv_gest_pass_cc") $val_priv_r = $priv_gest_pass_cc;
 if ($val_priv_r) echo "<privr_$priv_r>$val_priv_r</privr_$priv_r>";
-} # fine if ($priv_r)
+} # fine if (!empty($priv_r))
 
 } # fine if ($sessione_trovata)
 unlock_tabelle($tabelle_lock);
@@ -788,7 +806,7 @@ exit();
 
 
 # Azioni da modulo carte di credito
-if ($azione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "") {
+if (!empty($azione) and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "") {
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1")) {
 
@@ -834,12 +852,7 @@ if (stristr($valore_xml,"<id>$token_res_id<")) {
 @include(C_DATI_PATH."/lingua.php");
 $lingua_mex = $lingua[1];
 $id_utente_sessione = "-1";
-$adesso = $anno.date("mdHis",(time() + (C_DIFF_ORE * 3600)));
-$versione_unica = prendi_numero_versione($tableversioni);
-list($usec, $sec) = explode(' ', microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
-$val_casuale = mt_rand(100000,999999);
-$id_sessione = $adesso.$val_casuale.$versione_unica;
+$id_sessione = crea_id_sessione($anno,$tableversioni);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
@@ -865,7 +878,7 @@ $id_utente = $id_utente_origi;
 
 
 } # fine if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1"))
-} # fine if ($azione and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "")
+} # fine if (!empty($azione) and defined('C_IP_MOD_EXT_CARTE_CREDITO') and C_IP_MOD_EXT_CARTE_CREDITO != "")
 
 
 
