@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -101,6 +101,7 @@ else include("./includes/head.php");
 $Euro = nome_valuta();
 $altre_valute = altre_valute();
 $stile_soldi = stile_soldi();
+$inserire = "";
 
 
 if ($priv_ins_entrate != "s") $inserisci_entrata = "";
@@ -151,14 +152,14 @@ elseif ($id_cassa != 1) $nome_cassa = risul_query($cassa_esistente,0,'nome_cassa
 } # fine else if (!$id_cassa or controlla_num_pos($id_cassa) != "SI")
 
 if (@get_magic_quotes_gpc()) $metodo_pagamento = stripslashes($metodo_pagamento);
-$metodo_pagamento = htmlspecialchars($metodo_pagamento);
+$metodo_pagamento = htmlspecialchars(fixstr($metodo_pagamento));
 if (strcmp($metodo_pagamento,"")) {
 $metodi_pagamento = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'metodi_pagamento' and idutente = '$id_utente'");
 $metodi_pagamento = risul_query($metodi_pagamento,0,'valpersonalizza');
 if (str_replace(",$metodo_pagamento,",",",",$metodi_pagamento,") == ",$metodi_pagamento,") $inserire = "NO";
 } # fine if (strcmp($metodo_pagamento,""))
 
-if (strcmp($valuta,"")) {
+if (strcmp(fixstr($valuta),"")) {
 $n_valuta = "-1";
 for ($num1 = 0 ; $num1 < $altre_valute['num'] ; $num1++) if ($valuta == $altre_valute[$num1]['nome']) $n_valuta = $num1;
 if ($n_valuta == "-1") $inserire = "NO";
@@ -172,7 +173,7 @@ $val_costo = round($val_costo);
 $val_costo = $val_costo * (double) $arrotond_tasse;
 $valuta = $altre_valute[$n_valuta]['nome'].">".$altre_valute[$n_valuta]['cambio'].">".$altre_valute[$n_valuta]['arrotond'];
 } # fine else if ($n_valuta == "-1")
-} # fine if (strcmp($valuta,""))
+} # fine if (strcmp(fixstr($valuta),""))
 else $costo_valuta = "";
 
 if ($inserire != "NO") {
@@ -182,7 +183,7 @@ if ($priv_persona_ins_costi == "u") $persona_costo = $nome_utente;
 if ($priv_entrate_da_prenota != "c") unset($entrata_da_prenota);
 if ($priv_entrate_da_prenota == "s") $entrata_da_prenota = "SI";
 $provenienza_costo = "";
-if ($inserisci_entrata and $entrata_da_prenota) {
+if (!empty($inserisci_entrata) and !empty($entrata_da_prenota)) {
 $provenienza_costo = "p";
 if ($anno >= substr($datainserimento,0,4)) {
 $costo0 = esegui_query("select * from $tablecosti where idcosti = 0");
@@ -190,14 +191,14 @@ $costo0 = risul_query($costo0,0,'val_costo');
 $costo0 = $costo0 + $val_costo;
 esegui_query("update $tablecosti set val_costo = '$costo0' where idcosti = 0 ");
 } # fine if ($anno >= substr($datainserimento,0,4))
-} # fine if ($inserisci_entrata and $entrata_da_prenota)
+} # fine if (!empty($inserisci_entrata) and !empty($entrata_da_prenota))
 $idcosti = esegui_query("select max(idcosti) from $tablecosti");
 $idcosti = risul_query($idcosti,0,0) + 1;
 $tipo_costo = "e";
 if ($inserisci_spesa) $tipo_costo = "s";
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,tipo_costo,nome_cassa,persona_costo,provenienza_costo,metodo_pagamento,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti','$nome_costo','$val_costo','$tipo_costo','".aggslashdb($nome_cassa)."','$persona_costo','$provenienza_costo','$metodo_pagamento','$datainserimento','$HOSTNAME','$id_utente') ");
 if ($valuta) esegui_query("update $tablecosti set valuta = '".aggslashdb($valuta)."', costo_valuta = '".aggslashdb($costo_valuta)."' where idcosti = '$idcosti' ");
-if ($inserisci_entrata) echo mex("L'entrata è stata inserita",$pag);
+if (!empty($inserisci_entrata)) echo mex("L'entrata è stata inserita",$pag);
 if ($inserisci_spesa) echo mex("La spesa è stata inserita",$pag);
 echo " (".punti_in_num($val_costo,$stile_soldi)." $Euro";
 if ($valuta) echo " = ".punti_in_num($costo_valuta,$stile_soldi)." ".$altre_valute[$n_valuta]['nome'];
