@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -132,7 +132,7 @@ $num_anni = numlin_query($anni);
 $cond_anni = "";
 $cond_personalizza = "";
 $cond_ic_e_priv = "";
-if ($anni_backup) {
+if (!empty($anni_backup)) {
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_reg = risul_query($anni,$num1,'idanni');
 if (${'anno_sel'.$anno_reg}) {
@@ -151,7 +151,7 @@ $cond_ic_e_priv .= "anno != '$anno_reg'";
 } # fine else if (${'anno_sel'.$anno_reg})
 } # fine for $num1
 if (!$cond_anni) $anni_backup = "";
-} # fine if ($anni_backup)
+} # fine if (!empty($anni_backup))
 
 $tabelle_lock = "";
 $altre_tab_lock = array($tableanni);
@@ -278,13 +278,13 @@ if (@is_file(C_DATI_PATH."/dati_interconnessioni.php")) dump_testo("/dati_interc
 if (@is_file(C_DATI_PATH."/log_utenti.php")) dump_testo("/log_utenti.php",$file);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_reg = risul_query($anni,$num1,'idanni');
-if (!$anni_backup or ${'anno_sel'.$anno_reg}) {
+if (empty($anni_backup) or ${'anno_sel'.$anno_reg}) {
 for ($num2 = 0 ; $num2 < numlin_query($utenti) ; $num2++) {
 $idutente_reg = risul_query($utenti,$num2,'idutenti');
 if (@is_file(C_DATI_PATH."/selectperiodi$anno_reg.$idutente_reg.php")) dump_testo("/selectperiodi$anno_reg.$idutente_reg.php",$file);
 if (@is_file(C_DATI_PATH."/selperiodimenu$anno_reg.$idutente_reg.php")) dump_testo("/selperiodimenu$anno_reg.$idutente_reg.php",$file);
 } # fine for $num2
-} # fine if (!$anni_backup or ${'anno_sel'.$anno_reg})
+} # fine if (empty($anni_backup) or ${'anno_sel'.$anno_reg})
 } # fine for $num1
 
 fwrite($file,"<database>
@@ -319,7 +319,7 @@ dump_tabella("interconnessioni",$file,$cond_ic_e_priv);
 dump_tabella("messaggi",$file);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_reg = risul_query($anni,$num1,'idanni');
-if (!$anni_backup or ${'anno_sel'.$anno_reg}) {
+if (empty($anni_backup) or ${'anno_sel'.$anno_reg}) {
 dump_tabella("prenota$anno_reg",$file);
 dump_tabella("prenotacanc$anno_reg",$file);
 dump_tabella("costiprenota$anno_reg",$file);
@@ -329,13 +329,13 @@ dump_tabella("ntariffe$anno_reg",$file);
 dump_tabella("regole$anno_reg",$file);
 dump_tabella("soldi$anno_reg",$file);
 dump_tabella("costi$anno_reg",$file);
-} # fine if (!$anni_backup or ${'anno_sel'.$anno_reg})
+} # fine if (empty($anni_backup) or ${'anno_sel'.$anno_reg})
 } # fine for $num1
 fwrite($file,"</database>
 ");
 echo "<br>";
 
-if ($includi_modelli == "SI") {
+if (isset($includi_modelli) and $includi_modelli == "SI") {
 $lingua_orig = $lingua_mex;
 if ($id_utente != 1) {
 include(C_DATI_PATH."/lingua.php");
@@ -376,7 +376,7 @@ closedir($lang_dir);
 closedir($templates_dir);
 } # fine for $num_cart
 $lingua_mex = $lingua_orig;
-} # fine if ($includi_modelli == "SI")
+} # fine if (isset($includi_modelli) and $includi_modelli == "SI")
 
 fwrite($file,"</backup>");
 flock($file,3);
@@ -446,6 +446,7 @@ $file_tmp = C_DATI_PATH."/hoteld_doc_backup.php.tmp";
 $file_backup = C_DATI_PATH."/hoteld_doc_backup.php";
 } # fine else if (!isset($backup_contratti) or $backup_contratti != "SI")
 if (empty($file_backup_upload)) {
+fix_set($file_backup_upload);
 if (!empty($HTTP_POST_FILES['file_backup_upload']['tmp_name'])) $file_backup_upload = $HTTP_POST_FILES['file_backup_upload']['tmp_name'];
 else if (!empty($_FILES['file_backup_upload']['tmp_name'])) $file_backup_upload = $_FILES['file_backup_upload']['tmp_name'];
 } # fine if (empty($file_backup_upload))
@@ -502,7 +503,7 @@ if ($filelock) {
 if (@is_file($file)) {
 if (isset($compresso) and $compresso == "SI") {
 list($usec,$sec) = explode(' ',microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
+mt_srand((float) $sec + (int) ((float) $usec * 1000000.0));
 $file_compresso = C_DATI_PATH."/backup".mt_rand(10000,99999).".php.gz";
 $cfp = gzopen($file_compresso,"wb9");
 $fbackup = fopen($file,"r");
@@ -615,7 +616,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_backup.php\
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"ripristina_backup\" value=\"$ripristina_backup\">
-<input type=\"hidden\" name=\"mantieni_anni\" value=\"".htmlspecialchars(fixset($mantieni_anni))."\">
+<input type=\"hidden\" name=\"mantieni_anni\" value=\"".htmlspecialchars(fixstr($mantieni_anni))."\">
 <input type=\"hidden\" name=\"azione\" value=\"SI\">
 <input type=\"hidden\" name=\"continua\" value=\"SI\">";
 
@@ -648,11 +649,11 @@ echo "".mex("Database già esistente",$pag)."?
 (".mex("Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle",$pag).")</small><br>";
 if (!$HOTELD_DB_HOST) echo "".mex("Nome del computer a cui collegarsi",$pag).":
 <input type=\"text\" name=\"N_PHPR_DB_HOST\" value=\"localhost\"><br>";
-if (!strcmp($HOTELD_DB_PORT,"")) echo "".mex("Numero della porta a cui collegarsi",$pag).": 
+if (!strcmp((string) $HOTELD_DB_PORT,"")) echo "".mex("Numero della porta a cui collegarsi",$pag).": 
 <input type=\"text\" name=\"N_PHPR_DB_PORT\" value=\"5432\">(".mex("Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql",$pag).")<br>";
 if (!$HOTELD_DB_USER) echo "".mex("Nome per l'autenticazione al database",$pag).": 
 <input type=\"text\" name=\"N_PHPR_DB_USER\"><br>";
-if (!strcmp($HOTELD_DB_PASS,"")) echo "".mex("Parola segreta per l'autenticazione al database",$pag).": 
+if (!strcmp((string) $HOTELD_DB_PASS,"")) echo "".mex("Parola segreta per l'autenticazione al database",$pag).": 
 <input type=\"text\" name=\"N_PHPR_DB_PASS\"><br>";
 echo "".mex("Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"",$pag)."?
 <select name=\"N_PHPR_LOAD_EXT\">
@@ -854,7 +855,7 @@ $nomi_contratti[$nome_con[0]] = $nome_con[1];
 } # fine for $num1
 for ($num1 = 1 ; $num1 <= $info_contr['max_contr'] ; $num1++) {
 echo "<option value=\"$num1\">".mex("solo il documento",$pag)." $num1";
-if (isset($nomi_contratti[$num1]) and strcmp($nomi_contratti[$num1],"")) echo " (".$nomi_contratti[$num1].")";
+if (isset($nomi_contratti[$num1]) and strcmp((string) $nomi_contratti[$num1],"")) echo " (".$nomi_contratti[$num1].")";
 echo "</option>";
 } # fine for $num1
 echo "</select>";
