@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -38,7 +38,12 @@ $var_pag[10] = 'inizioperiodo';
 $var_pag[11] = 'fineperiodo';
 $var_pag[12] = 'motivazione';
 $var_pag[13] = 'regola_1';
-$n_var_pag = 14;
+$var_pag[14] = 'mod_idregola1';
+$var_pag[15] = 'regola_1_tar';
+$var_pag[16] = 'tipotariffa_regola3';
+$var_pag[17] = 'num_persone';
+$var_pag[18] = 'regola_3';
+$n_var_pag = 19;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -283,21 +288,21 @@ $appartamento = htmlspecialchars($appartamento);
 $app_esistente = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($appartamento)."' ");
 if (!numlin_query($app_esistente) or $appartamenti_consentiti[$appartamento] != "SI") echo mex("Non sono stati inseriti tutti i dati necessari",$pag).".<br>";
 else {
-if ($mod_idregola1 and controlla_num_pos($mod_idregola1) == "SI") {
+if (!empty($mod_idregola1) and controlla_num_pos($mod_idregola1) == "SI") {
 $reg_esist = esegui_query("select * from $tableregole where idregole = '$mod_idregola1' ");
 if (numlin_query($reg_esist)) {
 $app_agenzia = risul_query($reg_esist,0,'app_agenzia');
 if (!$app_agenzia) $mod_idregola1 = "";
 } # fine if (numlin_query($reg_esist))
 else $mod_idregola1 = "";
-} # fine if ($mod_idregola1 and controlla_num_pos($mod_idregola1) == "SI")
+} # fine if (!empty($mod_idregola1) and controlla_num_pos($mod_idregola1) == "SI")
 else $mod_idregola1 = "";
 if ($mod_idregola1) $cond_reg_mod = " and idregole != '$mod_idregola1'";
 else $cond_reg_mod = "";
 $vecchia_regola = esegui_query("select * from $tableregole where app_agenzia = '".aggslashdb($appartamento)."' and iddatainizio <= '$idfineperiodo' and iddatafine >= '$idinizioperiodo'$cond_reg_mod order by iddatainizio");
 $num_vecchia_regola = numlin_query($vecchia_regola);
 if ($attiva_regole1_consentite != "n") $cancella_vecchie_regole = "";
-if ($num_vecchia_regola != 0 and !$cancella_vecchie_regole) {
+if ($num_vecchia_regola != 0 and empty($cancella_vecchie_regole)) {
 echo mex("Esiste già una regola di questo tipo nell'appartamento e nel periodo selezionato",'unit.php')." (".formatta_data($inizioperiodo,$stile_data)." ".mex("al",$pag)." ".formatta_data($fineperiodo,$stile_data).").<br><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div class=\"linhbox\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -305,13 +310,13 @@ echo mex("Esiste già una regola di questo tipo nell'appartamento e nel periodo
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <input type=\"hidden\" name=\"regola_1\" value=\"1\">
 <input type=\"hidden\" name=\"mod_idregola1\" value=\"$mod_idregola1\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
 <input type=\"hidden\" name=\"cancella_vecchie_regole\" value=\"1\">
-<input type=\"hidden\" name=\"chiudi_app\" value=\"".htmlspecialchars($chiudi_app)."\">
+<input type=\"hidden\" name=\"chiudi_app\" value=\"".htmlspecialchars(fixstr($chiudi_app))."\">
 <input type=\"hidden\" name=\"appartamento\" value=\"$appartamento\">
-<input type=\"hidden\" name=\"inizioperiodo\" value=\"".htmlspecialchars($inizioperiodo)."\">
-<input type=\"hidden\" name=\"fineperiodo\" value=\"".htmlspecialchars($fineperiodo)."\">
-<input type=\"hidden\" name=\"motivazione\" value=\"".htmlspecialchars($motivazione)."\">
+<input type=\"hidden\" name=\"inizioperiodo\" value=\"".htmlspecialchars(fixstr($inizioperiodo))."\">
+<input type=\"hidden\" name=\"fineperiodo\" value=\"".htmlspecialchars(fixstr($fineperiodo))."\">
+<input type=\"hidden\" name=\"motivazione\" value=\"".htmlspecialchars(fixstr($motivazione))."\">
 <em>".mex("Regole esistenti",$pag)."</em>:<br>";
 for ($num1 = 0 ; $num1 < $num_vecchia_regola ; $num1++) {
 $idregola_v = risul_query($vecchia_regola,$num1,'idregole');
@@ -337,7 +342,7 @@ echo "<br>";
 } # fine for $num1
 if ($attiva_regole1_consentite == "n") echo "<button class=\"cont\" type=\"submit\"><div>".mex("Cancella o ridimensiona queste regole",$pag)."</div></button>";
 echo "<br><br><br></div></form>";
-} # fine if ($num_vecchia_regola != 0 and !$cancella_vecchie_regole)
+} # fine if ($num_vecchia_regola != 0 and empty($cancella_vecchie_regole))
 else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
 $idregole = risul_query($idregole,0,0);
@@ -421,10 +426,10 @@ if ($risul_agg) {
 echo mex("Il periodo chiuso è stato liberato dalle prenotazioni",$pag).".<br>";
 } # fine if ($risul_agg)
 else echo mex("<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso",$pag).".<br>";
-unlock_tabelle($tabelle_lock);
-unset($tabelle_lock);
 $aggiorna_ic_disp = 1;
 } # fine if ($chiudi_app)
+unlock_tabelle($tabelle_lock);
+#unset($tabelle_lock);
 echo mex("La regola è stata inserita",$pag).".";
 $tabelle_lock = array($tableversioni,$tabletransazioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
@@ -435,12 +440,7 @@ $transaz_esistente = risul_query($transaz_esistente,0,'idtransazioni');
 esegui_query("update $tabletransazioni set dati_transazione1 = '".aggslashdb($inizioperiodo)."', dati_transazione2 = '".aggslashdb($fineperiodo)."', dati_transazione3 = '".aggslashdb($motivazione)."', dati_transazione4 = '".aggslashdb($chiudi_app)."', ultimo_accesso = '$ultimo_accesso' where idtransazioni = '$transaz_esistente' ");
 } # fine if (numlin_query($transaz_esistente))
 else {
-$adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-list($usec, $sec) = explode(' ', microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
-$val_casuale = mt_rand(100000,999999);
-$versione_transazione = prendi_numero_versione($tableversioni);
-$id_transazione = $adesso.$val_casuale.$versione_transazione;
+$id_transazione = crea_id_sessione("",$tableversioni,8);
 esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_transazione,anno,dati_transazione1,dati_transazione2,dati_transazione3,dati_transazione4,ultimo_accesso) 
 values ('$id_transazione','$id_sessione','cr_1a','$anno','".aggslashdb($inizioperiodo)."','".aggslashdb($fineperiodo)."','".aggslashdb($motivazione)."','".aggslashdb($chiudi_app)."','$ultimo_accesso')");
 } # fine else if (numlin_query($transaz_esistente))
@@ -470,14 +470,14 @@ echo mex("Le date sono sbagliate",$pag).".<br>";
 else {
 if ($motivazione == " ") echo mex("Motivazione non valida",$pag).".<br>";
 else {
-if ($mod_idregola1 and controlla_num_pos($mod_idregola1) == "SI") {
+if (!empty($mod_idregola1) and controlla_num_pos($mod_idregola1) == "SI") {
 $reg_esist = esegui_query("select * from $tableregole where idregole = '$mod_idregola1' ");
 if (numlin_query($reg_esist)) {
 $tariffa_chiusa = risul_query($reg_esist,0,'tariffa_chiusa');
 if (!$tariffa_chiusa) $mod_idregola1 = "";
 } # fine if (numlin_query($reg_esist))
 else $mod_idregola1 = "";
-} # fine if ($mod_idregola1 and controlla_num_pos($mod_idregola1) == "SI")
+} # fine if (!empty($mod_idregola1) and controlla_num_pos($mod_idregola1) == "SI")
 else $mod_idregola1 = "";
 if ($mod_idregola1) $cond_reg_mod = " and idregole != '$mod_idregola1'";
 else $cond_reg_mod = "";
@@ -550,6 +550,7 @@ $motivazione = htmlspecialchars($motivazione);
 if ($motivazione) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
 echo mex("La regola è stata inserita",$pag).".";
 $aggiorna_ic_tar = 1;
+unlock_tabelle($tabelle_lock);
 $tabelle_lock = array($tableversioni,$tabletransazioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
@@ -559,12 +560,7 @@ $transaz_esistente = risul_query($transaz_esistente,0,'idtransazioni');
 esegui_query("update $tabletransazioni set dati_transazione1 = '".aggslashdb($inizioperiodo)."', dati_transazione2 = '".aggslashdb($fineperiodo)."', dati_transazione3 = '".aggslashdb($motivazione)."', dati_transazione4 = '".aggslashdb($tipotariffa)."', ultimo_accesso = '$ultimo_accesso' where idtransazioni = '$transaz_esistente' ");
 } # fine if (numlin_query($transaz_esistente))
 else {
-$adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-list($usec, $sec) = explode(' ', microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
-$val_casuale = mt_rand(100000,999999);
-$versione_transazione = prendi_numero_versione($tableversioni);
-$id_transazione = $adesso.$val_casuale.$versione_transazione;
+$id_transazione = crea_id_sessione("",$tableversioni,8);
 esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_transazione,anno,dati_transazione1,dati_transazione2,dati_transazione3,dati_transazione4,ultimo_accesso) 
 values ('$id_transazione','$id_sessione','cr_1t','$anno','".aggslashdb($inizioperiodo)."','".aggslashdb($fineperiodo)."','".aggslashdb($motivazione)."','".aggslashdb($tipotariffa)."','$ultimo_accesso')");
 } # fine else if (numlin_query($transaz_esistente))
@@ -662,11 +658,11 @@ $num_da_assegnare = $num_apti;
 if ($num_apti < 1 or $num_apti > $num_appartamenti) $inserire = "NO";
 if ($num_regole_esistente) {
 $regola_2b_esist = risul_query($regola_esistente,0,'motivazione2');
-if (strcmp($regola_2b_esist,"")) {
+if (strcmp((string) $regola_2b_esist,"")) {
 $num_regola_2b_esist = explode(",",$regola_2b_esist);
 $num_regola_2b_esist = count($num_regola_2b_esist);
 if ($num_regola_2b_esist < $num_app_reali) $num_app_reali = $num_regola_2b_esist;
-} # fine if if (strcmp($regola_2b_esist,""))
+} # fine if if (strcmp((string) $regola_2b_esist,""))
 } # fine if ($num_regole_esistente)
 } # fine if ($regola_2)
 elseif ($num_regole_esistente) {
@@ -754,7 +750,7 @@ if (!$num_persone or controlla_num_pos($num_persone) != "SI") {
 $inserire = "NO";
 echo mex("Si deve inserire il numero di persone da associare",$pag).".<br>";
 } # fine if (!$num_persone or controlla_num_pos($num_persone) != "SI")
-if ($inserire != "NO") {
+if (!isset($inserire) or $inserire != "NO") {
 $regola2_esistente = esegui_query("select * from $tableregole where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 if (numlin_query($regola2_esistente)) {
 $lista_app2 = risul_query($regola2_esistente,0,'motivazione');
@@ -769,7 +765,7 @@ $app_trovato = array();
 $app_piccoli = "";
 $app_compatibile = 0;
 for ($num1 = 0 ; $num1 < $num_app2 ; $num1++) {
-if (!$app_trovato[$vett_app2[$num1]]) {
+if (empty($app_trovato[$vett_app2[$num1]])) {
 $app_trovato[$vett_app2[$num1]] = 1;
 $app = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($vett_app2[$num1])."' ");
 if (numlin_query($app)) {
@@ -777,7 +773,7 @@ $pers_max = risul_query($app,0,'maxoccupanti');
 if ($pers_max < $num_persone) $app_piccoli .= ", ".$vett_app2[$num1];
 else $app_compatibile = 1;
 } # fine if (numlin_query($app))
-} # fine if (!$app_trovato[$vett_app2[$num1]])
+} # fine if (empty($app_trovato[$vett_app2[$num1]]))
 } # fine for $num1
 if (!$app_compatibile) echo "<br><b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".lcfirst(mex("Non ci sono appartamenti con le caratteristiche richieste",'unit.php'))." ".mex("nella regola di assegnazione 2 di questa tariffa",$pag).".<br>";
 elseif ($app_piccoli) echo "<br><b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".mex("ci sono appartamenti",'unit.php')." (<b>".substr($app_piccoli,2)."</b>) ".mex("nella regola 2 di questa tariffa che non possono ospitare",$pag)." $num_persone ".mex("persone",$pag).".<br>";
@@ -794,7 +790,7 @@ esegui_query("insert into $tableregole (idregole,tariffa_per_persone,iddatainizi
 echo "<br>".mex("La regola di assegnazione",$pag)." 3 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_tar = 1;
-} # fine if ($inserire != "NO")
+} # fine if (!isset($inserire) or $inserire != "NO")
 } # fine if (!empty($regola_3) and $priv_mod_reg2 == "s")
 
 
@@ -842,7 +838,7 @@ echo mex("La regola di assegnazione",$pag)." 4 ".mex("è stata inserita",$pag)."
 
 
 if ($tabelle_lock) unlock_tabelle($tabelle_lock);
-if ($origine) $azione = controlla_pag_origine($origine);
+if (!empty($origine)) $azione = controlla_pag_origine($origine);
 else $azione = "crearegole.php";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$azione\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -869,7 +865,7 @@ echo "<br><h4 id=\"h_irul\"><span>".mex("Inserisci le regole di assegnazione per
 </span></h4><br><hr style=\"width: 95%\">";
 
 $mostra_solo_regola = 0;
-$origine = htmlspecialchars(fixset($origine));
+$origine = htmlspecialchars(fixstr($origine));
 if ($origine == "tab_reg1") {
 $mostra_solo_regola = 1;
 $origine = "visualizza_tabelle.php?tipo_tabella=regole#hreg1";
@@ -899,6 +895,8 @@ $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 
 if ((!$mostra_solo_regola or $mostra_solo_regola == 1) and $priv_mod_reg1 != "n") {
 $tipo_mod_reg1 = "";
+$inizio_select_orig = "";
+$fine_select_orig = "";
 if (!empty($mod_idregola1) and controlla_num_pos($mod_idregola1) == "SI") {
 $reg_esist = esegui_query("select * from $tableregole where idregole = '$mod_idregola1' ");
 if (numlin_query($reg_esist)) {
@@ -910,7 +908,7 @@ if ($tipo_mod_reg1) {
 $iddatainizio = risul_query($reg_esist,0,'iddatainizio');
 $iddatafine = risul_query($reg_esist,0,'iddatafine');
 $motivazione = risul_query($reg_esist,0,'motivazione');
-$motivazione2 = risul_query($reg_esist,0,'motivazione2');
+$motivazione2 = (string) risul_query($reg_esist,0,'motivazione2');
 $inizio_select = esegui_query("select datainizio from $PHPR_TAB_PRE"."periodi$anno where idperiodi = '$iddatainizio' ");
 $inizio_select = risul_query($inizio_select,0,'datainizio');
 $fine_select = esegui_query("select datafine from $PHPR_TAB_PRE"."periodi$anno where idperiodi = '$iddatafine' ");
@@ -924,7 +922,7 @@ $transaz_esist_1t = esegui_query("select * from $tabletransazioni where idsessio
 if (!numlin_query($transaz_esist_1a) or !numlin_query($transaz_esist_1t)) {
 $inizio_select = "";
 $fine_select = "";
-$motivazione_orig = htmlspecialchars(fixset($motivazione));
+$motivazione_orig = htmlspecialchars(fixstr($motivazione));
 $oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
 $date_select = esegui_query("select datainizio,datafine from $PHPR_TAB_PRE"."periodi$anno where datainizio <= '$oggi' and datafine > '$oggi' ");
 if (numlin_query($date_select) != 0) {
@@ -936,13 +934,14 @@ if (numlin_query($transaz_esist_1a)) {
 $inizio_select = risul_query($transaz_esist_1a,0,'dati_transazione1');
 $fine_select = risul_query($transaz_esist_1a,0,'dati_transazione2');
 $motivazione = risul_query($transaz_esist_1a,0,'dati_transazione3');
-$motivazione2 = risul_query($transaz_esist_1a,0,'dati_transazione4');
+$motivazione2 = (string) risul_query($transaz_esist_1a,0,'dati_transazione4');
 if ($motivazione2) $motivazione2 = "x";
 } # fine if (numlin_query($transaz_esist_1a))
 else {
 $inizio_select = $inizio_select_orig;
 $fine_select = $fine_select_orig;
 $motivazione = $motivazione_orig;
+unset($motivazione2);
 } # fine else if (numlin_query($transaz_esist_1a))
 } # fine if (!$tipo_mod_reg1)
 
@@ -954,13 +953,13 @@ echo "<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)."
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">";
 if ($tipo_mod_reg1) echo "<input type=\"hidden\" name=\"mod_idregola1\" value=\"$mod_idregola1\">";
 if ($origine) echo "<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">";
-echo "<select name=\"chiudi_app\">";
-if (isset($motivazione2) and $motivazione2 == "x") { $sel_x = " selected"; $sel = ""; }
-else { $sel_x = ""; $sel = " selected"; }
-echo "<option value=\"1\"$sel_x>".mex("Chiudi",$pag)."</option>";
+if (isset($motivazione2) and $motivazione2 != "x") { $sel_x = ""; $sel = " selected"; }
+else { $sel_x = " selected"; $sel = ""; }
+echo "<select name=\"chiudi_app\">
+<option value=\"1\"$sel_x>".mex("Chiudi",$pag)."</option>";
 if ($attiva_regole1_consentite == "n") echo "<option value=\"\"$sel>".mex("Chiedi prima di assegnare",$pag)."</option>";
 echo "</select> ".mex("l'appartamento",'unit.php')." <select name=\"appartamento\">";
-if (!isset($app_agenzia) or !strcmp($app_agenzia,"")) $sel = " selected";
+if (!isset($app_agenzia) or !strcmp((string) $app_agenzia,"")) $sel = " selected";
 else $sel = "";
 echo "<option value=\"\"$sel>--</option>";
 if ($tutti_app_consentiti and !$tipo_mod_reg1) include(C_DATI_PATH."/selectappartamenti.php");
@@ -1039,7 +1038,7 @@ echo " 1 ".mex("per le tariffe",$pag)."</div></button>
 </div></form>";
 } # fine if (($priv_mod_reg1 == "s" or $priv_mod_reg1 == "t") and $tipo_mod_reg1 != "a")
 
-if ($tutti_app_consentiti and $attiva_regole1_consentite == "n" and $tutte_tar_consentite and $priv_mod_reg1 == "s" and !$mostra_solo_regola) {
+if (!empty($tutti_app_consentiti) and $attiva_regole1_consentite == "n" and !empty($tutte_tar_consentite) and $priv_mod_reg1 == "s" and !$mostra_solo_regola) {
 echo "<hr style=\"width: 50%; margin-left: 2.5%;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -1047,7 +1046,7 @@ echo "<hr style=\"width: 50%; margin-left: 2.5%;\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <button class=\"crul\" type=\"submit\" name=\"canc_regola_1\" value=\"1\"><div>".mex("Cancella tutte le regole di questo tipo",$pag)."</div></button>
 </div></form>";
-} # fine if ($tutti_app_consentiti and $attiva_regole1_consentite == "n" and...
+} # fine if (!empty($tutti_app_consentiti) and $attiva_regole1_consentite == "n" and...
 
 echo "<hr style=\"width: 95%\">";
 } # fine if ((!$mostra_solo_regola or $mostra_solo_regola == 1) and $priv_mod_reg1 != "n")
@@ -1093,7 +1092,7 @@ for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
 $tariffa = risul_query($regole2,$num1,'tariffa_per_app');
 if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)])) {
 $lista_app = risul_query($regole2,$num1,'motivazione');
-$num_apti = risul_query($regole2,$num1,'motivazione3');
+$num_apti = (string) risul_query($regole2,$num1,'motivazione3');
 $v_apti = "true";
 if (substr($num_apti,0,1) == "v") $num_apti = substr($num_apti,1);
 elseif ($num_apti) $v_apti = "false";
