@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -73,9 +73,11 @@ define('C_MASSIMO_NUM_STORIA_SOLDI',140000);
 define('C_MASSIMO_NUM_COSTI',90000);
 define('C_MASSIMO_NUM_APP',0);
 define('C_MASSIMO_NUM_BYTE_UPLOAD',12582912);
+define('C_MASSIMO_NUM_EMAIL_GIORNALIERE',200); # NUM + (10%NUM * NUM_APP)
 define('C_CREA_ULTIMO_ACCESSO',"SI");
 #if (!defined('C_CARTELLA_CREA_MODELLI')) define('C_CARTELLA_CREA_MODELLI',"");
 #if (!defined('C_URL_CREA_MODELLI')) define('C_URL_CREA_MODELLI',"");
+#if (!defined('C_PERCORSO_PHPMAILER')) define('C_PERCORSO_PHPMAILER',"");
 define('C_DOMINIO_CREA_MODELLI',"");
 define('C_CHMOD_EXEC_MODELLI',"NO");
 define('C_CARTELLA_DOC',"");
@@ -91,7 +93,8 @@ define('C_URL_FAVICON',"");
 define('C_SEC_LIMITE_LIBERA_APP',"");
 define('C_LIMITE_BACKUP_GIORNALIERI',0);
 define('C_LIMITE_CHIAMATE_API_AL_MINUTO',0);
-define('C_MASCHERA_EMAIL',"NO");
+# può essere SI, NO o "spf: ..." con i campi spf (separati da spazi) che devono esistere nel dominio dell'email da mascherare
+if (!defined('C_MASCHERA_EMAIL')) define('C_MASCHERA_EMAIL',"");
 define('C_LIB_MERCADOPAGO',"");
 define('C_URL_MODULO_PAYBOX',"http://");
 define('C_NASCONDI_MARCA',"");
