@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -520,7 +520,7 @@ $costi_agg_importati = esegui_query("select * from $tablecostiprenota where idco
 $num_costi_agg_importati = numlin_query($costi_agg_importati);
 for ($num1 = 0 ; $num1 < $num_costi_agg_importati ; $num1++) {
 $idcostiprenota = risul_query($costi_agg_importati,$num1,'idcostiprenota');
-$settimane = risul_query($costi_agg_importati,$num1,'settimane');
+$settimane = (string) risul_query($costi_agg_importati,$num1,'settimane');
 if (str_replace(",","",$settimane) != $settimane) {
 $settimane = explode(",",$settimane);
 $settimane_nuove = ",";
@@ -556,9 +556,9 @@ $idperiodi = risul_query($tariffe_importate,$num1,'idperiodi');
 $idperiodi = $idperiodi - $id_data_ini_periodi_prec + 1;
 for ($num2 = 1 ; $num2 <= $num_tariffe_tab ; $num2++) {
 $tariffa = (string) risul_query($tariffe_importate,$num1,"tariffa".$num2);
-if (strcmp($tariffa,"")) esegui_query("update $tableperiodi set tariffa$num2 = '$tariffa' where idperiodi = $idperiodi ");
+if (strcmp((string) $tariffa,"")) esegui_query("update $tableperiodi set tariffa$num2 = '$tariffa' where idperiodi = $idperiodi ");
 $tariffap = (string) risul_query($tariffe_importate,$num1,"tariffa".$num2."p");
-if (strcmp($tariffap,"")) esegui_query("update $tableperiodi set tariffa$num2"."p = '$tariffap' where idperiodi = $idperiodi ");
+if (strcmp((string) $tariffap,"")) esegui_query("update $tableperiodi set tariffa$num2"."p = '$tariffap' where idperiodi = $idperiodi ");
 } # fine for $num2
 } # fine for $num1
 
@@ -583,9 +583,9 @@ else {
 if ($tariffa_chiusa) esegui_query("insert into $tableregole (idregole,tariffa_chiusa,iddatainizio,iddatafine) values ('$idregole','$tariffa_chiusa','$iddatainizio','$iddatafine') ");
 else esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ('$idregole','$app_agenzia','$iddatainizio','$iddatafine') ");
 } # fine else $tariffa_commissioni)
-if (strcmp($motivazione,"")) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
-if (strcmp($motivazione2,"")) esegui_query("update $tableregole set motivazione2 = '".aggslashdb($motivazione2)."' where idregole = '$idregole' ");
-if (strcmp($motivazione3,"")) esegui_query("update $tableregole set motivazione3 = '".aggslashdb($motivazione3)."' where idregole = '$idregole' ");
+if (strcmp((string) $motivazione,"")) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
+if (strcmp((string) $motivazione2,"")) esegui_query("update $tableregole set motivazione2 = '".aggslashdb($motivazione2)."' where idregole = '$idregole' ");
+if (strcmp((string) $motivazione3,"")) esegui_query("update $tableregole set motivazione3 = '".aggslashdb($motivazione3)."' where idregole = '$idregole' ");
 } # fine for $num1
 
 $soldi_importati = esegui_query("select * from $tablesoldi_prec where data_inserimento >= '$data_inizio_periodi' and  saldo_prenota is not NULL order by idsoldi");
@@ -837,7 +837,7 @@ esegui_query("insert into $tablenometariffe ($colonne) select $colonne from $tab
 $prezzi_tar_importati = esegui_query("select * from $tablenometariffe where idntariffe = '6' ");
 if (numlin_query($prezzi_tar_importati)) {
 for ($num1 = 1 ; $num1 <= $num_tariffe_tab ; $num1++) {
-$prezzi_imp_int = risul_query($prezzi_tar_importati,0,"tariffa$num1");
+$prezzi_imp_int = (string) risul_query($prezzi_tar_importati,0,"tariffa$num1");
 $prezzi_imp = explode(">",$prezzi_imp_int);
 $pi_nuovi = $prezzi_imp[0];
 for ($num2 = 1 ; $num2 < count($prezzi_imp) ; $num2++) {
