@@ -29,7 +29,7 @@ $tableclienti = $PHPR_TAB_PRE."clienti";
 $tablerelclienti = $PHPR_TAB_PRE."relclienti";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
-if (@is_array($campi_pers_vett) and $campi_pers_vett['num']) $num_campi_pers = $campi_pers_vett['num'];
+if (isset($campi_pers_vett) and is_array($campi_pers_vett) and !empty($campi_pers_vett['num'])) $num_campi_pers = $campi_pers_vett['num'];
 else $num_campi_pers = 0;
 
 if ($valida != "NO") {
@@ -65,34 +65,34 @@ $partita_iva = stripslashes($partita_iva);
 for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = stripslashes($campi_pers_vett['val'][$num1]);
 } # fine if (@get_magic_quotes_gpc())
 $cognome = htmlspecialchars($cognome);
-$nome = htmlspecialchars($nome);
-$soprannome = htmlspecialchars($soprannome);
-$titolo_cli = htmlspecialchars($titolo_cli);
-$documento = htmlspecialchars($documento);
-$tipodoc = htmlspecialchars($tipodoc);
-$cittadoc = htmlspecialchars($cittadoc);
-$regionedoc = htmlspecialchars($regionedoc);
-$nazionedoc = htmlspecialchars($nazionedoc);
-$cittanascita = htmlspecialchars($cittanascita);
-$regionenascita = htmlspecialchars($regionenascita);
-$nazionenascita = htmlspecialchars($nazionenascita);
-$nazionalita = htmlspecialchars($nazionalita);
-$nazione = htmlspecialchars($nazione);
-$regione = htmlspecialchars($regione);
-$citta = htmlspecialchars($citta);
-$nomevia = htmlspecialchars($nomevia);
-$numcivico = htmlspecialchars($numcivico);
-$cap = htmlspecialchars($cap);
-$telefono = htmlspecialchars($telefono);
-$telefono2 = htmlspecialchars($telefono2);
-$telefono3 = htmlspecialchars($telefono3);
-$fax = htmlspecialchars($fax);
-$email = htmlspecialchars($email);
-$email2 = htmlspecialchars($email2);
-$email_cert = htmlspecialchars($email_cert);
-$cod_fiscale = htmlspecialchars($cod_fiscale);
-$partita_iva = htmlspecialchars($partita_iva);
-for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = htmlspecialchars($campi_pers_vett['val'][$num1]);
+$nome = htmlspecialchars((string) $nome);
+$soprannome = htmlspecialchars((string) $soprannome);
+$titolo_cli = htmlspecialchars((string) $titolo_cli);
+$documento = htmlspecialchars((string) $documento);
+$tipodoc = htmlspecialchars((string) $tipodoc);
+$cittadoc = htmlspecialchars((string) $cittadoc);
+$regionedoc = htmlspecialchars((string) $regionedoc);
+$nazionedoc = htmlspecialchars((string) $nazionedoc);
+$cittanascita = htmlspecialchars((string) $cittanascita);
+$regionenascita = htmlspecialchars((string) $regionenascita);
+$nazionenascita = htmlspecialchars((string) $nazionenascita);
+$nazionalita = htmlspecialchars((string) $nazionalita);
+$nazione = htmlspecialchars((string) $nazione);
+$regione = htmlspecialchars((string) $regione);
+$citta = htmlspecialchars((string) $citta);
+$nomevia = htmlspecialchars((string) $nomevia);
+$numcivico = htmlspecialchars((string) $numcivico);
+$cap = htmlspecialchars((string) $cap);
+$telefono = htmlspecialchars((string) $telefono);
+$telefono2 = htmlspecialchars((string) $telefono2);
+$telefono3 = htmlspecialchars((string) $telefono3);
+$fax = htmlspecialchars((string) $fax);
+$email = htmlspecialchars((string) $email);
+$email2 = htmlspecialchars((string) $email2);
+$email_cert = htmlspecialchars((string) $email_cert);
+$cod_fiscale = htmlspecialchars((string) $cod_fiscale);
+$partita_iva = htmlspecialchars((string) $partita_iva);
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = htmlspecialchars((string) $campi_pers_vett['val'][$num1]);
 } # fine if ($valida != "NO")
 
 if (!$idclienti) {
@@ -119,7 +119,7 @@ $nome_maius = trim(ucwords($nome));
 esegui_query("update $tableclienti set nome = '".aggslashdb(substr($nome_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nome)
 if ($soprannome) {
-esegui_query("update $tableclienti set soprannome = '".aggslashdb($soprannome)."' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set soprannome = '".aggslashdb(substr($soprannome,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($soprannome)
 if ($titolo_cli) {
 $titoli_cliente = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'titoli_cliente' and idutente = '$id_utente'");
@@ -129,7 +129,7 @@ $titoli_cliente = explode(">",$titoli_cliente);
 for ($num1 = 0 ; $num1 < count($titoli_cliente) ; $num1++) {
 $tito = explode("<",$titoli_cliente[$num1]);
 if ($titolo_cli == $tito[0]) {
-esegui_query("update $tableclienti set titolo = '".aggslashdb($titolo_cli)."' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set titolo = '".aggslashdb(substr($titolo_cli,0,30))."' where idclienti = '$idclienti' ");
 if ($tito[1] and !$sesso) $sesso = $tito[1];
 break;
 } # fine if ($titolo_cli == $opt[0])
@@ -141,10 +141,14 @@ if ($sesso != "f") $sesso = "m";
 esegui_query("update $tableclienti set sesso = '$sesso' where idclienti = '$idclienti' ");
 } # fine if ($sesso)
 if ($mesenascita and $giornonascita and strlen($annonascita) == 4) {
-if ($annonascita > 1970) $datanascita = date("Y-m-d",mktime(0,0,0,$mesenascita,$giornonascita,$annonascita));
+if ($annonascita > 1970) $datanascita = date("Y-m-d",mktime(0,0,0,(int) $mesenascita,(int) $giornonascita,(int) $annonascita));
 else {
+$mesenascita = (int) $mesenascita;
+$giornonascita = (int) $giornonascita;
+$annonascita = (int) $annonascita;
 if (strlen($mesenascita) < 2) $mesenascita = "0".$mesenascita;
 if (strlen($giornonascita) < 2) $giornonascita = "0".$giornonascita;
+while (strlen($annonascita) < 4) $annonascita = "1".$annonascita;
 $datanascita = $annonascita."-".$mesenascita."-".$giornonascita;
 } # fine else if ($annonascita > 1970)
 $datanascita = aggslashdb($datanascita);
@@ -217,11 +221,11 @@ $regione_maius = trim(ucwords($regione));
 esegui_query("update $tableclienti set regione = '".aggslashdb(substr($regione_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($regione)
 if ($nomevia) {
-if (strcmp($via,"")) {
+if (strcmp((string) $via,"")) {
 if ($lingua_mex != "ita") include("./includes/lang/$lingua_mex/ordine_frasi.php");
-if ($ordine_strada == 2) $via = $nomevia." ".$via;
+if (isset($ordine_strada) and $ordine_strada == 2) $via = $nomevia." ".$via;
 else $via = $via." ".$nomevia;
-} # fine if (strcmp($via,""))
+} # fine if (strcmp((string) $via,""))
 else $via = $nomevia;
 $via_maius = trim(ucwords($via));
 esegui_query("update $tableclienti set via = '".aggslashdb(substr($via_maius,0,70))."' where idclienti = '$idclienti' ");
@@ -245,10 +249,10 @@ if ($partita_iva) esegui_query("update $tableclienti set partita_iva = '$partita
 if ($max_num_ordine) esegui_query("update $tableclienti set max_num_ordine = '".aggslashdb($max_num_ordine)."' where idclienti = '$idclienti' ");
 
 for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) {
-if (strcmp($campi_pers_vett['val'][$num1],"")) {
+if (strcmp((string) $campi_pers_vett['val'][$num1],"")) {
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tablerelclienti (idclienti,numero,tipo,testo1,testo2,testo3,datainserimento,hostinserimento,utente_inserimento) values ('$idclienti','1','campo_pers','".$campi_pers_vett[$num1]."','".$campi_pers_vett['tipo'][$num1]."','".aggslashdb($campi_pers_vett['val'][$num1])."','$datainserimento','$HOSTNAME','$id_utente_ins') ");
-} # fine if (strcmp($campi_pers_vett['val'][$num1],""))
+} # fine if (strcmp((string) $campi_pers_vett['val'][$num1],""))
 } # fine for $num1
 
 return $idclienti;
@@ -526,7 +530,7 @@ $liste_relutente[$id_sup_sel][$nomelista] .= "<option value=\"$opzione\">$opzion
 $liste_relutente[$id_sup_sel][$nomelista] .= "</select>";
 } # fine else if (!$num_lista_utente)
 } # fine if (empty($liste_relutente[$id_sup_sel][$nomelista]))
-$lista_return = fixset($liste_relutente[$id_sup_sel][$nomelista]);
+$lista_return = fixstr($liste_relutente[$id_sup_sel][$nomelista]);
 if ($sel) {
 if (substr($lista_return,0,7) == "<select") $lista_return = str_replace("<option value=\"$sel\">","<option value=\"$sel\" selected>",$lista_return);
 else $lista_return = str_replace(" name=\"\""," name=\"\" value=\"$sel\"",$lista_return);
