@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -47,7 +47,7 @@ $reg_costo = 0;
 if ($solo_visibili != "+pmin" or substr($mostra_ca,0,1) == "s" or substr($mostra_ca,0,1) == "p") $reg_costo = 1;
 elseif ($solo_visibili == "+pmin") {
 for ($nt = 1 ; $nt <= $num_tariffe ; $nt++) {
-$tariffa_corr = substr(risul_query($costi,$num1,"tariffa".$nt),0,1);
+$tariffa_corr = substr((string) risul_query($costi,$num1,"tariffa".$nt),0,1);
 if ($tariffa_corr == "s" or $tariffa_corr == "r") {
 $reg_costo = 2;
 break;
@@ -70,8 +70,8 @@ $dati_ca[$num_ca]['tasseperc'] = risul_query($costi,$num1,'tasseperc_ca');
 for ($nt = 1 ; $nt <= $num_tariffe ; $nt++) {
 $dati_ca[$num_ca]["tariffa".$nt] = risul_query($costi,$num1,"tariffa".$nt);
 if ($dati_ca[$num_ca]["tariffa".$nt] != "i") {
-$dati_ca[$num_ca]["tipo_associa_tariffa".$nt] = substr($dati_ca[$num_ca]["tariffa".$nt],0,1);
-$dati_ca[$num_ca]["tariffa".$nt] = substr($dati_ca[$num_ca]["tariffa".$nt],1);
+$dati_ca[$num_ca]["tipo_associa_tariffa".$nt] = substr((string) $dati_ca[$num_ca]["tariffa".$nt],0,1);
+$dati_ca[$num_ca]["tariffa".$nt] = substr((string) $dati_ca[$num_ca]["tariffa".$nt],1);
 } # fine if ($dati_ca[$num_ca]["tariffa".$nt] != "i")
 else {
 $dati_ca[$num_ca]["tariffa".$nt] = "";
@@ -79,7 +79,7 @@ $dati_ca[$num_ca]["incomp_tariffa".$nt] = "i";
 } # fine else if ($dati_ca[$num_ca]["tariffa".$nt] != "i")
 } # fine for $nt
 $dati_ca[$num_ca]['associasett'] = risul_query($costi,$num1,'associasett_ca');
-$numsett = risul_query($costi,$num1,'numsett_ca');
+$numsett = (string) risul_query($costi,$num1,'numsett_ca');
 $dati_ca[$num_ca]['numsett_orig'] = $numsett;
 $dati_ca[$num_ca]['numsett'] = substr($numsett,0,1);
 if ($dati_ca[$num_ca]['numsett'] == "m") $dati_ca[$num_ca]['sett_meno_una'] = substr($numsett,1,1);
@@ -152,7 +152,7 @@ $dati_ca[$num_ca]['id_beneinv'][$num2] = $bene_inv[0];
 $dati_ca[$num_ca]['molt_beneinv'][$num2] = $bene_inv[1];
 } # fine for $num2
 } # fine if ($dati_ca[$num_ca]['beniinv_orig'])
-$dati_ca[$num_ca]['periodipermessi_orig'] = risul_query($costi,$num1,'periodipermessi_ca');
+$dati_ca[$num_ca]['periodipermessi_orig'] = (string) risul_query($costi,$num1,'periodipermessi_ca');
 $dati_ca[$num_ca]['periodipermessi'] = substr($dati_ca[$num_ca]['periodipermessi_orig'],0,1);
 if ($dati_ca[$num_ca]['periodipermessi']) {
 $dati_ca[$num_ca]['sett_periodipermessi_ini'] = array();
@@ -188,7 +188,7 @@ $dati_ca[$num_ca]['appincompatibili_letto'] = 1;
 if (substr($dati_ca[$num_ca]['appincompatibili'],0,1) == ",") $dati_ca[$num_ca]['appincompatibili'] = substr($dati_ca[$num_ca]['appincompatibili'],1);
 } # fine if ($num_app_letto)
 } # fine if ($dati_ca[$num_ca]['letto'] == "s" and $tableappartamenti)
-$dati_ca[$num_ca]['categoria'] = risul_query($costi,$num1,'categoria_ca');
+$dati_ca[$num_ca]['categoria'] = (string) risul_query($costi,$num1,'categoria_ca');
 $dati_ca[$num_ca]['numlimite'] = risul_query($costi,$num1,'numlimite_ca');
 $regoleassegna_ca = explode(";",risul_query($costi,$num1,'regoleassegna_ca'));
 $dati_ca[$num_ca]['assegna_da_ini_prenota'] = $regoleassegna_ca[0];
@@ -340,10 +340,10 @@ for ($num1 = $idinizioperiodo ; $num1 <= $idfineperiodo ; $num1++) {
 if (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo) {
 if (!$moltiplica[$num_sett]) $moltiplica[$num_sett] = 0;
 $prezzo_costo_fisso_tot = $prezzo_costo_fisso_tot + ($prezzo_costo_fisso * $moltiplica[$num_sett]);
-if ($dati_ca[$num_costo]['tipo_val'] == "p") $prezzo_costo_sett = ($lista_tariffe[$num_lista_tariffe] * $prezzo_costo_perc) / 100;
-if ($dati_ca[$num_costo]['tipo_val'] == "q") $prezzo_costo_sett = (($lista_tariffe[$num_lista_tariffe] - $lista_tariffep[$num_lista_tariffe]) * $prezzo_costo_perc) / 100;
+if ($dati_ca[$num_costo]['tipo_val'] == "p") $prezzo_costo_sett = ((double) $lista_tariffe[$num_lista_tariffe] * $prezzo_costo_perc) / 100;
+if ($dati_ca[$num_costo]['tipo_val'] == "q") $prezzo_costo_sett = (((double) $lista_tariffe[$num_lista_tariffe] - (double) $lista_tariffep[$num_lista_tariffe]) * $prezzo_costo_perc) / 100;
 if ($dati_ca[$num_costo]['tipo_val'] == "s") {
-if ($numpersone) $prezzo_costo_sett = (($lista_tariffep[$num_lista_tariffe] / (double) $numpersone) * $prezzo_costo_perc) / 100;
+if ($numpersone) $prezzo_costo_sett = (((double) $lista_tariffep[$num_lista_tariffe] / (double) $numpersone) * $prezzo_costo_perc) / 100;
 else $prezzo_costo_sett = 0;
 } # fine if ($dati_ca[$num_costo]['tipo_val'] == "s")
 $prezzo_costo_perc_tot = $prezzo_costo_perc_tot + ($prezzo_costo_sett * $moltiplica[$num_sett]);
@@ -394,9 +394,9 @@ $prezzo_costo_perc = $prezzo_costo_perc * $moltiplica;
 if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_perc = floor($prezzo_costo_perc / $dati_ca[$num_costo]['arrotonda']) * $dati_ca[$num_costo]['arrotonda'];
 $prezzo_costo = $prezzo_costo_fisso + $prezzo_costo_perc;
 
-if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp($catpers_ca,"") and isset($dati_cat_pers[$catpers_ca]['perc']) and strcmp($dati_cat_pers[$catpers_ca]['perc'],"") and $dati_cat_pers[$catpers_ca]['perc'] != 100) {
+if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp((string) $catpers_ca,"") and isset($dati_cat_pers[$catpers_ca]['perc']) and strcmp((string) $dati_cat_pers[$catpers_ca]['perc'],"") and $dati_cat_pers[$catpers_ca]['perc'] != 100) {
 $prezzo_costo = round((((double) $prezzo_costo * (double)$dati_cat_pers[$catpers_ca]['perc']) / 100) / $dati_cat_pers['arrotond']) * $dati_cat_pers['arrotond'];
-} # fine if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp($catpers_ca,"") and...
+} # fine if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp((string) $catpers_ca,"") and...
 
 return $prezzo_costo;
 
@@ -454,7 +454,7 @@ return $settimane_costo;
 function calcola_moltiplica_costo ($dati_ca,$num_costo,&$moltiplica,$idinizioperiodo,$idfineperiodo,$settimane_costo,$nummoltiplica_ca,$numpersone,$cat_persone,$num_letti_agg) {
 
 $moltiplica = "";
-if (!strcmp($numpersone,"")) $numpersone = 0;
+if (!strcmp((string) $numpersone,"")) $numpersone = 0;
 if (!empty($dati_ca[$num_costo]['modo_cp_molt'])) {
 if (empty($cat_persone)) {
 $cat_persone = array(0 => array());
@@ -493,7 +493,7 @@ else $num_letti_agg[$num1] = $num_letti_agg[$num1] - $num_letti_agg['catp_tot'][
 } # fine if (!empty($dati_ca[$num_costo]['modo_cp_molt']))
 if ($dati_ca[$num_costo]['tipo'] == "s" and $dati_ca[$num_costo]['associasett'] == "s") {
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
-if (!strcmp(fixset($num_letti_agg[$num1]),"")) $num_letti_agg[$num1] = 0;
+if (!strcmp(fixstr($num_letti_agg[$num1]),"")) $num_letti_agg[$num1] = 0;
 if ($num_letti_agg[$num1] > $letti_agg_max) $letti_agg_max = $num_letti_agg[$num1];
 if ($settimane_costo != str_replace(",$num1,","",$settimane_costo)) $moltiplica .= ",".max(($numpersone + $num_letti_agg[$num1] + $dati_ca[$num_costo]['molt_agg']),0);
 } # fine for $num1
@@ -543,7 +543,7 @@ else $moltiplica_corr = $moltiplica;
 $num_letti_agg[$num1] = $num_letti_agg[$num1] + $moltiplica_corr;
 
 if (!empty($dati_cat_pers['num'])) {
-if (strcmp($catpers_ca,"")) $dati_ca[$num_costo]['cat_pers']['esist'][0] = 1;
+if (strcmp((string) $catpers_ca,"")) $dati_ca[$num_costo]['cat_pers']['esist'][0] = 1;
 else $catpers_ca = $dati_ca[$num_costo]['cat_pers']['ord'][0];
 if (!isset($num_letti_agg['catp'][$num1])) $num_letti_agg['catp'][$num1] = "";
 $num_letti_agg['catp'][$num1] .= " + $moltiplica_corr ";
@@ -686,7 +686,7 @@ $dati_cap[$numca]['id_beneinv'][$num1] = $bene_inv[0];
 $dati_cap[$numca]['molt_beneinv'][$num1] = $bene_inv[1];
 } # fine for $num1
 } # fine if ($dati_cap[$numca]['beniinv_orig'])
-$dati_cap[$numca]['periodipermessi_orig'] = risul_query($costi,$numca,'varperiodipermessi');
+$dati_cap[$numca]['periodipermessi_orig'] = (string) risul_query($costi,$numca,'varperiodipermessi');
 $dati_cap[$numca]['periodipermessi'] = substr($dati_cap[$numca]['periodipermessi_orig'],0,1);
 if ($dati_cap[$numca]['periodipermessi']) {
 $dati_cap[$numca]['sett_periodipermessi_ini'] = array();
@@ -715,13 +715,13 @@ for ($num1 = 1 ; $num1 < (count($sett) - 1) ; $num1++) $dati_cap[$numca]['moltip
 $dati_cap[$numca]['idntariffe'] = risul_query($costi,$numca,'idntariffe');
 $dati_cap[$numca]['appincompatibili'] = risul_query($costi,$numca,'varappincompatibili');
 $dati_cap[$numca]['categoria'] = risul_query($costi,$numca,'categoria');
-$dati_cap[$numca]['combina'] = risul_query($costi,$numca,'variazione');
+$dati_cap[$numca]['combina'] = (string) risul_query($costi,$numca,'variazione');
 $dati_cap[$numca]['escludi_tot_perc'] = substr($dati_cap[$numca]['combina'],1,1);
 $dati_cap[$numca]['combina'] = substr($dati_cap[$numca]['combina'],0,1);
-$dati_cap[$numca]['tariffeassociate'] = risul_query($costi,$numca,'vartariffeassociate');
+$dati_cap[$numca]['tariffeassociate'] = (string) risul_query($costi,$numca,'vartariffeassociate');
 $dati_cap[$numca]['tipo_tariffeassociate'] = substr($dati_cap[$numca]['tariffeassociate'],0,1);
 $dati_cap[$numca]['tariffeassociate'] = substr($dati_cap[$numca]['tariffeassociate'],1);
-$incomp_tariffe = risul_query($costi,$numca,'vartariffeincomp');
+$incomp_tariffe = (string) risul_query($costi,$numca,'vartariffeincomp');
 $incomp_tariffe = explode(",",$incomp_tariffe);
 for ($num1 = 0 ; $num1 < count($incomp_tariffe) ; $num1++) $dati_cap[$numca]["incomp_tariffa".$incomp_tariffe[$num1]] = "i";
 $dati_cap[$numca]['idprenota'] = $id_prenota;
@@ -780,19 +780,19 @@ else $numsettimane = "0";
 } # fine else if ($associasett_ca == "n")
 } # fine if ($dati_ca[$num_costo]['tipo'] == "s")
 else $numsettimane = "";
-if ($valnummoltiplica_ca != 1 or strcmp($numsettimane,"") or strcmp($cat_pers,"")) {
+if ($valnummoltiplica_ca != 1 or strcmp((string) $numsettimane,"") or strcmp((string) $cat_pers,"")) {
 $mess .= " (";
-if (strcmp($numsettimane,"")) $mess .= "$numsettimane ".mex("$parola_settimane",$pag);
-if ($valnummoltiplica_ca != 1 or strcmp($cat_pers,"")) {
-if (strcmp($numsettimane,"")) $mess .= " ";
+if (strcmp((string) $numsettimane,"")) $mess .= "$numsettimane ".mex("$parola_settimane",$pag);
+if ($valnummoltiplica_ca != 1 or strcmp((string) $cat_pers,"")) {
+if (strcmp((string) $numsettimane,"")) $mess .= " ";
 if ($valnummoltiplica_ca == 1) $mess .= mex("moltiplicato per",$pag)." 1 <em>".$dati_cat_pers[$cat_pers]['n_sing']."</em>";
 else {
 $mess .= mex("moltiplicato per",$pag)." $valnummoltiplica_ca";
-if (strcmp($cat_pers,"")) $mess .= " <em>".$dati_cat_pers[$cat_pers]['n_plur']."</em>";
+if (strcmp((string) $cat_pers,"")) $mess .= " <em>".$dati_cat_pers[$cat_pers]['n_plur']."</em>";
 } # fine else if ($valnummoltiplica_ca == 1)
-} # fine if ($valnummoltiplica_ca != 1 or strcmp($cat_pers,""))
+} # fine if ($valnummoltiplica_ca != 1 or strcmp((string) $cat_pers,""))
 $mess .= ")";
-} # fine if ($valnummoltiplica_ca != 1 or strcmp($numsettimane,"") or strcmp($cat_pers,""))
+} # fine if ($valnummoltiplica_ca != 1 or strcmp((string) $numsettimane,"") or strcmp((string) $cat_pers,""))
 $mess .= " ".mex("verrà aggiunto",$pag)."$per_la_prenotazione: <b>$val_costoagg_p</b> $Euro.<br>";
 
 if (!$silenzio) echo $mess;
@@ -832,8 +832,8 @@ function controlla_beni_inventario_costo ($tablerelinventario,$dati_ca,$num_cost
 
 $beni_presenti = "SI";
 if ($dati_ca[$num_costo]['tipo_beniinv']) {
-if (!strcmp($num_ripetizioni_costo,"")) $num_ripetizioni_costo = calcola_ripetizioni_costo($dati_ca,$num_costo,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica);
-if (!strcmp($beniinv_ripeti,"")) $beniinv_ripeti = $dati_ca[$num_costo]['beniinv_ripeti'];
+if (!strcmp((string) $num_ripetizioni_costo,"")) $num_ripetizioni_costo = calcola_ripetizioni_costo($dati_ca,$num_costo,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica);
+if (!strcmp((string) $beniinv_ripeti,"")) $beniinv_ripeti = $dati_ca[$num_costo]['beniinv_ripeti'];
 if ($beniinv_ripeti) $num_ripetizioni_costo_diff = $num_ripetizioni_costo - $beniinv_ripeti;
 else $num_ripetizioni_costo_diff = $num_ripetizioni_costo;
 if ($num_ripetizioni_costo_diff) {
@@ -848,12 +848,12 @@ $cond_mag = "idappartamento = '$idapp'";
 } # fine if ($tipo_beniinv == "app")
 for ($num1 = 0 ; $num1 < $dati_ca[$num_costo]['num_beniinv'] ; $num1++) {
 $id_beneinv = $dati_ca[$num_costo]['id_beneinv'][$num1];
-if (!isset($beniinv_presenti[$tipo_beniinv][$id_beneinv]) or !strcmp($beniinv_presenti[$tipo_beniinv][$id_beneinv],"")) {
+if (!isset($beniinv_presenti[$tipo_beniinv][$id_beneinv]) or !strcmp((string) $beniinv_presenti[$tipo_beniinv][$id_beneinv],"")) {
 $beniinv_presenti[$tipo_beniinv][$id_beneinv] = 0;
 $bip = esegui_query("select quantita from $tablerelinventario where idbeneinventario = '$id_beneinv' and $cond_mag ");
 if (numlin_query($bip)) $beniinv_presenti[$tipo_beniinv][$id_beneinv] = risul_query($bip,0,'quantita');
 else $beni_presenti = "NO";
-} # fine if (!isset($beniinv_presenti[$tipo_beniinv][$id_beneinv]) or !strcmp($beniinv_presenti[$tipo_beniinv][$id_beneinv],""))
+} # fine if (!isset($beniinv_presenti[$tipo_beniinv][$id_beneinv]) or !strcmp((string) $beniinv_presenti[$tipo_beniinv][$id_beneinv],""))
 $num_beni_tot = $num_ripetizioni_costo_diff * $dati_ca[$num_costo]['molt_beneinv'][$num1];
 if (($beniinv_presenti[$tipo_beniinv][$id_beneinv] - $num_beni_tot) < 0) {
 $beni_presenti = "NO";
