@@ -88,9 +88,9 @@ if ($mostra_cod) {
 $codice = htmlspecialchars(risul_query($rel_utente,$num1,"codice_$rel_sing",$tablerel));
 $codice2 = htmlspecialchars(risul_query($rel_utente,$num1,"codice2_$rel_sing",$tablerel));
 $codice3 = htmlspecialchars(risul_query($rel_utente,$num1,"codice3_$rel_sing",$tablerel));
-if (strcmp($codice,"")) echo " ($codice)";
-if (strcmp($codice2,"")) echo " (".mex("2°",'personalizza.php')." $codice2)";
-if (strcmp($codice3,"")) echo " (".mex("3°",'personalizza.php')." $codice3)";
+if (strcmp((string) $codice,"")) echo " ($codice)";
+if (strcmp((string) $codice2,"")) echo " (".mex("2°",'personalizza.php')." $codice2)";
+if (strcmp((string) $codice3,"")) echo " (".mex("3°",'personalizza.php')." $codice3)";
 } # fine if ($mostra_cod)
 echo "</option>";
 } # fine for $num1
