@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="",$ins_costi_agg="",$costo_letto_imposto="NO") {
+function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="",$ins_costi_agg="",$costo_letto_imposto="NO",$info_per_mod=array('num' => 0)) {
 global $id_utente,$HOSTNAME;
 
 $PHPR_TAB_PRE = aggslashdb($PHPR_TAB_PRE);
@@ -60,6 +60,22 @@ if (!function_exists('dati_costi_agg_ntariffe')) include("./includes/funzioni_co
 $dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","",$tableappartamenti);
 } # fine if ($ins_costi_agg or $costo_letto_imposto != "NO")
 
+if ($info_per_mod['num']) {
+# Periodi modificati inclusi in periodo chiuso, devono essere ordinati per data iniziale nel caso ce ne siano vari in un solo periodo chiuso
+$info_per_mod_ord = $info_per_mod['ini'];
+asort($info_per_mod_ord);
+reset($info_per_mod_ord);
+$info_per_mod['new']['num'] = 0;
+foreach ($info_per_mod_ord as $num_per => $ini_per) {
+$info_per_mod['new']['ini'][$info_per_mod['new']['num']] = $ini_per;
+$info_per_mod['new']['fine'][$info_per_mod['new']['num']] = $info_per_mod['fine'][$num_per];
+$info_per_mod['new']['app'][$info_per_mod['new']['num']] = $info_per_mod['app'][$num_per];
+$info_per_mod['new']['num']++;
+} # fine foreach ($info_per_mod_ord as $num_per => $ini_per)
+$info_per_mod = $info_per_mod['new'];
+unset($info_per_mod_ord);
+} # fine if ($info_per_mod['num'])
+
 $app_eliminati_costi = array();
 $inserire = "";
 $mess_prenota = "";
@@ -105,8 +121,8 @@ for ($num1 = $inizioperiodo[$n_t] ; $num1 <= $fineperiodo[$n_t] ; $num1++) {
 $rigasettimana = esegui_query("select * from $tableperiodi where idperiodi = '$num1' ");
 $esistetariffa = risul_query($rigasettimana,0,$tipotariffa[$n_t]);
 $esistetariffap = risul_query($rigasettimana,0,$tipotariffa[$n_t]."p");
-if ((!strcmp($esistetariffa,"") or $esistetariffa < 0) and (!strcmp($esistetariffap,"") or $esistetariffap < 0) and (!isset($tar_sett_imp[$num1]) or !strcmp($tar_sett_imp[$num1],""))) $tariffa_sbagliata = "SI";
-if (!empty($dati_tariffe[$tipotariffa[$n_t]]['chiusa'][$num1]) and (!isset($tar_sett_imp[$num1]) or !strcmp($tar_sett_imp[$num1],""))) $tariffa_sbagliata = "SI";
+if ((!strcmp((string) $esistetariffa,"") or $esistetariffa < 0) and (!strcmp((string) $esistetariffap,"") or $esistetariffap < 0) and (!isset($tar_sett_imp[$num1]) or !strcmp((string) $tar_sett_imp[$num1],""))) $tariffa_sbagliata = "SI";
+if (!empty($dati_tariffe[$tipotariffa[$n_t]]['chiusa'][$num1]) and (!isset($tar_sett_imp[$num1]) or !strcmp((string) $tar_sett_imp[$num1],""))) $tariffa_sbagliata = "SI";
 } # fine for $num1
 } # fine else if (substr($tipotariffa[$n_t],0,7) != "tariffa" or...
 if ($tariffa_sbagliata == "SI") {
@@ -178,11 +194,11 @@ $mess_errore .= ".<br>";
 } # fine if (!empty($lista_app[$n_t]))
 
 # se il costo letto imposto ha appartamenti incompatibili
-if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] and strcmp($dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],"")) {
+if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] and strcmp((string) $dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],"")) {
 $app_incomp_costi[$n_t] = ",".$dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'].",";
 $lista_app_corr = fixset($lista_app[$n_t]);
 $lista_app[$n_t] = "";
-if (strcmp($lista_app_corr,"")) $lista_app_corr = ",$lista_app_corr,";
+if (strcmp((string) $lista_app_corr,"")) $lista_app_corr = ",$lista_app_corr,";
 for ($num1 = 0 ; $num1 < $numappartamenti ; $num1++) {
 $idapp = risul_query($appartamenti,$num1,'idappartamenti');
 if (!$lista_app_corr or str_replace(",$idapp,","",$lista_app_corr) != $lista_app_corr) {
@@ -206,7 +222,7 @@ if ($num_tipologie > 1) $mess_errore .= " (".mex("tipologia","clienti.php")." $n
 $mess_errore .= ".<br>";
 $inserire = "NO";
 } # fine else if ($lista_app[$n_t])
-} # fine if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] and strcmp($dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],""))
+} # fine if ($costo_letto_imposto != "NO" and $costo_letto_imposto[$n_t]['id'] and strcmp((string) $dati_ca[$dati_ca['id'][$costo_letto_imposto[$n_t]['id']]]['appincompatibili'],""))
 
 if ($numpersone[$n_t]) {
 if (controlla_num_pos($numpersone[$n_t]) == "NO") {
@@ -217,10 +233,10 @@ $mess_errore .= ".<br>";
 } # fine if (controlla_num_pos($numpersone[$n_t]) == "NO")
 $app_richiesti_copia = $app_richiesti_id[$n_t];
 $posti = 0;
-if ($app_regola2_predef) {
+if (!empty($app_regola2_predef)) {
 $app_regola2_predef = ",$app_regola2_predef,";
 $posto_reg2_orig = 0;
-} # fine if ($app_regola2_predef)
+} # fine if (!empty($app_regola2_predef))
 for ($num1 = 0 ; $num1 < $numappartamenti ; $num1++) {
 $idapp = risul_query($appartamenti,$num1,'idappartamenti');
 $maxoccupanti = risul_query($appartamenti,$num1,'maxoccupanti');
@@ -233,13 +249,13 @@ $app_richiesti_id[$n_t][$idapp] = "SI";
 $posti++;
 } # fine else if ($maxoccupanti and $maxoccupanti < $numpersone[$n_t])
 } # fine if (!$app_richiesti_copia or (isset($app_richiesti_copia[$idapp]) and...
-if ($app_regola2_predef) {
+if (!empty($app_regola2_predef)) {
 if (str_replace(",$idapp,","",$app_regola2_predef) != $app_regola2_predef) {
 if (!$maxoccupanti or $maxoccupanti >= $numpersone[$n_t]) $posto_reg2_orig = 1;
 } # fine if (str_replace(",$idapp,","",$app_regola2_predef) != $app_regola2_predef)
-} # fine if ($app_regola2_predef)
+} # fine if (!empty($app_regola2_predef))
 } # fine for $num1
-if ($posti == 0 or ($app_regola2_predef and !$posto_reg2_orig)) {
+if ($posti == 0 or (!empty($app_regola2_predef) and empty($posto_reg2_orig))) {
 $mess_errore .= mex("Non c'è nessun appartamento tra quelli richiesti che possa ospitare",'unit.php')." ".$numpersone[$n_t]." ".mex("persone","clienti.php");
 if ($num_tipologie > 1) $mess_errore .= " (".mex("tipologia","clienti.php")." $n_t)";
 $mess_errore .= ".<br>";
@@ -264,21 +280,20 @@ $app_richiesti[',succ_non_vicino,'] = $prenota_vicine;
 elseif ($prenota_vicine == "SI") $app_richiesti[',vicini,'] = "SI";
 } # fine if ($num_tipologie > 1)
 
-if ($id_prenota_imp) {
+if (!empty($id_prenota_imp[$n_t])) {
 if (controlla_num_pos($id_prenota_imp[$n_t]) == "SI") {
 $id_esistente = esegui_query("select idprenota from $tableprenota where idprenota = '".$id_prenota_imp[$n_t]."' ");
 if (numlin_query($id_esistente)) unset($id_prenota_imp);
 } # fine if (controlla_num_pos($id_prenota_imp[$n_t]) == "SI")
 else unset($id_prenota_imp);
-} # fine if ($id_prenota_imp)
+} # fine if (!empty($id_prenota_imp[$n_t]))
 
 } # fine for $n_t
 
 
 if ($inserire != "NO") {
 
-$condizioni_regole1_non_sel = "";
-$app_agenzia = esegui_query("select * from $tableregole where app_agenzia != ''$condizioni_regole1_non_sel");
+$app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' ");
 $num_app_agenzia = numlin_query($app_agenzia);
 
 $minuti_durata_insprenota = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_insprenota' and idutente = '1'");
@@ -308,15 +323,36 @@ else $tot_prenota = 0;
 $profondita['tot_prenota_ini'] = $tot_prenota;
 $profondita['tot_prenota_attuale'] = $tot_prenota;
 tab_a_var($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett,$anno,$dati_app,$profondita,$PHPR_TAB_PRE."prenota");
-unset($info_periodi_ag);
-$info_periodi_ag['numero'] = 0;
+$info_periodi_ag = array('numero' => 0);
+# Periodi con regole 1 di chiusura (motivazione2 = x) sono inseriti in $app_prenota_id
 for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
 $mot2 = risul_query($app_agenzia,$num1,'motivazione2');
 if ($mot2 == "x") {
-$info_periodi_ag['app'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'app_agenzia');
-$info_periodi_ag['ini'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'iddatainizio');
-$info_periodi_ag['fine'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'iddatafine');
+$app_ag = risul_query($app_agenzia,$num1,'app_agenzia');
+$ini_ag = risul_query($app_agenzia,$num1,'iddatainizio');
+$fine_ag = risul_query($app_agenzia,$num1,'iddatafine');
+# Se ci sono periodi lasciati liberi da prenotazioni che si stanno modificando non si devono chiudere
+for ($num2 = 0 ; $num2 < $info_per_mod['num'] ; $num2++) {
+if ($info_per_mod['app'][$num2] == $app_ag and $info_per_mod['ini'][$num2] <= $fine_ag and $info_per_mod['fine'][$num2] >= $ini_ag) {
+if ($info_per_mod['ini'][$num2] > $ini_ag and $info_per_mod['fine'][$num2] < $fine_ag) {
+$info_periodi_ag['app'][$info_periodi_ag['numero']] = $app_ag;
+$info_periodi_ag['ini'][$info_periodi_ag['numero']] = $ini_ag;
+$info_periodi_ag['fine'][$info_periodi_ag['numero']] = ($info_per_mod['ini'][$num2] - 1);
 $info_periodi_ag['numero']++;
+$ini_ag = ($info_per_mod['fine'][$num2] + 1);
+} # fine if ($info_per_mod['ini'][$num2] > $ini_ag and...
+else {
+if ($info_per_mod['ini'][$num2] <= $ini_ag) $ini_ag = ($info_per_mod['fine'][$num2] + 1);
+if ($info_per_mod['fine'][$num2] >= $fine_ag) $fine_ag = ($info_per_mod['ini'][$num2] - 1);
+} # fine else if ($info_per_mod['ini'][$num2] > $ini_ag and...
+} # fine if ($info_per_mod['app'][$num2] == $app_ag and...
+} # fine for $num2
+if ($fine_ag >= $ini_ag) {
+$info_periodi_ag['app'][$info_periodi_ag['numero']] = $app_ag;
+$info_periodi_ag['ini'][$info_periodi_ag['numero']] = $ini_ag;
+$info_periodi_ag['fine'][$info_periodi_ag['numero']] = $fine_ag;
+$info_periodi_ag['numero']++;
+} # fine if ($fine_ag >= $ini_ag)
 } # fine if ($mot2 == "x")
 } # fine for $num1
 if ($info_periodi_ag['numero']) inserisci_prenota_fittizie($info_periodi_ag,$profondita,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett,$app_assegnabili_id);
@@ -374,7 +410,7 @@ if (!$risul_agg) $fatto_libera2 = "NO";
 if ($fatto_libera2 == "NO") {
 $inserire = "NO";
 $mess_errore .= mex("Nel periodo selezionato non è possibile ospitare il cliente negli appartamenti richiesti",'unit.php');
-if ($app_incomp_costi) $mess_errore .= " ".mex("con i costi aggiuntivi selezionati",'clienti.php');
+if (!empty($app_incomp_costi)) $mess_errore .= " ".mex("con i costi aggiuntivi selezionati",'clienti.php');
 $mess_errore .= ".<br>";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $mess_prenota .= mex("Prenotazione","prenota.php")." ".mex("dal","prenota.php")." <b>".formatta_data($inizioperiodo_orig[$n_t],$stile_data)."</b> ".mex("al","prenota.php")." <b>".formatta_data($fineperiodo_orig[$n_t],$stile_data)."</b>";
@@ -528,13 +564,13 @@ $lista_tariffepo_sett = "";
 $tar_sett_imp = fixset($tariffe_sett_imp[$n_t]);
 for ($num2 = $inizioperiodo[$n_t] ; $num2 <= $fineperiodo[$n_t] ; $num2++) {
 $riga_tariffa = esegui_query("select * from  $tableperiodi where idperiodi = $num2");
-if (isset($tar_sett_imp[$num2]) and strcmp($tar_sett_imp[$num2],"")) $costo_tariffa = $tar_sett_imp[$num2];
+if (isset($tar_sett_imp[$num2]) and strcmp((string) $tar_sett_imp[$num2],"")) $costo_tariffa = $tar_sett_imp[$num2];
 else $costo_tariffa = risul_query($riga_tariffa,0,$tipotariffa[$n_t]);
 if ($dati_tariffe[$tipotariffa[$n_t]]['moltiplica'] == "p") {
-if (!strcmp($costo_tariffa,"")) $costo_tariffa = 0;
-if (isset($tar_sett_imp[$num2]) and strcmp($tar_sett_imp[$num2],"")) $costo_tariffap = 0;
+if (!strcmp((string) $costo_tariffa,"")) $costo_tariffa = 0;
+if (isset($tar_sett_imp[$num2]) and strcmp((string) $tar_sett_imp[$num2],"")) $costo_tariffap = 0;
 else $costo_tariffap = risul_query($riga_tariffa,0,$tipotariffa[$n_t]."p");
-if (!strcmp($costo_tariffap,"")) $costo_tariffap = 0;
+if (!strcmp((string) $costo_tariffap,"")) $costo_tariffap = 0;
 $lista_tariffepo_sett .= ",".$costo_tariffap;
 $costo_tariffap = (double) $costo_tariffap * (double) $numpersone[$n_t];
 $lista_tariffep_sett .= ",".$costo_tariffap;
@@ -666,7 +702,7 @@ $variazione_ca .= $dati_ca[$num_costo]['escludi_tot_perc'];
 esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,variazione,varmoltiplica,varnumsett,varperiodipermessi,varbeniinv,varappincompatibili,vartariffeassociate,vartariffeincomp,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$idprenota','$tipo_ca','".aggslashdb($dati_ca[$num_costo]['nome'])."','$valore_ca','$associasett_ca','$settimane_costo','$moltiplica','".$dati_ca[$num_costo]['letto']."','".$dati_ca[$num_costo]['id']."','$variazione_ca','$varmoltiplica_ca','$varnumsett_ca','$varperiodipermessi_ca','$varbeniinv_ca','$varappincompatibili_ca','$vartariffeassociate_ca','$vartariffeincomp_ca','$datainserimento','$HOSTNAME','$id_utente_ins')");
 if (substr($tipo_ca,1,1) != "f") esegui_query("update $tablecostiprenota set valore_perc = '$valore_perc_ca', arrotonda = '".$dati_ca[$num_costo]['arrotonda']."' where idcostiprenota = '$idcostiprenota'");
 if ($dati_ca[$num_costo]['tasseperc']) esegui_query("update $tablecostiprenota set tasseperc = '".$dati_ca[$num_costo]['tasseperc']."' where idcostiprenota = '$idcostiprenota'");
-if (strcmp($dati_ca[$num_costo]['categoria'],"")) esegui_query("update $tablecostiprenota set categoria = '".$dati_ca[$num_costo]['categoria']."' where idcostiprenota = '$idcostiprenota'");
+if (strcmp((string) $dati_ca[$num_costo]['categoria'],"")) esegui_query("update $tablecostiprenota set categoria = '".$dati_ca[$num_costo]['categoria']."' where idcostiprenota = '$idcostiprenota'");
 if ($prezzo_costo_tot) {
 $prezzo_costo_tot_p = punti_in_num($prezzo_costo_tot,$stile_soldi);
 $mess_prenota .= "$prezzo_costo_tot_p $Euro &nbsp;&nbsp;&nbsp;&nbsp;&nbsp; ";
@@ -786,15 +822,28 @@ $mess_prenota .= "<br>".mex("Orario stimato di entrata","prenota.php").": <b>".s
 } # fine if (controlla_num_pos($giorno_stima_checkin) == "SI" and...
 } # fine if (!empty($giorno_stima_checkin[$n_t]) and !empty($ora_stima_checkin[$n_t]) and...
 
-if (strcmp($commento[$n_t],"") or $commento['pers'][$n_t]) {
-$commento[$n_t] = htmlspecialchars($commento[$n_t]);
-if (strcmp($commento[$n_t],"")) $mess_prenota .= "<br>".mex("Commento","prenota.php").": ".$commento[$n_t]."<br>";
-if (!empty($commento['pers'][$n_t])) $commento[$n_t] .= $commento['pers'][$n_t];
-$commento[$n_t] = aggslashdb($commento[$n_t]);
-esegui_query("update $tableprenota set commento = '".$commento[$n_t]."' where idprenota = '$idprenota' ");
-} # fine if (strcmp($commento[$n_t],"") or $commento['pers'][$n_t])
+if (strcmp(fixstr($commento[$n_t]),"") or !empty($commento['pers_esist'][$n_t]) or !empty($commento['ins_pers_tipo'][$n_t])) {
+$commento[$n_t] = htmlspecialchars(fixstr($commento[$n_t]));
+if (strcmp($commento[$n_t],"")) {
+$mess_prenota .= "<br>".mex("Commento",'prenota.php').": ".$commento[$n_t];
+if (empty($commento['ins_pers_tipo'][$n_t])) $mess_prenota .= "<br>";
+} # fine if (strcmp($commento[$n_t],""))
+if (!empty($commento['pers_esist'][$n_t])) {
+$commento[$n_t] .= $commento['pers_esist'][$n_t];
+if (!empty($commento['ins_pers_tipo'][$n_t]) and strstr($commento[$n_t],">".$commento['ins_pers_tipo'][$n_t]."<")) {
+$commento[$n_t] = explode(">".$commento['ins_pers_tipo'][$n_t]."<",$commento[$n_t]);
+$commento[$n_t] = $commento[$n_t][0].strstr(fixstr($commento[$n_t][1]),">");
+} # fine if (!empty($commento['pers_esist'][$n_t]) and...
+} # fine if (!empty($commento['pers_esist'][$n_t]))
+elseif (!empty($commento['ins_pers_tipo'][$n_t])) $commento[$n_t] .= ">>";
+if (!empty($commento['ins_pers_tipo'][$n_t])) {
+$commento[$n_t] .= ">".$commento['ins_pers_tipo'][$n_t]."<".htmlspecialchars($commento['ins_pers_txt'][$n_t]);
+$mess_prenota .= "<br>".mex("Commento","prenota.php")." \"".$commento['ins_pers_tipo'][$n_t]."\": ".htmlspecialchars($commento['ins_pers_txt'][$n_t])."<br>";
+} # fine if (!empty($commento['ins_pers_tipo'][$n_t]))
+esegui_query("update $tableprenota set commento = '".aggslashdb($commento[$n_t])."' where idprenota = '$idprenota' ");
+} # fine if (strcmp((string) $commento[$n_t],"") or !empty($commento['pers_esist'][$n_t] or..
 
-$mess_prenota .= "<br>".mex("Prenotazione","prenota.php")." $idprenota ".mex("inserita","prenota.php")."!<br>";
+$mess_prenota .= "<br>".mex("Prenotazione","prenota.php")." $idprenota ".mex("inserita",'prenota.php')."!<br>";
 if ($n_t != $num_tipologie) $mess_prenota .= "<hr style=\"width: 95%\">";
 
 $lista_idprenota .= ",$idprenota";
@@ -843,7 +892,7 @@ $stato['inserita'] = "SI";
 
 } # fine if ($inserire != "NO")
 
-if (!@is_array($stato) or $stato['inserita'] != "SI") $stato['inserita'] = "NO";
+if (!isset($stato) or !is_array($stato) or fixset($stato['inserita']) != "SI") $stato['inserita'] = "NO";
 $stato['mess_errore'] = $mess_errore;
 $stato['mess_regola1'] = $mess_regola1;
 $stato['mess_prenota'] = $mess_prenota;
