@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -39,7 +39,7 @@ function connetti_db ($database,$host,$port,$user,$password,$estensione) {
 global $link_mysqli;
 if ($estensione == "SI") dl("mysqli.so");
 $link_mysqli = mysqli_connect($host,$user,$password,$database,$port);
-@mysqli_query($link_mysqli,"SET NAMES 'utf8mb4'");
+if ($link_mysqli) @mysqli_query($link_mysqli,"SET NAMES 'utf8mb4'");
 
 return $link_mysqli;
 
@@ -159,7 +159,7 @@ return $risul;
 
 function aggslashdb ($stringa) {
 
-$risul = addslashes($stringa);
+$risul = addslashes((string) $stringa);
 return $risul;
 
 } # fine function aggslashdb
@@ -248,10 +248,11 @@ return $risul;
 } # fine function lock_tabelle
 
 
-function unlock_tabelle ($tabelle_lock,$azione = "") {
+function unlock_tabelle (&$tabelle_lock,$azione = "") {
 
 global $link_mysqli;
 $risul = mysqli_query($link_mysqli,"unlock tables");
+$tabelle_lock = null;
 
 } # fine function unlock_tabelle
 
