@@ -31,6 +31,14 @@ unset($nome_raggr);
 $app_ric_raggr = array();
 unset($tipotariffa);
 $napp_ric_raggr = array();
+if ($c_sfondo_tab_disp) {
+$sfondo = " background-color: $c_sfondo_tab_disp;";
+$stile_sfondo = " style=\"background-color: $c_sfondo_tab_disp;\"";
+} # fine if ($c_sfondo_tab_disp)
+else {
+$sfondo = "";
+$stile_sfondo = "";
+} # fine else if ($c_sfondo_tab_disp)
 
 if ($mostra_quadro_disp == "app") {
 $mostra_num_liberi = "NO";
@@ -96,7 +104,7 @@ $num_raggr++;
 $righe_tab_disp = "";
 for ($num1 = 0 ; $num1 < $num_raggr ; $num1++) {
 if ($app_ric_raggr[$num1]) {
-$righe_tab_disp .= "<tr><td style=\"text-align: right;\">$aper_font_tab_disp".$nome_raggr[$num1]."$chiu_font_tab_disp</td>";
+$righe_tab_disp .= "<tr><td class=\"t1left\" style=\"text-align: right;$sfondo\">$aper_font_tab_disp".$nome_raggr[$num1]."$chiu_font_tab_disp</td>";
 $max_app_liberi = explode(",",$app_ric_raggr[$num1]);
 $max_app_liberi = count($max_app_liberi);
 $app_ric_colonna = ",".$app_ric_raggr[$num1].",";
@@ -135,7 +143,7 @@ $righe_tab_disp .= "<td style=\"background-color: $color;\" colspan=\"$colspan_v
 if ($return_var) $tab_liberi[$nome_raggr[$num1]][$id_periodo] = $num_app_liberi;
 } # fine for $num2
 
-if ($colonna_destra_tab_disp != "NO") $righe_tab_disp .= "<td>$aper_font_tab_disp".$nome_raggr[$num1]."$chiu_font_tab_disp</td></tr>";
+if ($colonna_destra_tab_disp != "NO") $righe_tab_disp .= "<td$stile_sfondo>$aper_font_tab_disp".$nome_raggr[$num1]."$chiu_font_tab_disp</td></tr>";
 else $righe_tab_disp .= "</tr>";
 } # fine if ($app_ric_raggr[$num1])
 } # fine for $num1
@@ -156,19 +164,24 @@ else $giorno_vedi_ini_sett = 0;
 } # fine else if ($tipo_periodi == "s")
 $ultimo_mese = "";
 $num_col_mese = 0;
-$riga_mese = "<tr><td rowspan=\"2\">$aper_font_tab_disp&nbsp;$chiu_font_tab_disp</td>";
+$riga_mese = "<tr$stile_sfondo><td rowspan=\"2\">$aper_font_tab_disp&nbsp;$chiu_font_tab_disp</td>";
 $riga_giorni = "<tr>";
+$g_inizio_periodo = 1;
+$m_inizio_periodo = 1;
+$a_inizio_periodo = 1990;
 for ($num1 = 0 ; $num1 < ($num_colonne_tab_disp + 1) ; $num1++) {
 if ($allinea_disp != "SI" or $num1 != $num_colonne_tab_disp) {
 if ($num1 != $num_colonne_tab_disp) $id_periodo = $id_data_inizio_tab_disp + $num1;
 else $id_periodo = $id_data_inizio_tab_disp + $num1 - 1;
 $riga_periodo = esegui_query("select * from $tableperiodi where idperiodi = '$id_periodo'");
+if (numlin_query($riga_periodo)) {
 if ($num1 != $num_colonne_tab_disp) $inizio_periodo = risul_query($riga_periodo,0,'datainizio');
 else $inizio_periodo = risul_query($riga_periodo,0,'datafine');
 $inizio_periodo = explode("-",$inizio_periodo);
 $g_inizio_periodo = $inizio_periodo[2];
 $m_inizio_periodo = $inizio_periodo[1];
 $a_inizio_periodo = $inizio_periodo[0];
+} # fine if (numlin_query($riga_periodo))
 if ($num1 == $num_colonne_tab_disp) $ripeti_giorni = 1;
 for ($num2 = 0 ; $num2 < $ripeti_giorni ; $num2++) {
 $timestamp_periodo = mktime(0,0,0,$m_inizio_periodo,($g_inizio_periodo + $num2),$a_inizio_periodo);
@@ -193,7 +206,7 @@ $giorno_sett_corr = date("w",$timestamp_periodo);
 if ($giorno_sett_corr == $giorno_vedi_ini_sett) $bgcolor = "$c_inisett_tab_disp";
 } # fine ($tipo_periodi != "s")
 else if ($num2 == 0) $bgcolor = "$c_inisett_tab_disp";
-$riga_giorni .= "<td";
+$riga_giorni .= "<td class=\"t1top\"$stile_sfondo";
 if ($bgcolor) $riga_giorni .= " style=\"background-color: $bgcolor;\"";
 if (($num1 != 0 or $num2 != 0) and $num1 != $num_colonne_tab_disp) $riga_giorni .= " colspan=2";
 $riga_giorni .= ">$aper_font_tab_disp$g_mostra$chiu_font_tab_disp</td>";
@@ -204,7 +217,7 @@ $a_mostra = date("Y",mktime(0,0,0,$m_inizio_periodo,($g_inizio_periodo + $num2 -
 $riga_mese .= "<td colspan=\"$num_col_mese\">$aper_font_tab_disp";
 if ($num_col_mese > 6) $riga_mese .= $nome_mese[$ultimo_mese]."&nbsp;$a_mostra";
 else $riga_mese .= "&nbsp;";
-if ($colonna_destra_tab_disp != "NO") $riga_mese .= "$chiu_font_tab_disp</td><td rowspan=\"2\">$aper_font_tab_disp&nbsp;$chiu_font_tab_disp</td></tr>";
+if ($colonna_destra_tab_disp != "NO") $riga_mese .= "$chiu_font_tab_disp</td><td rowspan=\"2\"$stile_sfondo>$aper_font_tab_disp&nbsp;$chiu_font_tab_disp</td></tr>";
 else $riga_mese .= "$chiu_font_tab_disp</td></tr>";
 $riga_giorni .= "</tr>";
 
