@@ -67,8 +67,6 @@ case "Mostrare la caparra se presente?":  	$messaggio = "Show the deposit if pre
 case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":	$messaggio = "Show which days are full inside the periods where there is no more availability?"; break;
 case "Mostrare la form di richiesta prenotazione?":	$messaggio = "Show the request reservation form?"; break;
 case "Indirizzo email a cui inviare le richieste di prenotazione":	$messaggio = "Email address to which send the requests for reservation"; break;
-case "Mascherare la provenienza dell'email sull'envelope?":	$messaggio = "Masquerade sender on the email envelope?"; break;
-case "provare a cambiare se non si riescono a spedire le email":	$messaggio = "try to change this if you can't send the email"; break;
 case "Tag html di apertura per la formattazione delle font":	$messaggio = "Opening html tag for formatting fonts"; break;
 case "Tag html di chiusura per la formattazione delle font":	$messaggio = "Closing html tag for formatting fonts"; break;
 case "Tag html di apertura per la formattazione delle font rosse":	$messaggio = "Opening html tag for formatting red fonts"; break;
@@ -381,7 +379,6 @@ case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_show_alternativ
 case "var_mostra_caparra":  			$messaggio = "var_show_deposit"; break;
 case "var_mostra_richiesta_via_mail":  		$messaggio = "var_show_request_by_mail"; break;
 case "var_indirizzo_email":  			$messaggio = "var_email_address"; break;
-case "var_maschera_email":  			$messaggio = "var_masquerade_email_envelope"; break;
 case "var_mostra_giorni_pieni":  		$messaggio = "var_show_full_days"; break;
 case "var_mostra_bottone_paypal":  		$messaggio = "var_show_paypal_button"; break;
 case "var_nome_modello_paypal":  		$messaggio = "var_paypal_template_name"; break;
