@@ -274,7 +274,7 @@ case "opzionale":  				$messaggio = "optional"; break;
 case "Costi combinati":  			$messaggio = "Combined costs"; break;
 case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Fast insertion of a new extra cost for"; break;
 case "permanenza minima":  			$messaggio = "minimum stay"; break;
-case "numero di bambini":  			$messaggio = "number of children"; break;
+case "numero di neonati":  			$messaggio = "number of infants"; break;
 case "letto aggiuntivo":  			$messaggio = "extra bed"; break;
 case "offerta speciale":  			$messaggio = "special offer"; break;
 case "inserisci":  				$messaggio = "insert"; break;
@@ -282,10 +282,10 @@ case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; b
 case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
 case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
 case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
-case "Valore dello sconto per ogni bambino":  	$messaggio = "Discount value for each child"; break;
+case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
 case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
 case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
-case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "with this cost the number of children must be included in the number of people too"; break;
+case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
 case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
 case "Valore dello sconto":  			$messaggio = "Discount value"; break;
 case "del prezzo totale":  			$messaggio = "of total price"; break;
@@ -320,6 +320,7 @@ case "includi solo":  				$messaggio = "include only"; break;
 case "questi tipi":  				$messaggio = "these types"; break;
 case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
 case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
+case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
