@@ -67,6 +67,9 @@ case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale do
 case "Cancella":  				$messaggio = "Delete"; break;
 case "Ridimensiona":  				$messaggio = "Scale down"; break;
 case "Modifica la regola":  			$messaggio = "Modify rule"; break;
+case "chiusure":  				$messaggio = "closures"; break;
+case "numero di persone":  			$messaggio = "number of people"; break;
+case "utente inserimento":  			$messaggio = "inserting user"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
