@@ -266,6 +266,9 @@ case "cancella in modo permanente":  		$messaggio = "delete permanently"; break;
 case "in modo permanente":  			$messaggio = "permanently"; break;
 case "Prenotazione cancellata":  		$messaggio = "Deleted reservation"; break;
 case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "Data o orario stimato di entrata <span class=\"colred\">errato</span>":	$messaggio = "<span class=\"colred\">Wrong</span> estimated check-in time or date"; break;
+case "Data cancellazione":  			$messaggio = "Deletion date"; break;
+case "Cancellata dall'utente":  		$messaggio = "Deleted by user"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
