@@ -110,7 +110,7 @@ case "solo nelle ripetizioni dei costi aggiuntivi":	$messaggio = "only inside re
 case "solo nelle ripetizioni dei pagamenti":	$messaggio = "only inside repetitions of payments"; break;
 case "solo nelle ripetizioni delle unità":	$messaggio = "only inside repetitions of units"; break;
 case "Condizioni applicate":  			$messaggio = "Conditions applied"; break;
-case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "all other conditions won't be apllied anymore in these repetitions"; break;
+case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "all other conditions won't be applied anymore in these repetitions"; break;
 case "solo nelle ripetizioni dell'array":	$messaggio = "only inside repetitions of array"; break;
 case "prima di con valori negativi":  		$messaggio = "before with negative values"; break;
 case "prima di":  				$messaggio = "before"; break;
