@@ -441,6 +441,36 @@ case "La cartella":  				$messaggio = "The directory"; break;
 case "è un duplicato":  			$messaggio = "is a duplicate"; break;
 case "le seguenti pagine web verranno cancellate":	$messaggio = "the following web pages will be deleted"; break;
 case "le tipologie di persone rimosse erano presenti in alcuni costi aggiuntivi, questi costi vanno aggiornati manualmente se necessario":	$messaggio = "removed person types were present in some extra costs, eventually these costs must be updated manually"; break;
+case "Utilizzo dei cookies per la gestione delle sessioni attivato":	$messaggio = "Use of cookies for session handling enabled"; break;
+case "Utilizzo dei cookies per la gestione delle sessioni disattivato":	$messaggio = "Use of cookies for session handling disabled"; break;
+case "Percorso al file autoload.php di phpmailer":	$messaggio = "Path to autoload.php file for phpmailer"; break;
+case "per inviare email attraverso un server remoto":	$messaggio = "to send emails through a remote server"; break;
+case "Per inviare le email usare":  		$messaggio = "To send emails use"; break;
+case "il server locale":  			$messaggio = "the local server"; break;
+case "un server remoto":  			$messaggio = "a remote server"; break;
+case "Server di posta SMTP":  			$messaggio = "SMTP mail server"; break;
+case "Sicurezza connessione":  			$messaggio = "Connection security"; break;
+case "nessuna":  				$messaggio = "no one"; break;
+case "Il percorso al file autoload.php di phpmailer è stato cambiato":	$messaggio = "The path to autoload.php file for phpmailer has been changed"; break;
+case "Il file inserito <span class=\"colred\">non carica phpmailer</span> correttamente":	$messaggio = "The inserted file <span class=\"colred\">does not load phpmailer</span> correctly"; break;
+case "Il metodo per inviare le email è stato cambiato":	$messaggio = "The method to send emails has been changed"; break;
+case "Connessione fallita":  			$messaggio = "Falied connection"; break;
+case "EHLO fallito":  				$messaggio = "Failed EHLO"; break;
+case "Connessione cifrata STARTTLS fallita":  	$messaggio = "STARTTLS encrypted connection failed"; break;
+case "EHLO dopo STARTTLS fallito":  		$messaggio = "EHLO after STARTTLS failed"; break;
+case "Autenticazione fallita":  		$messaggio = "Failed authentication"; break;
+case "I dati per il collegamento al server SMTP sono <span class=\"colred\">sbagliati o incompleti</span>":	$messaggio = "The data to connect to the SMTP server are <span class=\"colred\">wrong or incomplete</span>"; break;
+case "I dati per il collegamento al server SMTP sono stati aggiornati":	$messaggio = "The data to connect to the SMTP server have been updated"; break;
+case "controllando SPF":  			$messaggio = "checking SPF"; break;
+case "Attualmente SPF è configurato correttamente sul dominio della email della struttura":	$messaggio = "Currently SPF is correctly configured on the domain of the property email"; break;
+case "Attualmente <span class=\"colred\">SPF non è configurato correttamente</span> sul dominio della email della struttura":	$messaggio = "Currently <span class=\"colred\">SPF is not configured correctly</span> on the domain of the property email"; break;
+case "Il mascheramento delle email verrà attivato solo se nel DNS del dominio dell'email del mittente c'è un record TXT per SPF contenente":	$messaggio = "Email masquerading will be activated only if in the DNS of the domain of the sender's email there is a TXT record for SPF containing"; break;
+case "Il dominio":  				$messaggio = "The domain"; break;
+case "non ha nessun record per SPF":  		$messaggio = "has no record for SPF"; break;
+case "nella gestione del suo DNS va aggiunto un record TXT contenente un testo come questo":	$messaggio = "in the management of your DNS you must add a TXT record containing a text like this"; break;
+case "Questo è il record SPF attuale del dominio":	$messaggio = "This is the current SPF record of the domain"; break;
+case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "this TXT record must be modified in the management of DNS of the domain"; break;
+case "sostituendolo con un testo come questo":	$messaggio = "replacing it with a text like this"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
