@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Prenota":  				$messaggio = "Reserve"; break;
 case "Inserisci una nuova prenotazione":  	$messaggio = "Insert a new reservation"; break;
 case "Cliente titolare":  			$messaggio = "Titular client"; break;
 case "cognome":  				$messaggio = "surname"; break;
@@ -99,6 +100,7 @@ case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
 case "per la prenotazione":  			$messaggio = "for reservation"; break;
 case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
 case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
+case "valuta":  				$messaggio = "currency"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
