@@ -67,8 +67,6 @@ case "Mostrare la caparra se presente?":  	$messaggio = "Enseñar la fianza si e
 case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":	$messaggio = "Enseñar cuáles son los días llenos al interior de los períodos en los que ya no hay disponibilidad?"; break;
 case "Mostrare la form di richiesta prenotazione?":	$messaggio = "Enseñar el formulario para pedir reservar?"; break;
 case "Indirizzo email a cui inviare le richieste di prenotazione":	$messaggio = "Dirección de correo electrónico a la que enviar el pedido de reserva"; break;
-case "Mascherare la provenienza dell'email sull'envelope?":	$messaggio = "Enmascarar la proveniencia del email en el envelope?"; break;
-case "provare a cambiare se non si riescono a spedire le email":	$messaggio = "intentar cambiarlo si no es posible enviar las emails"; break;
 case "Tag html di apertura per la formattazione delle font":	$messaggio = "Elemento html de apertura para dar formato a las letras"; break;
 case "Tag html di chiusura per la formattazione delle font":	$messaggio = "Elemento html de cierre para dar formato a las letras"; break;
 case "Tag html di apertura per la formattazione delle font rosse":	$messaggio = "Elemento html de apertura para dar formato a las letras rojas"; break;
@@ -381,7 +379,6 @@ case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_muestra_frase_a
 case "var_mostra_caparra":  			$messaggio = "var_muestra_fianza"; break;
 case "var_mostra_richiesta_via_mail":  		$messaggio = "var_muestra_pedido_por_mail"; break;
 case "var_indirizzo_email":  			$messaggio = "var_direccion_email"; break;
-case "var_maschera_email":  			$messaggio = "var_enmascara_email"; break;
 case "var_mostra_giorni_pieni":  		$messaggio = "var_muestra_dias_llenos"; break;
 case "var_mostra_bottone_paypal":  		$messaggio = "var_muestra_boton_paypal"; break;
 case "var_nome_modello_paypal":  		$messaggio = "var_nombre_modelo_paypal"; break;
