@@ -274,7 +274,7 @@ case "opzionale":  				$messaggio = "opcionál"; break;
 case "Costi combinati":  			$messaggio = "Costes combinados"; break;
 case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Inserción rápida de un nuevo coste añadido para"; break;
 case "permanenza minima":  			$messaggio = "estadía mínima"; break;
-case "numero di bambini":  			$messaggio = "número de niños"; break;
+case "numero di neonati":  			$messaggio = "número de bebés"; break;
 case "letto aggiuntivo":  			$messaggio = "cama extra"; break;
 case "offerta speciale":  			$messaggio = "oferta especial"; break;
 case "inserisci":  				$messaggio = "insertar"; break;
@@ -282,10 +282,10 @@ case "Inserisci il costo aggiuntivo":  		$messaggio = "Insertar el coste añadid
 case "Numero minimo di giorni":  		$messaggio = "Número mínimo de días"; break;
 case "Applicato alle tariffe":  		$messaggio = "Aplicar a las tarifas"; break;
 case "Periodi in cui viene applicato il costo":	$messaggio = "Períodos en los que se aplica el coste"; break;
-case "Valore dello sconto per ogni bambino":  	$messaggio = "Valor del descuento para cada niño"; break;
+case "Valore per ogni neonato":  		$messaggio = "Valor para cada bebé"; break;
 case "del prezzo di una persona":  		$messaggio = "del precio de una persona"; break;
 case "solo per tariffe con prezzi a persona":  	$messaggio = "solo para tarifas con precios por persona"; break;
-case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "con este coste hay que incluir el número de niños también en el número de personas"; break;
+case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "con este coste el número de bebés na está incluido en el número de personas"; break;
 case "Valore del letto aggiuntivo":  		$messaggio = "Valor de la cama extra"; break;
 case "Valore dello sconto":  			$messaggio = "Valor del descuento"; break;
 case "del prezzo totale":  			$messaggio = "del precio total"; break;
@@ -320,6 +320,7 @@ case "includi solo":  				$messaggio = "incluir solo"; break;
 case "questi tipi":  				$messaggio = "estos tipos"; break;
 case "Mostrare come tipo di persona":  		$messaggio = "Enseñar como tipo de persona"; break;
 case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Aplicar el porcentaje del tipo de persona al coste"; break;
+case "Neonati (0-23 mesi)":  				$messaggio = "Bebés (0-23 meses)"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
