@@ -266,6 +266,9 @@ case "cancella in modo permanente":  		$messaggio = "borrar permanentemente"; br
 case "in modo permanente":  			$messaggio = "permanentemente"; break;
 case "Prenotazione cancellata":  		$messaggio = "Reserva borrada"; break;
 case "Prenotazioni cancellate":  		$messaggio = "Reservas borradas"; break;
+case "Data o orario stimato di entrata <span class=\"colred\">errato</span>":	$messaggio = "Fecha o horario de entrada estimativo <span class=\"colred\">equivocado</span>"; break;
+case "Data cancellazione":  			$messaggio = "Fecha de cancelación"; break;
+case "Cancellata dall'utente":  		$messaggio = "Borrada por el usuario"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
