@@ -257,8 +257,8 @@ case "m":  					$messaggio = "m"; break;
 case "f":  					$messaggio = "f"; break;
 case "Titolo dei clienti eliminato":  		$messaggio = "Título de los clientes eliminado"; break;
 case "Nuovo titolo dei clienti aggiunto":  	$messaggio = "Nuevo título de los clientes añadido"; break;
-case "I dati della struttura sono stati cambiati":	$messaggio = "Los datos de la estructura han sido cambiados"; break;
-case "Dati della struttura":  			$messaggio = "Datos de la estructura"; break;
+case "I dati della struttura sono stati cambiati":	$messaggio = "Los datos de la propiedad han sido cambiados"; break;
+case "Dati della struttura":  			$messaggio = "Datos de la propiedad"; break;
 case "Nome":  					$messaggio = "Nombre"; break;
 case "Tipo":  					$messaggio = "Tipo"; break;
 case "Numero stelle":  				$messaggio = "Número estrellas"; break;
@@ -270,7 +270,7 @@ case "Telefono":  				$messaggio = "Teléfono"; break;
 case "Fax":  					$messaggio = "Fax"; break;
 case "Codice fiscale":  			$messaggio = "Número Identificación Fiscal"; break;
 case "Parita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
-case "Modifica i dati della struttura":  	$messaggio = "Modificar los datos de la estructura"; break;
+case "Modifica i dati della struttura":  	$messaggio = "Modificar los datos de la propiedad"; break;
 case "Clicca su un documento per modificarlo":	$messaggio = "Hacer clic sobre un documento para modificarlo"; break;
 case "Cambia l'ordine dei documenti":  		$messaggio = "Cambiar el orden de los documentos"; break;
 case "Applica i cambiamenti":  			$messaggio = "Aplicar los cambios"; break;
@@ -441,6 +441,36 @@ case "La cartella":  				$messaggio = "El directorio"; break;
 case "è un duplicato":  			$messaggio = "es un duplicado"; break;
 case "le seguenti pagine web verranno cancellate":	$messaggio = "las siguientes páginas web serán borradas"; break;
 case "le tipologie di persone rimosse erano presenti in alcuni costi aggiuntivi, questi costi vanno aggiornati manualmente se necessario":	$messaggio = "los tipos de personas eliminados estaban presentes en algunos costes añadidos, estos costes tendrán que ser actualizados manualmente si es necesario"; break;
+case "Utilizzo dei cookies per la gestione delle sessioni attivato":	$messaggio = "Uso de cookies para la gestión de sesiones activado"; break;
+case "Utilizzo dei cookies per la gestione delle sessioni disattivato":	$messaggio = "Uso de cookies para la gestión de sesiones desactivado"; break;
+case "Percorso al file autoload.php di phpmailer":	$messaggio = "Recorrido al archivo autoload.php de phpmailer"; break;
+case "per inviare email attraverso un server remoto":	$messaggio = "Para enviar correos electrónicos através de un servidor remoto"; break;
+case "Per inviare le email usare":  		$messaggio = "Para enviar correos electrónicos usar"; break;
+case "il server locale":  			$messaggio = "el servidor local"; break;
+case "un server remoto":  			$messaggio = "un servidor remoto"; break;
+case "Server di posta SMTP":  			$messaggio = "Servidor de correo SMTP"; break;
+case "Sicurezza connessione":  			$messaggio = "Seguridad de la conexión"; break;
+case "nessuna":  				$messaggio = "ninguna"; break;
+case "Il percorso al file autoload.php di phpmailer è stato cambiato":	$messaggio = "El recorrido al archivo autoload.php de phpmailer ha sido cambiado"; break;
+case "Il file inserito <span class=\"colred\">non carica phpmailer</span> correttamente":	$messaggio = "El archivo isertado <span class=\"colred\">no carga phpmailer</span> correctamente"; break;
+case "Il metodo per inviare le email è stato cambiato":	$messaggio = "El método para enviar correos electrónicos ha sido cambiado"; break;
+case "Connessione fallita":  			$messaggio = "Error de conexión"; break;
+case "EHLO fallito":  				$messaggio = "EHLO fallido"; break;
+case "Connessione cifrata STARTTLS fallita":  	$messaggio = "Conexión cifrada STARTTLS fallida"; break;
+case "EHLO dopo STARTTLS fallito":  		$messaggio = "EHLO después de STARTTLS fallido"; break;
+case "Autenticazione fallita":  		$messaggio = "Autenticación fallida "; break;
+case "I dati per il collegamento al server SMTP sono <span class=\"colred\">sbagliati o incompleti</span>":	$messaggio = "Los datos para la conexión al servidor SMTP están <span class=\"colred\">equivocados o incompletos</span>"; break;
+case "I dati per il collegamento al server SMTP sono stati aggiornati":	$messaggio = "Los datos para la conexión al servidor SMTP han sido actualizados"; break;
+case "controllando SPF":  			$messaggio = "controlando SPF"; break;
+case "Attualmente SPF è configurato correttamente sul dominio della email della struttura":	$messaggio = "Actualmente SPF está correctamente configurado en el dominio del correo electrónico de la propiedad"; break;
+case "Attualmente <span class=\"colred\">SPF non è configurato correttamente</span> sul dominio della email della struttura":	$messaggio = "Actualmente <span class=\"colred\">SPF no está configurado correctamente</span> en el dominio del correo electrónico de la propiedad"; break;
+case "Il mascheramento delle email verrà attivato solo se nel DNS del dominio dell'email del mittente c'è un record TXT per SPF contenente":	$messaggio = "El enmascaramiento de los correos electrónicos se activará solo si en el DNS del dominio del correo electrónico del remitente hay un registro TXT para SPF que contiene"; break;
+case "Il dominio":  				$messaggio = "El dominio"; break;
+case "non ha nessun record per SPF":  		$messaggio = "no tiene ningún record para SPF"; break;
+case "nella gestione del suo DNS va aggiunto un record TXT contenente un testo come questo":	$messaggio = "en la gestión de su DNS hay que añadir un record TXT que contenga un texto como este"; break;
+case "Questo è il record SPF attuale del dominio":	$messaggio = "Este es el record SPF actual del dominio"; break;
+case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "este record TXT debe ser modificado en la gestión del DNS del dominio"; break;
+case "sostituendolo con un testo come questo":	$messaggio = "reemplazándolo con un texto como este"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
