@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Prenota":  				$messaggio = "Reservar"; break;
 case "Inserisci una nuova prenotazione":  	$messaggio = "Insertar una nueva reserva"; break;
 case "Cliente titolare":  			$messaggio = "Cliente titular"; break;
 case "cognome":  				$messaggio = "apellido"; break;
@@ -99,6 +100,7 @@ case "costo aggiuntivo":  			$messaggio = "coste añadido"; break;
 case "per la prenotazione":  			$messaggio = "para la reserva"; break;
 case "per un promemoria all'entrata":  		$messaggio = "para un recordatorio a la entrada"; break;
 case "per un promemoria all'uscita":  		$messaggio = "para un recordatorio a la salida"; break;
+case "valuta":  				$messaggio = "divisa"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
