@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -118,11 +118,12 @@ if ($lista_comp) {
 $lista_comp = explode(",",substr($lista_comp,1));
 $num_lista_comp = count($lista_comp);
 for ($num1 = 0 ; $num1 < $num_lista_comp ; $num1++) {
-if (!$app_prenota_id[$lista_comp[$num1]]) {
+if (empty($app_prenota_id[$lista_comp[$num1]])) {
 $query_comp .= "idprenota = '".$lista_comp[$num1]."' or ";
-} # fine if (!$app_prenota_id[$lista_comp[$num1]])
+} # fine if (empty($app_prenota_id[$lista_comp[$num1]]))
 } # fine for $num1
 $query_comp = substr($query_comp,0,-3);
+$lista_comp = "";
 } # fine if ($lista_comp)
 if ($query_comp) $prenota_in_var = esegui_query("select idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone,idprenota_compagna,checkin,datainserimento from $tableprenota where $query_comp ");
 else break;
@@ -275,7 +276,7 @@ function aggiorna_tableprenota ($app_prenota_id,$app_orig_prenota_id,$nome_table
 $fatto = 1;
 if (@is_array($app_orig_prenota_id)) {
 reset($app_orig_prenota_id);
-foreach ($app_orig_prenota_id as $idprenota => $app_prenota) if (!strcmp($app_prenota_id[$idprenota],"")) $fatto = 0;
+foreach ($app_orig_prenota_id as $idprenota => $app_prenota) if (!strcmp((string) $app_prenota_id[$idprenota],"")) $fatto = 0;
 if ($fatto) {
 reset($app_orig_prenota_id);
 foreach ($app_orig_prenota_id as $idprenota => $app_prenota) {
@@ -433,12 +434,12 @@ if (!isset($limiti_var_orig['ini']) or $limiti_var['ini'] < $limiti_var_orig['in
 if (@is_array($app_orig_prenota_id)) {
 reset($app_orig_prenota_id);
 foreach ($app_orig_prenota_id as $idp => $app) {
-if (!strcmp($app_prenota_id[$idp],"")) {
+if (!strcmp(fixstr($app_prenota_id[$idp]),"")) {
 $app_prenota_id[$idp] = $app;
 for ($num1 = $inizio_prenota_id[$idp] ; $num1 <= $fine_prenota_id[$idp] ; $num1++) {
 $prenota_in_app_sett[$app][$num1] = $idp;
 } # fine for $num1
-} # fine if (!strcmp($app_prenota_id[$key2],""))
+} # fine if (!strcmp(fixstr($app_prenota_id[$idp]),""))
 } # fine foreach ($app_orig_prenota_id as $idp => $app)
 } # fine if (@is_array($app_orig_prenota_id))
 } # fine if (!isset($limiti_var_orig['ini']) or $limiti_var['ini'] < $limiti_var_orig['ini'] or...
@@ -578,10 +579,10 @@ $grp_vicini = explode(",",substr($dati_app['grp_vicini'][$num2],1,-1));
 for ($num3 = 0 ; $num3 < $dati_app['grp_vicini_num'][$num2] ; $num3++) {
 $prenotainperiodo = prenota_in_app_e_periodo($grp_vicini[$num3],$idinizio_corr,$idfine_corr,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 for ($num4 = 1 ; $num4 <= $num_pp ; $num4++) {
-if (!$app_assegnabili_id[$prenotainperiodo[$num4]]) {
+if (empty($app_assegnabili_id[$prenotainperiodo[$num4]])) {
 $num_vicini_disp--;
 break;
-} # fine if (!$app_assegnabili_id[$prenotainperiodo[$num4]])
+} # fine if (empty($app_assegnabili_id[$prenotainperiodo[$num4]]))
 elseif ($app_assegnabili_id[$prenotainperiodo[$num4]] != "v") {
 $vett_assegnabili = explode(",",$app_assegnabili_id[$prenotainperiodo[$num4]]);
 $num_assegnabili = count($vett_assegnabili);
@@ -763,7 +764,7 @@ if ($app_assegnabili_id[0][$idprenotainperiodo]) $prenota_comp_presente = "SI";
 $prenota_fissa_presente = "NO";
 for ($num4 = 1 ; $num4 <= $num_pp2 ; $num4++) {
 $idprenotainperiodo2 = $prenotainperiodo2[$num4];
-if (!$app_assegnabili_id[$idprenotainperiodo2]) $prenota_fissa_presente = "SI";
+if (empty($app_assegnabili_id[$idprenotainperiodo2])) $prenota_fissa_presente = "SI";
 else {
 # se $idprenotainperiodo è uguale o minore di $idprenotainperiodo2 e ne contiene gli app. assegnabili è inutile fare lo scambio
 if ($inizio_prenota_id[$idprenotainperiodo2] <= $inizio_prenota_id[$idprenotainperiodo] and $fine_prenota_id[$idprenotainperiodo2] >= $fine_prenota_id[$idprenotainperiodo]) {
@@ -1243,7 +1244,7 @@ if (!empty($riprova_senza_app_liberato) and ($limiti_var['t_limite'] + 20) >= ti
 $n_lista_app_ric = "";
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if ($numapp != $riprova_senza_app_liberato and $riprova_app[$numapp] != "NO") $n_lista_app_ric .= $numapp.",";
+if ($numapp != $riprova_senza_app_liberato and (!isset($riprova_app[$numapp]) or $riprova_app[$numapp] != "NO")) $n_lista_app_ric .= $numapp.",";
 } # fine for $num1
 $n_lista_app_ric = substr($n_lista_app_ric,0,-1);
 $app_richiesti_vett[$app_richiesti_vett['id']] = incrocia_app_richiesti($app_richiesti_vett[$app_richiesti_vett['id']],$n_lista_app_ric);
