@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@
 ##################################################################################
 
 
-function spezzaprenota ($idinizio,$idfine,$anno,&$limiti_var,$profondita,&$n_tronchi,&$vet_appartamenti,&$vett_idinizio,&$vett_idfine,$num_persone,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,&$dati_app,$nome_tab_prenota = "prenota") {
+function spezzaprenota ($idinizio,$idfine,$anno,&$limiti_var,$profondita,$app_richiesti,&$n_tronchi,&$vet_appartamenti,&$vett_idinizio,&$vett_idfine,$num_persone,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,&$dati_app,$nome_tab_prenota = "prenota") {
 global $debug;
 
 $limiti_var['n_ini'] = $idinizio;
@@ -50,7 +50,7 @@ if ($limiti_var['tutti_fissi'] != "SI" and $limiti_var['t_limite'] >= time()) {
 
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if ($dati_app['maxocc'][$numapp] >= $num_persone) {
+if ($dati_app['maxocc'][$numapp] >= $num_persone and (empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI"))) {
 $prima_prenota = prenota_in_app_e_periodo($numapp,$idinizio,$idinizio,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 if ($num_pp != 0) $idprima_prenota = $prima_prenota[1];
 else $idprima_prenota = "";
@@ -102,7 +102,7 @@ if ($debug == "on") {
 for ($i = 0 ; $i < $profondita['attuale'] ; $i++) echo "&nbsp;&nbsp;";
 echo "<b>".$profondita['attuale']."</b> <em>".date("H:i:s")."</em> spezza  da $id_settimana a $idfine<br>";
 } # fine if ($debug == "on")
-spezzaprenota($id_settimana,$idfine,$anno,$limiti_var,$nuova_profondita,$n_tronchi2,$vet_appartamenti2,$vett_idinizio2,$vett_idfine2,$num_persone,$app_prenota_id2,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett2,$dati_app,$nome_tab_prenota);
+spezzaprenota($id_settimana,$idfine,$anno,$limiti_var,$nuova_profondita,$app_richiesti,$n_tronchi2,$vet_appartamenti2,$vett_idinizio2,$vett_idfine2,$num_persone,$app_prenota_id2,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett2,$dati_app,$nome_tab_prenota);
 if ($debug == "on") {
 for ($i = 0 ; $i < $profondita['attuale'] ; $i++) echo "&nbsp;&nbsp;";
 echo "<b>".$profondita['attuale']."</b> finito <em>".date("H:i:s")."</em> spezza $fatto_libera $app_liber<br>";
@@ -136,7 +136,7 @@ $fine_prenota_id[$num2] = "";
 aggiorna_app_aggiunti($limiti_var,$limiti_var_orig,$app_orig_prenota_id,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett);
 
 } # fine if (!$idprima_prenota or !empty($app_assegnabili_id[$idprima_prenota]))
-} # fine if ($dati_app['maxocc'][$numapp] >= $num_persone)
+} # fine if ($dati_app['maxocc'][$numapp] >= $num_persone and (empty($app_richiesti) or...
 } # fine for $num1
 
 } # fine if ($limiti_var['tutti_fissi'] != "SI" and...
