@@ -110,7 +110,7 @@ if ($crea_modello) $funz_crea_modello($percorso_cartella_modello,$anno_modello,$
 $lang_dir = opendir("./includes/lang/");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != "..") {
-if ($template_file_name[$ini_lingua]) $nome_file = $template_file_name[$ini_lingua];
+if (!empty($template_file_name[$ini_lingua])) $nome_file = $template_file_name[$ini_lingua];
 else $nome_file = $ini_lingua."_".$template_file_name['en'];
 for ($num_cart = 0 ; $num_cart < $num_perc_cart_mod_vett ; $num_cart++) {
 $percorso_cartella_modello = $perc_cart_mod_vett[$num_cart];
