@@ -34,11 +34,11 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,valpersonalizza,idu
 
 
 # Prendo i dati dal file se già esistente
-if ($template_file_name[$lingua_modello]) $nome_file = $template_file_name[$lingua_modello];
+if (!empty($template_file_name[$lingua_modello])) $nome_file = $template_file_name[$lingua_modello];
 else {
 $nome_file = mext_cal($template_file_name['ita'],$pag,$lingua_modello);
 if ($nome_file == $template_file_name['en'] or $nome_file == $template_file_name['ita']) $nome_file = $lingua_modello."_".$template_file_name['en'];
-} # fine else if ($template_file_name[$lingua_modello])
+} # fine else if (!empty($template_file_name[$lingua_modello]))
 $modello_esistente = "NO";
 $lingua_mod_esist = $lingua_mex_1;
 unset($id_transazione);
@@ -53,7 +53,7 @@ $tabelle_lock = array($tableversioni,$tabletransazioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 list($usec, $sec) = explode(' ', microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
+mt_srand($sec + (int) ((float) $usec * 1000000.0));
 $val_casuale = mt_rand(100000,999999);
 $versione_transazione = prendi_numero_versione($tableversioni);
 $id_transazione = $adesso.$val_casuale.$versione_transazione;
@@ -72,20 +72,20 @@ $NO = mex2("NO",$pag,$lingua_mod_esist);
 echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form-data\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"id_transazione\" value=\"".htmlspecialchars(fixset($id_transazione))."\">
+<input type=\"hidden\" name=\"id_transazione\" value=\"".htmlspecialchars(fixstr($id_transazione))."\">
 <input type=\"hidden\" name=\"crea_modello\" value=\"SI\">
 <input type=\"hidden\" name=\"fonte_dati_conn\" value=\"$fonte_dati_conn\">
-<input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_TYPE))."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_NAME\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_NAME))."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_HOST\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_HOST))."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_PORT\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_PORT))."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_USER\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_USER))."\">
-<input type=\"hidden\" name=\"T_PHPR_DB_PASS\" value=\"".htmlspecialchars(fixset($T_PHPR_DB_PASS))."\">
-<input type=\"hidden\" name=\"T_PHPR_LOAD_EXT\" value=\"".htmlspecialchars(fixset($T_PHPR_LOAD_EXT))."\">
-<input type=\"hidden\" name=\"T_PHPR_TAB_PRE\" value=\"".htmlspecialchars(fixset($T_PHPR_TAB_PRE))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_TYPE\" value=\"".htmlspecialchars(fixstr($T_PHPR_DB_TYPE))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_NAME\" value=\"".htmlspecialchars(fixstr($T_PHPR_DB_NAME))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_HOST\" value=\"".htmlspecialchars(fixstr($T_PHPR_DB_HOST))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_PORT\" value=\"".htmlspecialchars(fixstr($T_PHPR_DB_PORT))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_USER\" value=\"".htmlspecialchars(fixstr($T_PHPR_DB_USER))."\">
+<input type=\"hidden\" name=\"T_PHPR_DB_PASS\" value=\"".htmlspecialchars(fixstr($T_PHPR_DB_PASS))."\">
+<input type=\"hidden\" name=\"T_PHPR_LOAD_EXT\" value=\"".htmlspecialchars(fixstr($T_PHPR_LOAD_EXT))."\">
+<input type=\"hidden\" name=\"T_PHPR_TAB_PRE\" value=\"".htmlspecialchars(fixstr($T_PHPR_TAB_PRE))."\">
 <input type=\"hidden\" name=\"anno_modello\" value=\"$anno_modello\">
 <input type=\"hidden\" name=\"lingua_modello\" value=\"$lingua_modello\">
-<input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars(fixset($perc_cart_mod_sel))."\">
+<input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars(fixstr($perc_cart_mod_sel))."\">
 <input type=\"hidden\" name=\"templ_data_dir\" value=\"$template_data_dir\">
 
 <div style=\"height: 4px;\"></div>
@@ -150,22 +150,26 @@ echo "".str_replace("?",":",mex("Mostrare il quadro indicativo della disponibili
 <option value=\"reg2\"$sel_REG2>".mex("Raggruppando gli appartamenti con la regola di assegnazione 2",'unit.php')."</option>
 <option value=\"pers\"$sel_PERS>".mex("Raggruppando gli appartamenti per numero di persone",'unit.php')."</option>
 </select><br><table><tr><td style=\"width: 25px;\"></td><td>";
-if (empty($stile_tabella_cal)) $stile_tabella_cal = htmlspecialchars("border=1 cellspacing=0 cellpadding=1  style=\"background-color: #dddddd; font-size:70%; text-align: center; margin-left: auto;  margin-right: auto;\"");
+if (empty($stile_tabella_cal)) $stile_tabella_cal = htmlspecialchars("border=1 cellspacing=0 cellpadding=1 style=\"font-size:70%; text-align: center; margin-left: auto;  margin-right: auto;\"");
 else $stile_tabella_cal = htmlspecialchars($stile_tabella_cal);
-if (empty($mostra_quadro_disponibilita) and empty($colore_inizio_settimana_quadro_disponibilita)) $colore_inizio_settimana_quadro_disponibilita = "#bbbbbb";
+if ($modello_esistente != "SI" and empty($colore_sfondo_quadro_disponibilita)) $colore_sfondo_quadro_disponibilita = "#dddddd";
+else $colore_sfondo_quadro_disponibilita = htmlspecialchars(fixstr($colore_sfondo_quadro_disponibilita));
+if ($modello_esistente != "SI" and empty($colore_inizio_settimana_quadro_disponibilita)) $colore_inizio_settimana_quadro_disponibilita = "#bbbbbb";
 else $colore_inizio_settimana_quadro_disponibilita = htmlspecialchars($colore_inizio_settimana_quadro_disponibilita);
-if (empty($mostra_quadro_disponibilita) and empty($colore_libero_quadro_disponibilita)) $colore_libero_quadro_disponibilita = "#0cc80c";
+if ($modello_esistente != "SI" and empty($colore_libero_quadro_disponibilita)) $colore_libero_quadro_disponibilita = "#0cc80c";
 else $colore_libero_quadro_disponibilita = htmlspecialchars($colore_libero_quadro_disponibilita);
-if (empty($mostra_quadro_disponibilita) and empty($colore_occupato_quadro_disponibilita)) $colore_occupato_quadro_disponibilita = "#f8011e";
+if ($modello_esistente != "SI" and empty($colore_occupato_quadro_disponibilita)) $colore_occupato_quadro_disponibilita = "#f8011e";
 else $colore_occupato_quadro_disponibilita = htmlspecialchars($colore_occupato_quadro_disponibilita);
-#if (empty($mostra_quadro_disponibilita) and empty($apertura_font_quadro_disponibilita)) $apertura_font_quadro_disponibilita = "<font size=&quot;-2&quot;>";
-if (empty($mostra_quadro_disponibilita) and empty($apertura_font_quadro_disponibilita)) $apertura_font_quadro_disponibilita = "";
-else $apertura_font_quadro_disponibilita = htmlspecialchars($apertura_font_quadro_disponibilita);
-#if (empty($mostra_quadro_disponibilita) and empty($chiusura_font_quadro_disponibilita)) $chiusura_font_quadro_disponibilita = "</font>";
-if (empty($mostra_quadro_disponibilita) and empty($chiusura_font_quadro_disponibilita)) $chiusura_font_quadro_disponibilita = "";
-else $chiusura_font_quadro_disponibilita = htmlspecialchars($chiusura_font_quadro_disponibilita);
+#if ($modello_esistente != "SI" and empty($apertura_font_quadro_disponibilita)) $apertura_font_quadro_disponibilita = "<font size=&quot;-2&quot;>";
+if ($modello_esistente != "SI" and empty($apertura_font_quadro_disponibilita)) $apertura_font_quadro_disponibilita = "";
+else $apertura_font_quadro_disponibilita = htmlspecialchars(fixstr($apertura_font_quadro_disponibilita));
+#if ($modello_esistente != "SI" and empty($chiusura_font_quadro_disponibilita)) $chiusura_font_quadro_disponibilita = "</font>";
+if ($modello_esistente != "SI" and empty($chiusura_font_quadro_disponibilita)) $chiusura_font_quadro_disponibilita = "";
+else $chiusura_font_quadro_disponibilita = htmlspecialchars(fixstr($chiusura_font_quadro_disponibilita));
 echo "".mext_cal("Stile tabella",$pag).":
  <input type=\"text\" name=\"stile_tabella_cal\" size=\"75\" value=\"$stile_tabella_cal\"><br>
+".mex("Colore di sfondo della tabella",$pag).":
+ <input type=\"text\" name=\"colore_sfondo_quadro_disponibilita\" value=\"$colore_sfondo_quadro_disponibilita\" size=\"10\"><br>
 ".mex("Colore del giorno di inizio settimana",$pag).":
  <input type=\"text\" name=\"colore_inizio_settimana_quadro_disponibilita\" value=\"$colore_inizio_settimana_quadro_disponibilita\" size=\"10\"><br>
 ".mex("Colore dei periodi liberi",$pag).":
@@ -350,10 +354,10 @@ $colori_tema = array();
 if ($tema_sel) $valori_tema = $template_theme_values[$tema_sel];
 $num_valori = count($valori_tema);
 for ($num1 = 1 ; $num1 <= $num_valori ; $num1++) {
-if (!isset(${"valore_tema_".$num1}) or !strcmp(${"valore_tema_".$num1},"")) ${"valore_tema_".$num1} = $valori_tema[$num1]['default'];
+if (!isset(${"valore_tema_".$num1}) or !strcmp((string) ${"valore_tema_".$num1},"")) ${"valore_tema_".$num1} = $valori_tema[$num1]['default'];
 $valore_sost = ${"valore_tema_".$num1};
-if (!strcmp($valore_sost,"")) $valore_sost = fixset($valori_tema[$num1]['null']);
-elseif (isset($valori_tema[$num1]['replace']) and strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
+if (!strcmp((string) $valore_sost,"")) $valore_sost = fixstr($valori_tema[$num1]['null']);
+elseif (isset($valori_tema[$num1]['replace']) and strcmp((string) $valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
 $template_theme_html_pre[$tema_sel] = str_replace("[theme_value_$num1]",$valore_sost,$template_theme_html_pre[$tema_sel]);
 $template_theme_html_post[$tema_sel] = str_replace("[theme_value_$num1]",$valore_sost,$template_theme_html_post[$tema_sel]);
 } # fine for $num1
@@ -419,7 +423,7 @@ agg_tema_sel();
 -->
 </script>
 
-<input type=\"hidden\" name=\"cambia_frasi\" value=\"".htmlspecialchars(fixset($cambia_frasi))."\">
+<input type=\"hidden\" name=\"cambia_frasi\" value=\"".htmlspecialchars(fixstr($cambia_frasi))."\">
 <input type=\"hidden\" name=\"modello_esistente\" value=\"$modello_esistente\">";
 if (!empty($cambia_frasi)) {
 echo "<br><table style=\"background-color: #000000; margin-left: auto; margin-right: auto;\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\">
