@@ -94,13 +94,14 @@ fwrite($file,"
 function formatta_input_var_x_file ($input_utente) {
 
 if (@get_magic_quotes_gpc()) $input_utente = stripslashes($input_utente);
-$input_utente = str_replace("\\\\","\\",$input_utente);
+$input_utente = str_replace("\\\\","\\",(string) $input_utente);
 $input_utente = str_replace("\\","\\\\",$input_utente);
 $input_utente = str_replace("\"","\\\"",$input_utente);
 $input_utente = str_replace("\\\\n","\\n",$input_utente);
 $input_utente = str_replace("<!-- END1 ","<!-- ED1 ",$input_utente);
 $input_utente = str_replace("<!-- START2:","<!-- ST2:",$input_utente);
 $input_utente = str_replace("<!-- END2:","<!-- ED2:",$input_utente);
+$input_utente = str_replace('{$','{\$',$input_utente);
 return $input_utente;
 
 } # fine function formatta_input_var_x_file
@@ -192,7 +193,7 @@ if ($altri_domini) {
 if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") $percorso_cartella_dominio = substr($percorso_cartella_modello,strlen(C_CARTELLA_CREA_MODELLI));
 else $percorso_cartella_dominio = $percorso_cartella_modello;
 if (substr($percorso_cartella_dominio,0,1) == "/") $percorso_cartella_dominio = substr($percorso_cartella_dominio,1);
-if (strcmp($percorso_cartella_dominio,"") and substr($percorso_cartella_dominio,-1) != "/") $percorso_cartella_dominio .= "/";
+if (strcmp((string) $percorso_cartella_dominio,"") and substr($percorso_cartella_dominio,-1) != "/") $percorso_cartella_dominio .= "/";
 if (substr($percorso_cartella_dominio,0,2) == "./") $percorso_cartella_dominio = substr($percorso_cartella_dominio,2);
 $lista_altri_domini = "";
 $num_altri_domini = count($altri_domini);
