@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -28,7 +28,11 @@ $titolo = "HotelDruid";
 $var_pag = array();
 $var_pag[0] = 'nuovo_mess';
 $var_pag[1] = 'mos_tut_dat';
-$n_var_pag = 1;
+$var_pag[2] = 'mese';
+$var_pag[3] = 'tipo_tabella';
+$var_pag[4] = 'torna_indietro';
+$var_pag[5] = 'logout';
+$n_var_pag = 6;
 
 include("./costanti.php");
 include("./includes/funzioni.php");
@@ -73,7 +77,7 @@ break;
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
 echo "<div style=\"text-align: center;\"><h3>".mex("Benvenuto a HOTELDRUID",$pag).".</h3><br><br>
-HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2021 Marco M. F. De Santis<br>
+HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2022 Marco M. F. De Santis<br>
 HotelDruid comes with ABSOLUTELY NO WARRANTY; <br>for details see the $file_copying.<br>
 This is free software, and you are welcome to redistribute it<br>
  under certain conditions; see the $file_copying for details.<br>
@@ -387,6 +391,7 @@ echo " <select name=\"mese\">
 echo "<div id=\"mm_sub2\"></div>";
 
 if ($priv_vedi_beni_inv == "n" and $priv_vedi_inv_mag == "n" and $priv_vedi_inv_app == "n") $priv_vedi_tab_inventario = "n";
+else $priv_vedi_tab_inventario = "s";
 if ($priv_vedi_tab_prenotazioni != "n" or $vedi_clienti != "NO" or $priv_vedi_tab_costi != "n" or $priv_vedi_tab_periodi != "n" or $priv_vedi_tab_regole != "n" or $priv_vedi_tab_appartamenti != "n" or $priv_vedi_tab_stat != "n" or $priv_vedi_tab_doc != "n" or $priv_vedi_tab_inventario != "n") {
 echo "<form id=\"vtab\" accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -666,7 +671,7 @@ $costo_tot_p = punti_in_num($costo_tot,$stile_soldi);
 $da_pagare = $costo_tot - $pagato;
 $da_pagare_p = punti_in_num($da_pagare,$stile_soldi);
 $confermato = risul_query($prenotazioni,$num1,'conferma');
-$confermato = substr($confermato,0,1);
+$confermato = substr((string) $confermato,0,1);
 $colore = "";
 if ($pagato < $costo_tot) {
 $colore = $colore_giallo; #giallo
@@ -696,11 +701,11 @@ $checkout = "";
 else $stima_checkin = "";
 $promemoria = "&nbsp;";
 $commento = risul_query($prenotazioni,$num1,'commento');
-if (strstr($commento,">")) {
+if (strstr((string) $commento,">")) {
 $commento = explode(">",$commento);
-if (!$checkin and strcmp($commento[1],"")) $promemoria = "<small><small>".$commento[1]."</small></small>";
-if ($checkin and !$checkout and strcmp($commento[2],"")) $promemoria = "<small><small>".$commento[2]."</small></small>";
-} # fine if (strstr($commento,">"))
+if (!$checkin and strcmp((string) $commento[1],"")) $promemoria = "<small><small>".$commento[1]."</small></small>";
+if ($checkin and !$checkout and strcmp((string) $commento[2],"")) $promemoria = "<small><small>".$commento[2]."</small></small>";
+} # fine if (strstr((string) $commento,">"))
 $data_inserimento = risul_query($prenotazioni,$num1,'datainserimento');
 $host_inserimento = risul_query($prenotazioni,$num1,'hostinserimento');
 
@@ -842,7 +847,7 @@ echo "<br>".mex("<span class=\"colred\">Avviso</span>: è consigliabile attender
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"creaanno.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"nuovo_mess\" value=\"".htmlspecialchars(fixset($nuovo_mess))."\">
+<input type=\"hidden\" name=\"nuovo_mess\" value=\"".htmlspecialchars(fixstr($nuovo_mess))."\">
 <input class=\"sbutton\" type=\"submit\" name=\"creaanno\" value=\"".mex("Crea l'anno",$pag)." $anno \">
  ".mex("con periodi",$pag).":<br>";
 unset($tipo_periodi_obbligati);
