@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -49,7 +49,8 @@ $var_pag[21] = 'aggiorna_disponibilita';
 $var_pag[22] = 'aggiorna_restrizioni';
 $var_pag[23] = 'aggiorna';
 $var_pag[24] = 'data_agg';
-$n_var_pag = 25;
+$var_pag[25] = 'commenti_prenota';
+$n_var_pag = 26;
 if (@is_array($_POST)) {
 reset($_POST);
 for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
@@ -66,6 +67,7 @@ include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 include("./includes/funzioni_backup.php");
+include("./includes/funzioni_email.php");
 $numconnessione = connetti_db_per_backup($PHPR_DB_TYPE,$PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT,$PHPR_TAB_PRE,$ext_pgsql_caricata,$ext_mysql_caricata);
 if (!isset($anno)) {
 if (isset($_GET['anno'])) $anno = $_GET['anno'];
@@ -115,12 +117,7 @@ include(C_DATI_PATH."/lingua.php");
 $lingua_mex = $lingua[1];
 if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "") {
 $id_utente_sessione = "-1";
-$adesso = $anno.date("mdHis",(time() + (C_DIFF_ORE * 3600)));
-$versione_unica = prendi_numero_versione($tableversioni);
-list($usec, $sec) = explode(' ', microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
-$val_casuale = mt_rand(100000,999999);
-$id_sessione = $adesso.$val_casuale.$versione_unica;
+$id_sessione = crea_id_sessione($anno,$tableversioni);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
@@ -268,6 +265,59 @@ return $errore;
 } # fine function scarica_backup_subordinazione
 
 
+function variabili_x_form (&$lista_tutti_app,&$maxocc,&$lista_regola2,&$lista_regola4,&$origini_prenota,&$campi_pers_comm,$tableappartamenti,$tableregole,$tablepersonalizza) {
+
+$lista_tutti_app = "";
+$maxocc = array();
+$appartamenti = esegui_query("select * from $tableappartamenti order by idappartamenti");
+$num_appartamenti = numlin_query($appartamenti);
+for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
+$idapp = risul_query($appartamenti,$num1,'idappartamenti');
+$maxocc[$idapp] = risul_query($appartamenti,$num1,'maxoccupanti');
+$lista_tutti_app .= "$idapp,";
+} # fine for $num1
+$lista_tutti_app = substr($lista_tutti_app,0,-1);
+
+$lista_regola2 = array();
+$regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
+$num_regole2 = numlin_query($regole2);
+for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
+$tariffa = risul_query($regole2,$num1,'tariffa_per_app');
+$lista_app = risul_query($regole2,$num1,'motivazione');
+if (strcmp((string) $lista_app,"")) {
+$lista_regola2[$tariffa] = explode(",",$lista_app);
+$lista_regola2[$tariffa]['num'] = count($lista_regola2[$tariffa]);
+} # fine if (strcmp((string) $lista_app,""))
+else $lista_regola2[$tariffa]['num'] = 0;
+$lista_regola2[$tariffa]['txt'] = $lista_app;
+$lista_app2 = risul_query($regole2,$num1,'motivazione2');
+$lista_regola2[$tariffa]['txt2'] = $lista_app;
+if ($lista_app and $lista_app2) $lista_regola2[$tariffa]['txt2'] .= ",$lista_app2";
+$lista_regola2[$tariffa]['napp'] = risul_query($regole2,$num1,'motivazione3');
+if (substr(fixstr($lista_regola2[$tariffa]['napp']),0,1) == "v") {
+$lista_regola2[$tariffa]['vapp'] = 1;
+$lista_regola2[$tariffa]['napp'] = substr($lista_regola2[$tariffa]['napp'],1);
+} # fine if (substr($lista_regola2[$tariffa]['napp'],0,1) == "v")
+} # fine for $num1
+
+$lista_regola4 = array();
+$regole4 = esegui_query("select * from $tableregole where tariffa_per_persone != '' order by tariffa_per_persone");
+$num_regole4 = numlin_query($regole4);
+for ($num1 = 0 ; $num1 < $num_regole4 ; $num1++) {
+$tariffa = risul_query($regole4,$num1,'tariffa_per_persone');
+$lista_regola4[$tariffa] = risul_query($regole4,$num1,'iddatainizio');
+} # fine for $num1
+
+$origini_prenota = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'origini_prenota' and idutente = '1' ");
+$origini_prenota = (string) risul_query($origini_prenota,0,"valpersonalizza");
+
+$campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '1' ");
+if (numlin_query($campi_pers_comm) == 1) $campi_pers_comm = $campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
+else $campi_pers_comm = array();
+
+} # fine function variabili_x_form
+
+
 
 if ((isset($azione_ic) and $azione_ic == "SI") or $id_utente_azione_ic) {
 $mostra_form_iniziale = "NO";
@@ -357,6 +407,7 @@ esegui_query("insert into $tableinterconnessioni (tipoid,nome_ic,idremoto1) valu
 $limite = date("YmdHis",mktime(date("H"),date("i"),(date("s") + (C_DIFF_ORE * 3600)),date("m"),(date("d") - 2),date("Y")));
 if ($ultimo_aggiornamento_tariffe < $limite) {
 $agg_tariffe_da_remoto = 1;
+variabili_x_form($lista_tutti_app,$maxocc,$lista_regola2,$lista_regola4,$origini_prenota,$campi_pers_comm,$tableappartamenti,$tableregole,$tablepersonalizza);
 include("./includes/interconnect/$mod_ext/form.php");
 $ultimo_aggiornamento_tariffe = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("update $tableinterconnessioni set idremoto1 = '$ultimo_aggiornamento_tariffe' where tipoid = 'u_agg_tar' and nome_ic = '$interconnection_name' ");
@@ -414,47 +465,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./inizio.php\"><di
 
 if ($priv_crea_interconnessioni == "s") {
 
-
-$lista_tutti_app = "";
-$maxocc = array();
-$appartamenti = esegui_query("select * from $tableappartamenti order by idappartamenti");
-$num_appartamenti = numlin_query($appartamenti);
-for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
-$idapp = risul_query($appartamenti,$num1,'idappartamenti');
-$maxocc[$idapp] = risul_query($appartamenti,$num1,'maxoccupanti');
-$lista_tutti_app .= "$idapp,";
-} # fine for $num1
-$lista_tutti_app = substr($lista_tutti_app,0,-1);
-
-$lista_regola2 = array();
-$regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
-$num_regole2 = numlin_query($regole2);
-for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
-$tariffa = risul_query($regole2,$num1,'tariffa_per_app');
-$lista_app = risul_query($regole2,$num1,'motivazione');
-if (strcmp($lista_app,"")) {
-$lista_regola2[$tariffa] = explode(",",$lista_app);
-$lista_regola2[$tariffa]['num'] = count($lista_regola2[$tariffa]);
-} # fine if (strcmp($lista_app,""))
-else $lista_regola2[$tariffa]['num'] = 0;
-$lista_regola2[$tariffa]['txt'] = $lista_app;
-$lista_app2 = risul_query($regole2,$num1,'motivazione2');
-$lista_regola2[$tariffa]['txt2'] = $lista_app;
-if ($lista_app and $lista_app2) $lista_regola2[$tariffa]['txt2'] .= ",$lista_app2";
-$lista_regola2[$tariffa]['napp'] = risul_query($regole2,$num1,'motivazione3');
-if (substr($lista_regola2[$tariffa]['napp'],0,1) == "v") {
-$lista_regola2[$tariffa]['vapp'] = 1;
-$lista_regola2[$tariffa]['napp'] = substr($lista_regola2[$tariffa]['napp'],1);
-} # fine if (substr($lista_regola2[$tariffa]['napp'],0,1) == "v")
-} # fine for $num1
-
-$lista_regola4 = array();
-$regole4 = esegui_query("select * from $tableregole where tariffa_per_persone != '' order by tariffa_per_persone");
-$num_regole4 = numlin_query($regole4);
-for ($num1 = 0 ; $num1 < $num_regole4 ; $num1++) {
-$tariffa = risul_query($regole4,$num1,'tariffa_per_persone');
-$lista_regola4[$tariffa] = risul_query($regole4,$num1,'iddatainizio');
-} # fine for $num1
+variabili_x_form($lista_tutti_app,$maxocc,$lista_regola2,$lista_regola4,$origini_prenota,$campi_pers_comm,$tableappartamenti,$tableregole,$tablepersonalizza);
 
 
 
@@ -619,13 +630,13 @@ echo "<option value=\"$idutenti\"$sel>$nome_utente</option>";
 } # fine for $num1
 echo "</select>
 <input class=\"sbutton\" type=\"submit\" value=\"".mex("Modifica",$pag)."\">";
-if ($nome_utente_agg) {
+if (!empty($nome_utente_agg)) {
 $url_corr = "http://";
 if ($_SERVER['HTTPS']) $url_corr = "https://";
 $url_corr .= $_SERVER['HTTP_HOST'].$_SERVER['SCRIPT_NAME'];
 echo "<br><div class=\"separ\" style=\"height: 3px;\"></div>
 <small>(URL: ".$url_corr."?user=$nome_utente_agg&amp;password=XXXXXX)</small>";
-} # fine if ($nome_utente_agg)
+} # fine if (!empty($nome_utente_agg))
 echo "</div></form><hr style=\"width: 95%\">";
 
 if (@is_file(C_DATI_PATH."/dati_subordinazione.php")) {
@@ -674,7 +685,7 @@ ksort($interconnessioni);
 reset($interconnessioni);
 foreach ($interconnessioni as $mod_ext => $val_i) {
 include("./includes/interconnect/$mod_ext/name.php");
-if ($interconnection_name_show[$lingua_mex]) $titolo = $interconnection_name_show[$lingua_mex];
+if (!empty($interconnection_name_show[$lingua_mex])) $titolo = $interconnection_name_show[$lingua_mex];
 else $titolo = $interconnection_name_show['en'];
 echo "<hr style=\"width: 95%\"><div id=\"h$interconnection_data_dir\" style=\"text-align: center;\"><b>$titolo</b></div><br>";
 $agg_tariffe_da_remoto = 0;
@@ -696,11 +707,11 @@ if (fixset($template_name_show['tpl_type']) == "interconnection") {
 if (!function_exists('mex2')) {
 $perc_cart_mod_sel = "";
 include("./includes/templates/funzioni_modelli.php");
-$percorso_cartella_modello = $perc_cart_mod_vett[0];
+#$percorso_cartella_modello = $perc_cart_mod_vett[0];
 $anno_modello = $anno;
 $lingua_modello = $lingua_mex;
 } # fine if (!function_exists('mex2'))
-if ($template_name_show[$lingua_mex]) $titolo = $template_name_show[$lingua_mex];
+if (!empty($template_name_show[$lingua_mex])) $titolo = $template_name_show[$lingua_mex];
 else {
 $messaggio = "";
 if (@is_file("./includes/lang/$lingua_mex/modt_$modello_ext.php")) {
