@@ -291,9 +291,9 @@ if (!empty($manda_form_tab)) {
 
 if (!empty($aggiungi_bene)) {
 if ($priv_ins_beni != "n") {
-if (!strcmp($n_quantita_min_predef,"")) $n_quantita_min_predef = 0;
+if (!strcmp((string) $n_quantita_min_predef,"")) $n_quantita_min_predef = 0;
 if (controlla_num_pos($n_quantita_min_predef) == "SI") {
-if (!strcmp($n_quantita,"")) $n_quantita = $n_quantita_min_predef;
+if (!strcmp((string) $n_quantita,"")) $n_quantita = $n_quantita_min_predef;
 if (controlla_num_pos($n_quantita) == "SI") {
 $n_id = aggslashdb($n_id);
 if ($ric_checkin != "s" or $tipoid != "idappartamento" or $priv_mod_checkin != "s") $ric_checkin = "n";
@@ -382,7 +382,7 @@ $frase_modifica .= "".mex("Nuovo bene",$pag)." \"<em>$nome_bene</em>\" ".mex("ag
 
 if ($crea_ca) {
 $prezzo_costo_agg = formatta_soldi($prezzo_costo_agg);
-if (strcmp($prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI") {
+if (strcmp((string) $prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI") {
 if (@get_magic_quotes_gpc()) $nome_costo_agg = stripslashes($nome_costo_agg);
 $costiagg_esist = esegui_query("select * from $tablenometariffe where nomecostoagg = '".aggslashdb($nome_costo_agg)."' and idntariffe > 10 ");
 if (!numlin_query($costiagg_esist)) {
@@ -416,7 +416,7 @@ $frase_modifica .= "<form accept-charset=\"utf-8\" method=\"post\" action=\"modi
 </div></form>";
 } # fine if (!numlin_query($costiagg_esist))
 else $frase_modifica .= "<span class=\"colred\">".mex("Costo aggiuntivo non inserito",$pag)."</span>: ".mex("costo già esistente",$pag).".<br>";
-} # fine if (strcmp($prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI")
+} # fine if (strcmp((string) $prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI")
 else $frase_modifica .= "<span class=\"colred\">".mex("Costo aggiuntivo non inserito",$pag)."</span>: ".mex("prezzo sbagliato",$pag).".<br>";
 } # fine if ($crea_ca)
 } # fine else if ($crea_ca and !$continua)
@@ -446,7 +446,7 @@ for ($num1 = 0 ; $num1 < $num_beni_in_mag ; $num1++) {
 $id_bene_in_mag = risul_query($beni_in_mag,$num1,'idbeneinventario',$tablerelinventario);
 if ($bene_permesso[$id_bene_in_mag]) {
 $n_quant = aggslashdb(${"n_quantita".$id_bene_in_mag});
-if (strcmp($n_quant,"") and controlla_num_pos($n_quant) == "SI") {
+if (strcmp((string) $n_quant,"") and controlla_num_pos($n_quant) == "SI") {
 $quantita = risul_query($beni_in_mag,$num1,'quantita',$tablerelinventario);
 if ($tipo_nuova_quantita == "piu") $n_quant = $quantita + $n_quant;
 if ($tipo_nuova_quantita == "meno") $n_quant = $quantita - $n_quant;
@@ -459,7 +459,7 @@ if ($diff < 0) $diff = "- ".substr($diff,1);
 else $diff = "+ $diff";
 $frasi_quantita .= "<b>$nome_bene</b>: $quantita $diff = $n_quant<br>";
 } # fine if ($quantita != $n_quant)
-} # fine if (strcmp($n_quant,"") and controlla_num_pos($n_quant) == "SI")
+} # fine if (strcmp((string) $n_quant,"") and controlla_num_pos($n_quant) == "SI")
 } # fine if ($bene_permesso[$id_bene_in_mag])
 } # fine for $num1
 unlock_tabelle($tabelle_lock);
@@ -733,7 +733,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventari
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixset($origine_vecchia))."\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars($tipo_tabella)."\">
 <input type=\"hidden\" name=\"idmag\" value=\"".htmlspecialchars($idmag_orig)."\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
