@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -36,7 +36,8 @@ $var_pag[8] = 'scarica_mess';
 $var_pag[9] = 'mese';
 $var_pag[10] = 'tipo_tabella';
 $var_pag[11] = 'torna_indietro';
-$n_var_pag = 12;
+$var_pag[12] = 'pagina_messaggi';
+$n_var_pag = 13;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -200,8 +201,7 @@ unlock_tabelle($tabelle_lock);
 } # fine if (!empty($spedisci_messaggio))
 
 function cancella_messaggi_vecchi ($tableprivilegi,$tablemessaggi) {
-unset($utente_attivo);
-$utente_attivo[1] = "SI";
+$utente_attivo = array(1 => "SI");
 $priv_vedi_mess = esegui_query("select idutente,priv_messaggi from $tableprivilegi where anno = '1'");
 $num_priv_vedi_mess = numlin_query($priv_vedi_mess);
 for ($num1 = 0 ; $num1 < $num_priv_vedi_mess ; $num1++) {
@@ -216,7 +216,7 @@ $idutenti = risul_query($messaggi,$num1,'idutenti');
 $idutenti = explode(",",$idutenti);
 $num_idutenti = count($idutenti);
 for ($num2 = 1 ; $num2 < ($num_idutenti - 1) ; $num2++) {
-if ($utente_attivo[$idutenti[$num2]] == "SI") $utente_attivo_trovato = "SI";
+if (isset($utente_attivo[$idutenti[$num2]]) and $utente_attivo[$idutenti[$num2]] == "SI") $utente_attivo_trovato = "SI";
 } # fine for $num2
 if ($utente_attivo_trovato == "NO") {
 $idmessaggi = risul_query($messaggi,$num1,'idmessaggi');
@@ -262,7 +262,7 @@ unlock_tabelle($tabelle_lock);
 if (isset($elimina_tutti_mess) and $elimina_tutti_mess == "SI") {
 if ($prima_dopo != "prima") $prima_dopo = "dopo";
 $mostra_form_iniziale = "NO";
-if ($continua != "SI") {
+if (!isset($continua) or $continua != "SI") {
 if (!preg_match("/-[0-9]{2}-[0-9]{2}/",$data_arrivo)) $data_arrivo = "";
 if ($anno_arrivo != $anno_corrente and $anno_arrivo != ($anno_corrente - 1)) $anno_arrivo = "";
 if ($data_arrivo and $anno_arrivo) $data_arrivo = $anno_arrivo.$data_arrivo;
@@ -285,7 +285,7 @@ echo " <b>".formatta_data($data_arrivo,$stile_data)."</b>";
 echo "?
 <button class=\"canc\" type=\"submit\"><div>".mex("SI",$pag)."</div></button>
 </div></form><br><br>";
-} # fine if ($continua != "SI")
+} # fine if (!isset($continua) or $continua != "SI")
 else {
 if (!preg_match("/[0-9]{4}-[0-9]{2}-[0-9]{2}/",$data_arrivo)) $data_arrivo = "";
 if (substr($data_arrivo,0,4) != $anno_corrente and substr($data_arrivo,0,4) != ($anno_corrente - 1)) $data_arrivo = "";
@@ -311,7 +311,7 @@ esegui_query("update $tablemessaggi set idutenti = '".str_replace(",$id_utente,"
 cancella_messaggi_vecchi($tableprivilegi,$tablemessaggi);
 unlock_tabelle($tabelle_lock);
 echo mex("Messaggi eliminati",$pag).".<br>";
-} # fine else if ($continua != "SI")
+} # fine else if (!isset($continua) or $continua != "SI")
 } # fine if (isset($elimina_tutti_mess) and $elimina_tutti_mess == "SI")
 
 
@@ -382,13 +382,13 @@ $oggetto = utf8_encode(imap_qprint($info_mess[$num1]->subject));
 $inserisci_mess = 0;
 for ($num2 = 0 ; $num2 < $num_trova_email_tm ; $num2++) {
 if (!$mittente_email_tm[$num2] or stristr($mittente,$mittente_email_tm[$num2])) {
-if (!strcmp($oggetto_email_tm[$num2],"") or stristr($oggetto,$oggetto_email_tm[$num2])) {
+if (!strcmp((string) $oggetto_email_tm[$num2],"") or stristr($oggetto,$oggetto_email_tm[$num2])) {
 if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and !$riferimento and substr($oggetto,0,4) != "Re: " and substr($oggetto,0,3) != "R: ")) {
 $inserisci_mess = 1;
 $mess_scaricati++;
 break;
 } # fine if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and...
-} # fine if (!strcmp($oggetto_email_tm[$num2],"") or stristr($oggetto,$oggetto_email_tm[$num2]))
+} # fine if (!strcmp((string) $oggetto_email_tm[$num2],"") or stristr($oggetto,$oggetto_email_tm[$num2]))
 } # fine if (!$mittente_email_tm[$num2] or stristr($mittente,$mittente_email_tm[$num2]))
 } # fine for $num2
 
@@ -697,12 +697,12 @@ $option_select_utenti .= "<option value=\"$idutenti\">".$nome_utente[$idutenti].
 } # fine for $num1
 
 $nomi_contratti = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '$id_utente'");
-$nomi_contratti = risul_query($nomi_contratti,0,'valpersonalizza');
+$nomi_contratti = (string) risul_query($nomi_contratti,0,'valpersonalizza');
 $nomi_contratti = explode("#@&",$nomi_contratti);
 $num_nomi_contratti = count($nomi_contratti);
 for ($num1 = 0 ; $num1 < $num_nomi_contratti ; $num1++) {
 $dati_nome_contratto = explode("#?&",$nomi_contratti[$num1]);
-$nome_contratto[$dati_nome_contratto[0]] = $dati_nome_contratto[1];
+$nome_contratto[$dati_nome_contratto[0]] = fixset($dati_nome_contratto[1]);
 } # fine for $num1
 $max_contr = esegui_query("select max(numero) from $tablecontratti where tipo $LIKE 'contr%'");
 $max_contr = risul_query($max_contr,0,0);
@@ -780,7 +780,10 @@ $stilebarrato = " style=\"text-decoration: line-through\"";
 $pcanc = "&amp;pcanc=1";
 } # fine if (numlin_query($dati_prenota))
 } # fine if (!numlin_query($dati_prenota))
-if (numlin_query($dati_prenota) != 1) $link_modifica = "NO";
+if (numlin_query($dati_prenota) != 1) {
+$link_modifica = "NO";
+$utente_ins_prenota = "";
+} # fine if (numlin_query($dati_prenota) != 1)
 else {
 $utente_ins_prenota = risul_query($dati_prenota,0,'utente_inserimento');
 $id_data_ini_prenota = risul_query($dati_prenota,0,'iddatainizio');
@@ -788,7 +791,7 @@ $data_ins_prenota = risul_query($dati_prenota,0,'datainserimento');
 } # fine else if (numlin_query($dati_prenota) != 1)
 if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "p" and $utente_ins_prenota != $id_utente) $link_modifica = "NO";
-if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_ins_prenota]) $link_modifica = "NO";
+if ($priv_mod_prenotazioni == "g" and empty($utenti_gruppi[$utente_ins_prenota])) $link_modifica = "NO";
 if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_data_ini_prenota) $link_modifica = "NO";
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
@@ -801,8 +804,8 @@ $link_modifica_fine = "</a>";
 #$checkbox_modifica = "<input type=\"checkbox\" name=\"cambia$numero\" value=\"SI\">";
 } # fine if ($link_modifica == "SI")
 else {
-unset($link_modifica_inizio);
-unset($link_modifica_fine);
+$link_modifica_inizio = "";
+$link_modifica_fine = "";
 #$checkbox_modifica = "&nbsp;";
 } # fine else if ($link_modifica == "SI")
 if ($num2 != 0) $tasto_prenota .= ", ";
@@ -864,27 +867,27 @@ unset($nummoltiplica_ca);
 unset($catpers_ca);
 $cat_numpers = array();
 $num_periodi = array();
-$stato_prenota = risul_query($messaggi,$num1,'dati_messaggio1');
-$num_tipologie = risul_query($messaggi,$num1,'dati_messaggio3');
-$inizioperiodo_dt = explode(",",risul_query($messaggi,$num1,'dati_messaggio4'));
-$fineperiodo_dt = explode(",",risul_query($messaggi,$num1,'dati_messaggio5'));
-$numero_tariffa_dt = explode(",",risul_query($messaggi,$num1,'dati_messaggio6'));
-$numpersone_dt = explode(",",risul_query($messaggi,$num1,'dati_messaggio7'));
-$num_app_tipo_richiesti_dt = explode(",",risul_query($messaggi,$num1,'dati_messaggio8'));
-$numcostiagg_dt = explode(",",risul_query($messaggi,$num1,'dati_messaggio9'));
-$idcostoagg_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio10'));
-$costoagg_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio11'));
-$numsettimane_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio12'));
-$nummoltiplica_ca_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio13'));
-$id_periodi_costo_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio14'));
-$catpers_ca_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio21'));
-$dati_calcolati_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio16'));
-$anno_prenota_dt = risul_query($messaggi,$num1,'dati_messaggio18');
-$origine_prenota_dt = explode(">",risul_query($messaggi,$num1,'dati_messaggio19'));
-$prenota_vicine_dt = $origine_prenota_dt[1];
+$stato_prenota = (string) risul_query($messaggi,$num1,'dati_messaggio1');
+$num_tipologie = (string) risul_query($messaggi,$num1,'dati_messaggio3');
+$inizioperiodo_dt = explode(",",(string) risul_query($messaggi,$num1,'dati_messaggio4'));
+$fineperiodo_dt = explode(",",(string) risul_query($messaggi,$num1,'dati_messaggio5'));
+$numero_tariffa_dt = explode(",",(string) risul_query($messaggi,$num1,'dati_messaggio6'));
+$numpersone_dt = explode(",",(string) risul_query($messaggi,$num1,'dati_messaggio7'));
+$num_app_tipo_richiesti_dt = explode(",",(string) risul_query($messaggi,$num1,'dati_messaggio8'));
+$numcostiagg_dt = explode(",",(string) risul_query($messaggi,$num1,'dati_messaggio9'));
+$idcostoagg_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio10'));
+$costoagg_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio11'));
+$numsettimane_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio12'));
+$nummoltiplica_ca_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio13'));
+$id_periodi_costo_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio14'));
+$catpers_ca_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio21'));
+$dati_calcolati_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio16'));
+$anno_prenota_dt = (string) risul_query($messaggi,$num1,'dati_messaggio18');
+$origine_prenota_dt = explode(">",(string) risul_query($messaggi,$num1,'dati_messaggio19'));
+$prenota_vicine_dt = fixset($origine_prenota_dt[1]);
 $origine_prenota_dt = $origine_prenota_dt[0];
-$aggiunta_testo_dt = risul_query($messaggi,$num1,'dati_messaggio20');
-$cat_numpers_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio22'));
+$aggiunta_testo_dt = (string) risul_query($messaggi,$num1,'dati_messaggio20');
+$cat_numpers_dt = explode(";",(string) risul_query($messaggi,$num1,'dati_messaggio22'));
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $inizioperiodo[$n_t] = aggslashdb($inizioperiodo_dt[($n_t - 1)]);
 $idinizioperiodo[$n_t] = esegui_query("select idperiodi from $tableperiodi where datainizio = '".$inizioperiodo[$n_t]."'");
@@ -905,8 +908,8 @@ $num_app_tipo_richiesti[$n_t] = $num_app_tipo_richiesti_dt[($n_t - 1)];
 $dati_calcolati = explode(":",$dati_calcolati_dt[($n_t - 1)]);
 $dati_calcolati_0 = explode(",",$dati_calcolati[0]);
 $costo_tariffa[$n_t] = (double) $dati_calcolati_0[0];
-$caparra[$n_t] = $dati_calcolati_0[1];
-$letti_agg[$n_t] = $dati_calcolati_0[2];
+$caparra[$n_t] = fixset($dati_calcolati_0[1]);
+$letti_agg[$n_t] = fixset($dati_calcolati_0[2]);
 $num_ca_calc[$n_t] = (count($dati_calcolati) - 1);
 for ($num2 = 1 ; $num2 < $num_ca_calc[$n_t] ; $num2++) {
 $dati_calcolati_ca = explode(",",$dati_calcolati[$num2]);
@@ -931,7 +934,7 @@ $catpers_ca[$n_t][$idcostoagg_dt2[($numca - 1)]] = $catpers_ca_dt2[($numca - 1)]
 } # fine for $numca
 $cat_numpers[$n_t] = explode(",",$cat_numpers_dt[($n_t - 1)]);
 } # fine for $n_t
-$dati_richiedente_dt = explode("<d>",risul_query($messaggi,$num1,'dati_messaggio15'));
+$dati_richiedente_dt = explode("<d>",(string) risul_query($messaggi,$num1,'dati_messaggio15'));
 $cognome_richiedente = $dati_richiedente_dt[0];
 $nome_richiedente = $dati_richiedente_dt[1];
 $email_richiedente = $dati_richiedente_dt[2];
@@ -945,7 +948,7 @@ $citta = $dati_richiedente_dt[8];
 $via = $dati_richiedente_dt[9];
 $numcivico = $dati_richiedente_dt[10];
 $cap = $dati_richiedente_dt[11];
-$lingua_cli = $dati_richiedente_dt[19];
+$lingua_cli = fixset($dati_richiedente_dt[19]);
 $telefono = $dati_richiedente_dt[12];
 $telefono2 = $dati_richiedente_dt[13];
 $telefono3 = $dati_richiedente_dt[14];
@@ -958,16 +961,16 @@ $min_stima_checkin = substr($oracheckin,14,2);
 $oracheckin = $oracheckin.":00";
 } # fine if ($oracheckin)
 $metodo_pagamento = $dati_richiedente_dt[17];
-$commento = $dati_richiedente_dt[20];
-$commenti_pers = explode(">",$dati_richiedente_dt[21]);
+$commento = fixset($dati_richiedente_dt[20]);
+$commenti_pers = explode(">",fixset($dati_richiedente_dt[21]));
 $num_commenti_pers = count($commenti_pers);
 if ($num_commenti_pers < 1) $num_commenti_pers = 1;
-$campi_pers_clienti = $dati_richiedente_dt[22];
-$codfiscale = $dati_richiedente_dt[23];
-$partitaiva = $dati_richiedente_dt[24];
-$valuta_pagamento = $dati_richiedente_dt[25];
-$cambio_pagamento = $dati_richiedente_dt[26];
-$arrotond_pagamento = $dati_richiedente_dt[27];
+$campi_pers_clienti = fixset($dati_richiedente_dt[22]);
+$codfiscale = fixset($dati_richiedente_dt[23]);
+$partitaiva = fixset($dati_richiedente_dt[24]);
+$valuta_pagamento = fixset($dati_richiedente_dt[25]);
+$cambio_pagamento = fixset($dati_richiedente_dt[26]);
+$arrotond_pagamento = fixset($dati_richiedente_dt[27]);
 
 if ($stato_prenota == "da_inserire") {
 if ($priv_ins_nuove_prenota == "s" and $inizioperiodo[1]) {
