@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -52,7 +52,16 @@ $var_pag[24] = 'cambia_estenstione_pers';
 $var_pag[25] = 'cambia_nome_file';
 $var_pag[26] = 'tipo_nome_file';
 $var_pag[27] = 'nome_file_salva';
-$n_var_pag = 28;
+$var_pag[28] = 'multi_lingua';
+$var_pag[29] = 'email_bcc';
+$var_pag[30] = 'cambia_bcc';
+$var_pag[31] = 'nuovo_oggetto';
+$var_pag[32] = 'cambia_oggetto';
+$var_pag[33] = 'cambia_compress';
+$var_pag[34] = 'MAX_FILE_SIZE';
+$var_pag[35] = 'upload_allegato';
+$var_pag[36] = 'elimina_allegato';
+$n_var_pag = 37;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -258,7 +267,7 @@ if (!$fileaperto) echo mex("Non ho i permessi di scrittura sulla cartella","pers
 else {
 fclose($fileaperto);
 unlink("$dir_salva/prova.tmp");
-if ($salva_contr == "SI") {
+if (isset($salva_contr) and $salva_contr == "SI") {
 if ($nuova_dir_salva == $dir_salva_home) $nuova_dir_salva = "~";
 $dir_esistente = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
 if (numlin_query($dir_esistente) >= 1) esegui_query("update $tablecontratti set testo = '$nuova_dir_salva' where numero = '$num_contratto' and tipo = 'dir'");
@@ -267,12 +276,12 @@ esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_cont
 esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','compress','gz')");
 } # fine else if (numlin_query($dir_esistente) >= 1)
 echo "".mex("I documenti verranno salvati nella cartella",$pag)." $dir_salva.<br>";
-} # fine if ($salva_contr == "SI")
+} # fine if (isset($salva_contr) and $salva_contr == "SI")
 else {
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and (tipo = 'dir' or tipo = 'num_prog' or tipo = 'nomefile' or tipo = 'compress' or tipo = 'autosalv' or tipo = 'incr_np') ");
 esegui_query("delete from $tablecontratti where testo = '$num_contratto_int' and tipo = 'num_prog' ");
 echo "".mex("I documenti non verranno salvati",$pag).".<br>";
-} # fine else if ($salva_contr == "SI")
+} # fine else if (isset($salva_contr) and $salva_contr == "SI")
 } # fine else if (!$fileaperto)
 } # fine else if (!@is_dir($nuova_dir_salva))
 } # fine if ($dir_salva)
@@ -285,18 +294,18 @@ $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
 if (numlin_query($dir_esistente)) {
-if (!$compress) {
+if (empty($compress)) {
 $mostra_form_iniziale = "NO";
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'compress' ");
 echo "".mex("Il documento non verrà salvato compresso su disco",$pag).".<br>";
-} # fine if (!$compress)
+} # fine if (empty($compress))
 else {
 $mostra_form_iniziale = "NO";
 $compress_esistente = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'compress' ");
 if (numlin_query($compress_esistente)) esegui_query("update $tablecontratti set testo = 'gz' where numero = '$num_contratto' and tipo = 'compress' ");
 else esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','compress','gz') ");
 echo "".mex("Il documento verrà salvato compresso su disco",$pag).".<br>";
-} # fine else if (!$compress)
+} # fine else if (empty($compress))
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
 } # fine if (!empty($cambia_compress))
@@ -352,11 +361,11 @@ $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $dir_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
 if (numlin_query($dir_esistente)) {
-if (!strcmp($contr_num_prog,"")) {
+if (!strcmp((string) $contr_num_prog,"")) {
 $mostra_form_iniziale = "NO";
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'num_prog' ");
 echo ucfirst(mex("il documento",$pag))." $num_contratto ".mex("non condividerà il numero progressivo con nessun documento",$pag).".<br>";
-} # fine if (!strcmp($contr_num_prog,""))
+} # fine if (!strcmp((string) $contr_num_prog,""))
 else {
 if ($contr_num_prog >= 1 and controlla_num_pos($contr_num_prog) != "NO") {
 if ($contr_num_prog != $num_contratto_int and ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$contr_num_prog] == "SI")) {
@@ -376,7 +385,7 @@ echo ucfirst(mex("il documento",$pag))." $num_contratto ".mex("condividerà il n
 } # fine if (numlin_query($dir_esistente))
 } # fine if ($contr_num_prog != $num_contratto_int and...
 } # fine if ($contr_num_prog >= 1 and controlla_num_pos($contr_num_prog) != "NO")
-} # fine else if (!strcmp($contr_num_prog,""))
+} # fine else if (!strcmp((string) $contr_num_prog,""))
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
 } # fine if (!empty($cambia_num_prog))
@@ -392,20 +401,20 @@ esegui_query("delete from $tablecontratti where numero = '$num_contratto' and ti
 echo "".mex("I file verranno salvati con il nome del documento",$pag).".<br>";
 } # fine if ($tipo_nome_file != "pers")
 else {
-if (strcmp($nome_file_salva,"") and strlen($nome_file_salva) < 121) {
+if (strcmp((string) $nome_file_salva,"") and strlen($nome_file_salva) < 121) {
 $mostra_form_iniziale = "NO";
 $nome_file_salva = htmlspecialchars($nome_file_salva);
 $nomefile_esistente = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'nomefile' ");
 if (numlin_query($nomefile_esistente)) esegui_query("update $tablecontratti set testo = '".aggslashdb($nome_file_salva)."' where numero = '$num_contratto' and tipo = 'nomefile' ");
 else esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','nomefile','".aggslashdb($nome_file_salva)."') ");
 echo "".mex("I file verranno salvati con il nome",$pag)." \"$nome_file_salva\".<br>";
-} # fine if (strcmp($nome_file_salva,"") and strlen($nome_file_salva) < 121)
+} # fine if (strcmp((string) $nome_file_salva,"") and strlen($nome_file_salva) < 121)
 } # fine else if ($tipo_nome_file != "pers")
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
 } # fine if (!empty($cambia_nome_file))
 
-if ($priv_mod_doc_api == "s" and (!empty($cambia_cons_api) or (isset($pass_api) and strcmp($pass_api,"")) or !empty($id_utente_api))) {
+if ($priv_mod_doc_api == "s" and (!empty($cambia_cons_api) or (isset($pass_api) and strcmp((string) $pass_api,"")) or !empty($id_utente_api))) {
 $tabelle_lock = array($tablecontratti);
 $altre_tab_lock = array($tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
@@ -413,19 +422,19 @@ $tipo_contratto = esegui_query("select tipo from $tablecontratti where numero =
 $tipo_contratto = risul_query($tipo_contratto,0,'tipo');
 if ($tipo_contratto == "contrrtf" or $tipo_contratto == "contrhtm" or $tipo_contratto == "contrtxt") {
 $api_esistente = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'api' ");
-if (strcmp($pass_api,"") or $id_utente_api) {
+if (strcmp(fixstr($pass_api),"") or !empty($id_utente_api)) {
 if (numlin_query($api_esistente)) {
 $pass_api_esist = risul_query($api_esistente,0,'testo');
 $id_utente_api_esist = explode(";",$pass_api_esist);
 $id_utente_api_esist = $id_utente_api_esist[0];
 $pass_api_esist = substr($pass_api_esist,(strlen($id_utente_api_esist) + 1));
-if (strcmp($pass_api,"")) {
+if (strcmp((string) $pass_api,"")) {
 $mostra_form_iniziale = "NO";
 if (@get_magic_quotes_gpc()) $pass_api = stripslashes($pass_api);
 $pass_api = aggslashdb($pass_api);
 esegui_query("update $tablecontratti set testo = '$id_utente_api_esist;$pass_api' where numero = '$num_contratto' and tipo = 'api' ");
 echo mex("La password per la API del documento è stata cambiata",$pag).".<br>";
-} # fine if (strcmp($pass_api,""))
+} # fine if (strcmp((string) $pass_api,""))
 if ($id_utente_api and ($id_utente == 1 or $id_utente_api == $id_utente)) {
 $utente_esistente = esegui_query("select nome_utente from $tableutenti where idutenti = '".aggslashdb($id_utente_api)."' ");
 if (numlin_query($utente_esistente)) {
@@ -435,27 +444,30 @@ echo mex("L'utente per la API del documento è stato cambiato",$pag).".<br>";
 } # fine if (numlin_query($utente_esistente))
 } # fine if ($id_utente_api and ($id_utente == 1 or $id_utente_api == $id_utente))
 } # fine if (numlin_query($api_esistente))
-} # fine if (strcmp($pass_api,"") or $id_utente_api)
+} # fine if (strcmp(fixstr($pass_api),"") or !empty($id_utente_api))
 else {
-if ($cons_api == "SI") {
+if (isset($cons_api) and $cons_api == "SI") {
 if (!numlin_query($api_esistente)) {
 $mostra_form_iniziale = "NO";
 $valori = "23456789ABCDEFGHJKLMNPQRSTUVWXZabcdefghijkmnpqrstuvwxyz";
+$pass_generata = "";
+if (function_exists('random_int')) for ($num1 = 0 ; $num1 < 8 ; $num1++) $pass_generata .= substr($valori,random_int(0,54),1);
+else {
 srand((double)microtime() * 1000000);
-unset($pass_generata);
 for ($num1 = 0 ; $num1 < 8 ; $num1++) $pass_generata .= substr($valori,rand(0,54),1);
+} # fine else if (function_exists('random_int'))
 esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','api','1;$pass_generata')");
-echo "".mex("Il documento verrà considerato come una API",$pag)." $dir_salva.<br>";
+echo "".mex("Il documento verrà considerato come una API",$pag).".<br>";
 } # fine if (!numlin_query($api_esistente))
-} # fine if ($cons_api == "SI")
+} # fine if (isset($cons_api) and $cons_api == "SI")
 else {
 if (numlin_query($api_esistente)) {
 $mostra_form_iniziale = "NO";
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'api' ");
 echo mex("Il documento non verrà più considerato come una API",$pag).".<br>";
 } # fine if (numlin_query($api_esistente))
-} # fine else if ($cons_api == "SI")
-} # fine else if (strcmp($pass_api,"") or $id_utente_api)
+} # fine else if (isset($cons_api) and $cons_api == "SI")
+} # fine else if (strcmp(fixstr($pass_api),"") or !empty($id_utente_api))
 } # fine if ($tipo_contratto == "contrrtf" or..
 unlock_tabelle($tabelle_lock);
 } # fine if ($priv_mod_doc_api == "s" and (!empty($cambia_cons_api) or (isset($pass_api) and...
@@ -521,20 +533,20 @@ unlock_tabelle($tabelle_lock);
 if (!empty($upload_allegato)) {
 $errore = "NO";
 $file_tmp = C_DATI_PATH."/allegato_contr$num_contratto.tmp";
-if (!$file_allegato_upload) {
-if ($HTTP_POST_FILES['file_allegato_upload']['tmp_name']) {
+if (empty($file_allegato_upload)) {
+if (!empty($HTTP_POST_FILES['file_allegato_upload']['tmp_name'])) {
 $file_allegato_upload = $HTTP_POST_FILES['file_allegato_upload']['tmp_name'];
 $file_allegato_upload_name = $HTTP_POST_FILES['file_allegato_upload']['name'];
 $file_allegato_upload_type = $HTTP_POST_FILES['file_allegato_upload']['type'];
-} # fine if ($HTTP_POST_FILES['file_allegato_upload']['tmp_name'])
+} # fine if (!empty($HTTP_POST_FILES['file_allegato_upload']['tmp_name']))
 else {
-if ($_FILES['file_allegato_upload']['tmp_name']) {
+if (!empty($_FILES['file_allegato_upload']['tmp_name'])) {
 $file_allegato_upload = $_FILES['file_allegato_upload']['tmp_name'];
 $file_allegato_upload_name = $_FILES['file_allegato_upload']['name'];
 $file_allegato_upload_type = $_FILES['file_allegato_upload']['type'];
-} # fine if ($_FILES['file_allegato_upload']['tmp_name'])
-} # fine else if ($HTTP_POST_FILES['file_allegato_upload']['tmp_name'])
-} # fine if (!$file_allegato_upload)
+} # fine if (!empty($_FILES['file_allegato_upload']['tmp_name']))
+} # fine else if (!empty($HTTP_POST_FILES['file_allegato_upload']['tmp_name']))
+} # fine if (empty($file_allegato_upload))
 if (!move_uploaded_file($file_allegato_upload,$file_tmp)) $errore = "SI";
 if ($errore == "NO") {
 if (!defined("C_MASSIMO_NUM_BYTE_UPLOAD") or C_MASSIMO_NUM_BYTE_UPLOAD == 0 or filesize($file_tmp) <= C_MASSIMO_NUM_BYTE_UPLOAD) {
@@ -609,7 +621,7 @@ if ($tipo_contratto == "contreml") {
 $mostra_form_iniziale = "NO";
 $opz_eml = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'opzeml'");
 $opz_eml = explode(";",risul_query($opz_eml,0,'testo'));
-if ($cambia_formato_email) {
+if (!empty($cambia_formato_email)) {
 if ($formato_email == "html") {
 $n_opz = "html;";
 if ($opz_eml[0] != "html") {
@@ -621,15 +633,15 @@ else $n_opz = ";";
 $n_opz .= $opz_eml[1].";".$opz_eml[2];
 esegui_query("update $tablecontratti set testo = '$n_opz' where numero = '$num_contratto' and tipo = 'opzeml' ");
 echo "".mex("Formato dell'email cambiato",$pag).".<br>";
-} # fine if ($cambia_formato_email)
-if ($cambia_bcc) {
+} # fine if (!empty($cambia_formato_email))
+if (!empty($cambia_bcc)) {
 $n_opz = $opz_eml[0].";";
-if ($bcc_mittente == "SI") $n_opz .= "SI";
+if (isset($bcc_mittente) and $bcc_mittente == "SI") $n_opz .= "SI";
 $n_opz .= ";";
-if ($bcc_indirizzo and preg_match('/^[_\.0-9a-z-]+@([0-9a-z][0-9a-z-]+\.)+[a-z]{2,4}$/i',$email_bcc)) $n_opz .= "$email_bcc";
+if (!empty($bcc_indirizzo) and preg_match('/^[_\.0-9a-z-]+@([0-9a-z][0-9a-z-]+\.)+[a-z]{2,4}$/i',$email_bcc)) $n_opz .= "$email_bcc";
 esegui_query("update $tablecontratti set testo = '$n_opz' where numero = '$num_contratto' and tipo = 'opzeml' ");
 echo "".mex("Copie bcc da spedire cambiate",$pag).".<br>";
-} # fine if ($cambia_bcc)
+} # fine if (!empty($cambia_bcc))
 } # fine if ($tipo_contratto == "contreml")
 unlock_tabelle($tabelle_lock);
 } # fine if (!empty($cambia_formato_email) or !empty($cambia_bcc))
@@ -669,7 +681,7 @@ $tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $vecchio_contr = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
 if (numlin_query($vecchio_contr)) {
-$vecchio_contr = risul_query($vecchio_contr,0,'testo');
+$vecchio_contr = (string) risul_query($vecchio_contr,0,'testo');
 if (substr($vecchio_contr,0,7) == "#!mln!#") {
 $multilingua = 1;
 if ($lingua_contr != "ita" and (preg_replace("/[a-z]{2,3}/","",$lingua_contr) != "" or !@is_file("./includes/lang/$lingua_contr/l_n"))) $errore = "SI";
@@ -684,7 +696,7 @@ $contr_controlla_int = preg_replace("/\\[r4 array=\"[A-Za-z]+[A-Za-z0-9_]*\"\\]/
 $contr_controlla = explode("[",$contr_controlla_int);
 $num_contr_controlla = count($contr_controlla);
 $livello = 0;
-unset($tipo_livello);
+$tipo_livello = array(0 => null);
 if (str_replace("[r]","",$contr_controlla_int) == $contr_controlla_int) $tipo_livello[0] = "r";
 for ($num1 = 1 ; $num1 < $num_contr_controlla ; $num1++) {
 $parte = $contr_controlla[$num1];
@@ -706,7 +718,7 @@ if ($apertura) {
 if ($apertura == "r" and $livello != 0 and ($livello != 1 or ($tipo_livello[1] != "r4" and $tipo_livello[1] != "r6") or $tipo_livello[0] == "r")) $errore = "SI";
 if (($apertura == "r2" or $apertura == "r3" or $apertura == "r5") and $tipo_livello[$livello] != "r") $errore = "SI";
 if (($apertura == "r4" or $apertura == "r6") and $tipo_livello[$livello] != "r" and $livello != 0 and ($livello != 1 or ($tipo_livello[1] != "r4" and $tipo_livello[1] != "r6") or $tipo_livello[0] == "r")) $errore = "SI";
-if ($apertura == "r6" and $tipo_livello[1] == "r6") $errore = "SI";
+if ($apertura == "r6" and isset($tipo_livello[1]) and $tipo_livello[1] == "r6") $errore = "SI";
 $livello++;
 $tipo_livello[$livello] = $apertura;
 } # fine ($apertura)
@@ -744,23 +756,23 @@ unlock_tabelle($tabelle_lock);
 } # fine if (!empty($salva_modifiche))
 
 if (!empty($aggiungi_var) or !empty($aggiungi_var2)) {
-if ($aggiungi_var2) $var_agg = $var_agg2;
+if (!empty($aggiungi_var2)) $var_agg = $var_agg2;
 if ($var_agg and preg_replace("/[A-Za-z0-9\(\)_]/","",$var_agg) == "") {
 if (@get_magic_quotes_gpc()) $n_contratto = stripslashes($n_contratto);
-if (!strcmp($pos_curs,"")) $testo_contratto_mod = $n_contratto."[".$var_agg."]";
+if (!strcmp((string) $pos_curs,"")) $testo_contratto_mod = $n_contratto."[".$var_agg."]";
 else {
 
 $pos_curs = strlen(utf8_encode(substr(utf8_decode($n_contratto),0,$pos_curs)));
 $pos_curs += (2 * substr_count(substr($n_contratto,0,$pos_curs),"€"));
 $pos_curs += (2 * substr_count(substr($n_contratto,0,$pos_curs),"–"));
 $testo_contratto_mod = substr($n_contratto,0,$pos_curs)."[".$var_agg."]".substr($n_contratto,$pos_curs);
-} # fine else if (!strcmp($pos_curs,""))
+} # fine else if (!strcmp((string) $pos_curs,""))
 } # fine if ($var_agg and preg_replace("/[A-Za-z0-9\(\)_]/","",$var_agg) == "")
 } # fine if (!empty($aggiungi_var) or !empty($aggiungi_var2))
 
 if (!empty($aggiungi_ripetizione) or !empty($aggiungi_ripetizione2)) {
 if (@get_magic_quotes_gpc()) $n_contratto = stripslashes($n_contratto);
-if ($aggiungi_ripetizione2) $tipo_rip = $tipo_rip2;
+if (!empty($aggiungi_ripetizione2)) $tipo_rip = $tipo_rip2;
 $testo_agg1 = "";
 $testo_agg2 = "";
 $testo_agg3 = "";
@@ -804,15 +816,15 @@ $testo_agg1 = "[c ".mex("nome_variabile",$pag)."=\"".mex("valore",$pag)."\"]";
 $testo_agg2 = "\n".mex("SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE",$pag)." (".mex("nome_variabile",$pag)." = ".mex("OPPURE",$pag)." != ".mex("valore",$pag).")\n";
 $testo_agg3 = "[/c]";
 } # fine if ($tipo_rip == 8)
-if (!strcmp($pos_curs,"")) $testo_contratto_mod = $n_contratto.$testo_agg1.$testo_agg2.$testo_agg3;
+if (!strcmp((string) $pos_curs,"")) $testo_contratto_mod = $n_contratto.$testo_agg1.$testo_agg2.$testo_agg3;
 else {
 $pos_curs = strlen(utf8_encode(substr(utf8_decode($n_contratto),0,$pos_curs)));
-if (!strcmp($pos_fine_sel,"")) $testo_contratto_mod = substr($n_contratto,0,$pos_curs).$testo_agg1.$testo_agg2.$testo_agg3.substr($n_contratto,$pos_curs);
+if (!strcmp((string) $pos_fine_sel,"")) $testo_contratto_mod = substr($n_contratto,0,$pos_curs).$testo_agg1.$testo_agg2.$testo_agg3.substr($n_contratto,$pos_curs);
 else {
 $pos_fine_sel = strlen(utf8_encode(substr(utf8_decode($n_contratto),0,$pos_fine_sel)));
 $testo_contratto_mod = substr($n_contratto,0,$pos_curs).$testo_agg1.substr($n_contratto,$pos_curs,($pos_fine_sel - $pos_curs)).$testo_agg3.substr($n_contratto,$pos_fine_sel);
-} # fine else if (!strcmp($pos_fine_sel,""))
-} # fine else if (!strcmp($pos_curs,""))
+} # fine else if (!strcmp((string) $pos_fine_sel,""))
+} # fine else if (!strcmp((string) $pos_curs,""))
 } # fine if (!empty($aggiungi_ripetizione) or !empty($aggiungi_ripetizione2))
 
 if (!empty($salva_foot)) {
@@ -830,14 +842,14 @@ unlock_tabelle($tabelle_lock);
 } # fine if (!empty($salva_foot))
 
 
-if ($mostra_form_iniziale == "NO") {
+if (isset($mostra_form_iniziale) and $mostra_form_iniziale == "NO") {
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag$anchor\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
 <input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
 </div></form>";
-} # fine if ($mostra_form_iniziale == "NO")
+} # fine if (isset($mostra_form_iniziale) and $mostra_form_iniziale == "NO")
 
 } # fine if (!empty($cambia_qualcosa))
 
@@ -849,7 +861,7 @@ if (!isset($mostra_form_iniziale) or $mostra_form_iniziale != "NO") {
 
 include("./includes/funzioni_contratti.php");
 $nomi_contratti = trova_nomi_contratti($max_contr,$id_utente,$tablecontratti,$tablepersonalizza,$LIKE,$pag);
-if (!isset($nomi_contratti['pers'][$num_contratto_int]) or !strcmp($nomi_contratti['pers'][$num_contratto_int],"")) $nome_contratto = "";
+if (!isset($nomi_contratti['pers'][$num_contratto_int]) or !strcmp((string) $nomi_contratti['pers'][$num_contratto_int],"")) $nome_contratto = "";
 else $nome_contratto = " (".$nomi_contratti['pers'][$num_contratto_int].")";
 
 unset($trad_var);
@@ -877,7 +889,7 @@ if ($max_contr > 1) {
 echo "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"./personalizza.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"id_utente_mod\" value=\"".htmlspecialchars(fixset($id_utente_mod))."\">
+<input type=\"hidden\" name=\"id_utente_mod\" value=\"".htmlspecialchars(fixstr($id_utente_mod))."\">
 <input type=\"hidden\" name=\"aggiorna_qualcosa\" value=\"SI\">
 <input type=\"hidden\" name=\"elimina_contratto\" value=\"SI\">
 <input type=\"hidden\" name=\"num_contr_elimina\" value=\"$num_contratto_int\">
@@ -888,7 +900,7 @@ echo "<td><form accept-charset=\"utf-8\" method=\"post\" action=\"./personalizza
 echo "</tr></table><br>";
 
 $tipo_contratto = substr(risul_query($dati_contratto,0,'tipo'),5);
-$testo_contratto = risul_query($dati_contratto,0,'testo');
+$testo_contratto = (string) risul_query($dati_contratto,0,'testo');
 $sel_HTML = "";
 $sel_EMAIL = "";
 $sel_RTF = "";
@@ -1014,6 +1026,9 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 $autosalv = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'autosalv' ");
 if (!numlin_query($autosalv)) $autosalv = "";
 else $autosalv = risul_query($autosalv,0,'testo');
+$sel_mai = "";
+$sel_checkin = "";
+$sel_checkout = "";
 if (!$autosalv) $sel_mai = " selected";
 else ${"sel_".$autosalv} = " selected";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
@@ -1059,7 +1074,7 @@ if ($num_contr != $num_contratto_int and ($attiva_contratti_consentiti == "n" or
 $num_prog_esistente = esegui_query("select * from $tablecontratti where numero = '$num_contr' and tipo = 'num_prog' ");
 if (!numlin_query($num_prog_esistente)) {
 $nome_contr = mex("il documento",$pag)." ".$num_contr;
-if (strcmp($nomi_contratti['pers'][$num_contr],"")) $nome_contr .= " (".$nomi_contratti['pers'][$num_contr].")";
+if (strcmp((string) $nomi_contratti['pers'][$num_contr],"")) $nome_contr .= " (".$nomi_contratti['pers'][$num_contr].")";
 if ($num_prog != $num_contr) $sel = "";
 else $sel = " selected";
 $opt_num_prog .= "<option value=\"$num_contr\"$sel>$nome_contr</option>";
@@ -1226,10 +1241,10 @@ echo "<br>";
 
 $contr_head = "";
 $contr_foot = "";
+$checked = "";
 if ($tipo_contratto == "htm") {
 $intestazione_html = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'headhtm'");
 if (numlin_query($intestazione_html) == 1) $checked = " checked";
-else $checked = "";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
