@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -153,6 +153,7 @@ $inserimento_nuovi_clienti = "SI";
 $modifica_clienti = "SI";
 $vedi_clienti = "SI";
 $attiva_prefisso_clienti = "n";
+$prefisso_clienti = "";
 $priv_vedi_tab_prenotazioni = "s";
 $attiva_contratti_consentiti = "n";
 $priv_mod_prenotazioni = "s";
@@ -238,7 +239,7 @@ unset($num_persone_tot_idpr);
 unset($app_letto_idpr);
 for ($num_idpr = 0 ; $num_idpr < $num_id_prenota ; $num_idpr++) {
 $id_prenota = $id_prenota_idpr[$num_idpr];
-unset($num_letti_agg);
+$num_letti_agg = array('max' => 0);
 $d_id_data_inizio = risul_query($dati_prenota[$id_prenota],0,'iddatainizio');
 $d_id_data_fine = risul_query($dati_prenota[$id_prenota],0,'iddatafine');
 $d_num_persone = risul_query($dati_prenota[$id_prenota],0,'num_persone');
@@ -266,7 +267,7 @@ $continua = 1;
 for ($num_idpr = 0 ; $num_idpr < $num_id_prenota ; $num_idpr++) {
 $id_prenota = $id_prenota_idpr[$num_idpr];
 $num_ospiti_inviati = ${"num_ospiti_inviati".$id_prenota};
-if (!strcmp($num_ospiti_inviati,"") or controlla_num_pos($num_ospiti_inviati) == "NO") $continua = 0;
+if (!strcmp((string) $num_ospiti_inviati,"") or controlla_num_pos($num_ospiti_inviati) == "NO") $continua = 0;
 } # fine for $num_idpr
 
 if ($continua) {
@@ -322,15 +323,15 @@ else $principale = "";
 } # fine if ($principale != $idclienti)
 
 unset($n_parentela);
-unset($lista_parentela_cambiata);
+$lista_parentela_cambiata = "";
 for ($num1 = 1 ; $num1 <= $num_ospiti_inviati ; $num1++) {
 $id_clienti_osp = aggslashdb(fixset(${"id_osp_num".$id_prenota."_".$num1}));
 if ($id_clienti_osp and $id_clienti_osp != $principale) {
-if ($osp_presente[$id_clienti_osp]) {
+if (!empty($osp_presente[$id_clienti_osp])) {
 $dati_ospite = esegui_query("select idclienti_compagni from $tableclienti where idclienti = '$id_clienti_osp' ");
 $idclienti_compagni .= substr(risul_query($dati_ospite,0,'idclienti_compagni'),1);
 $canc_ospite = 0;
-if (${"ospite".$id_prenota."_".$id_clienti_osp} == "SI") {
+if (isset(${"ospite".$id_prenota."_".$id_clienti_osp}) and ${"ospite".$id_prenota."_".$id_clienti_osp} == "SI") {
 if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) {
 $mess_letto = 1;
 $canc_ospite = 1;
@@ -349,48 +350,48 @@ esegui_query("update $tablerclientiprenota set parentela = '".aggslashdb($parent
 $lista_parentela_cambiata .= " and idclienti != '$id_clienti_osp'";
 } # fine if ($parentela != $d_parentela)
 } # fine else if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0)
-} # fine if (${"ospite".$id_prenota."_".$id_clienti_osp} == "SI")
+} # fine if (isset(${"ospite".$id_prenota."_".$id_clienti_osp}) and ${"ospite".$id_prenota."_".$id_clienti_osp} == "SI")
 else $canc_ospite = 1;
 if ($canc_ospite) esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$id_clienti_osp' ");
-} # fine if ($osp_presente[$id_clienti_osp])
+} # fine if (!empty($osp_presente[$id_clienti_osp]))
 } # fine if ($id_clienti_osp and...
 if (!$id_clienti_osp and ${"cognome".$id_prenota."_".$num1} and $inserimento_nuovi_clienti == "SI") {
 if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) $mess_letto = 1;
 else {
-$cognome_aux = ${"cognome".$id_prenota."_".$num1};
-$nome_aux = ${"nome".$id_prenota."_".$num1};
-$titolo_cli_aux = ${"titolo_cli".$id_prenota."_".$num1};
-$sesso_aux = ${"sesso".$id_prenota."_".$num1};
-$mesenascita_aux = ${"mesenascita".$id_prenota."_".$num1};
-$giornonascita_aux = ${"giornonascita".$id_prenota."_".$num1};
-$annonascita_aux = ${"annonascita".$id_prenota."_".$num1};
-$nazionenascita_aux = ${"nazionenascita".$id_prenota."_".$num1};
-$cittanascita_aux = ${"cittanascita".$id_prenota."_".$num1};
-$regionenascita_aux = ${"regionenascita".$id_prenota."_".$num1};
-$documento_aux = ${"documento".$id_prenota."_".$num1};
-$tipodoc_aux = ${"tipodoc".$id_prenota."_".$num1};
-$mesescaddoc_aux = ${"mesescaddoc".$id_prenota."_".$num1};
-$giornoscaddoc_aux = ${"giornoscaddoc".$id_prenota."_".$num1};
-$annoscaddoc_aux = ${"annoscaddoc".$id_prenota."_".$num1};
-$cittadoc_aux = ${"cittadoc".$id_prenota."_".$num1};
-$regionedoc_aux = ${"regionedoc".$id_prenota."_".$num1};
-$nazionedoc_aux = ${"nazionedoc".$id_prenota."_".$num1};
-$nazionalita_aux = ${"nazionalita".$id_prenota."_".$num1};
-$lingua_cli_aux = ${"lingua_cli".$id_prenota."_".$num1};
-$nazione_aux = ${"nazione".$id_prenota."_".$num1};
-$citta_aux = ${"citta".$id_prenota."_".$num1};
-$regione_aux = ${"regione".$id_prenota."_".$num1};
-$via_aux = ${"via".$id_prenota."_".$num1};
-$nomevia_aux = ${"nomevia".$id_prenota."_".$num1};
-$numcivico_aux = ${"numcivico".$id_prenota."_".$num1};
-$cap_aux = ${"cap".$id_prenota."_".$num1};
-$telefono__aux = ${"telefono_".$id_prenota."_".$num1};
-$telefono2__aux = ${"telefono2_".$id_prenota."_".$num1};
-$telefono3__aux = ${"telefono3_".$id_prenota."_".$num1};
-$fax_aux = ${"fax".$id_prenota."_".$num1};
-$email_aux = ${"email".$id_prenota."_".$num1};
-$email2_aux = ${"email2".$id_prenota."_".$num1};
-$email_cert_aux = ${"email_cert".$id_prenota."_".$num1};
+$cognome_aux = fixset(${"cognome".$id_prenota."_".$num1});
+$nome_aux = fixset(${"nome".$id_prenota."_".$num1});
+$titolo_cli_aux = fixset(${"titolo_cli".$id_prenota."_".$num1});
+$sesso_aux = fixset(${"sesso".$id_prenota."_".$num1});
+$mesenascita_aux = fixset(${"mesenascita".$id_prenota."_".$num1});
+$giornonascita_aux = fixset(${"giornonascita".$id_prenota."_".$num1});
+$annonascita_aux = fixset(${"annonascita".$id_prenota."_".$num1});
+$nazionenascita_aux = fixset(${"nazionenascita".$id_prenota."_".$num1});
+$cittanascita_aux = fixset(${"cittanascita".$id_prenota."_".$num1});
+$regionenascita_aux = fixset(${"regionenascita".$id_prenota."_".$num1});
+$documento_aux = fixset(${"documento".$id_prenota."_".$num1});
+$tipodoc_aux = fixset(${"tipodoc".$id_prenota."_".$num1});
+$mesescaddoc_aux = fixset(${"mesescaddoc".$id_prenota."_".$num1});
+$giornoscaddoc_aux = fixset(${"giornoscaddoc".$id_prenota."_".$num1});
+$annoscaddoc_aux = fixset(${"annoscaddoc".$id_prenota."_".$num1});
+$cittadoc_aux = fixset(${"cittadoc".$id_prenota."_".$num1});
+$regionedoc_aux = fixset(${"regionedoc".$id_prenota."_".$num1});
+$nazionedoc_aux = fixset(${"nazionedoc".$id_prenota."_".$num1});
+$nazionalita_aux = fixset(${"nazionalita".$id_prenota."_".$num1});
+$lingua_cli_aux = fixset(${"lingua_cli".$id_prenota."_".$num1});
+$nazione_aux = fixset(${"nazione".$id_prenota."_".$num1});
+$citta_aux = fixset(${"citta".$id_prenota."_".$num1});
+$regione_aux = fixset(${"regione".$id_prenota."_".$num1});
+$via_aux = fixset(${"via".$id_prenota."_".$num1});
+$nomevia_aux = fixset(${"nomevia".$id_prenota."_".$num1});
+$numcivico_aux = fixset(${"numcivico".$id_prenota."_".$num1});
+$cap_aux = fixset(${"cap".$id_prenota."_".$num1});
+$telefono__aux = fixset(${"telefono_".$id_prenota."_".$num1});
+$telefono2__aux = fixset(${"telefono2_".$id_prenota."_".$num1});
+$telefono3__aux = fixset(${"telefono3_".$id_prenota."_".$num1});
+$fax_aux = fixset(${"fax".$id_prenota."_".$num1});
+$email_aux = fixset(${"email".$id_prenota."_".$num1});
+$email2_aux = fixset(${"email2".$id_prenota."_".$num1});
+$email_cert_aux = fixset(${"email_cert".$id_prenota."_".$num1});
 $id_clienti_ins = inserisci_dati_cliente($cognome_aux,$nome_aux,"",$titolo_cli_aux,$sesso_aux,$mesenascita_aux,$giornonascita_aux,$annonascita_aux,$nazionenascita_aux,$cittanascita_aux,$regionenascita_aux,$documento_aux,$tipodoc_aux,$mesescaddoc_aux,$giornoscaddoc_aux,$annoscaddoc_aux,$cittadoc_aux,$regionedoc_aux,$nazionedoc_aux,$nazionalita_aux,$lingua_cli_aux,$nazione_aux,$citta_aux,$regione_aux,$via_aux,$nomevia_aux,$numcivico_aux,$cap_aux,$telefono__aux,$telefono2__aux,$telefono3__aux,$fax_aux,$email_aux,$email2_aux,$email_cert_aux,"","",($num_ospiti_inviati + 1),$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti);
 $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $id_clienti_ins;
@@ -419,7 +420,7 @@ $id_clienti_osp = $lista_ospiti[$num1];
 if ($id_clienti_osp == $idclienti) $n_num_ordine = 1;
 else $n_num_ordine = $max_num_ordine;
 $max_num_ordine++;
-if (!$osp_presente[$id_clienti_osp]) {
+if (empty($osp_presente[$id_clienti_osp])) {
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($n_num_ordine > 2) {
 if (@get_magic_quotes_gpc()) $n_parentela[$num1] = stripslashes($n_parentela[$num1]);
@@ -427,14 +428,14 @@ $parentela = htmlspecialchars($n_parentela[$num1]);
 } # fine if ($n_num_ordine > 2)
 else $parentela = "";
 esegui_query("insert into $tablerclientiprenota (idprenota,idclienti,num_ordine,parentela,datainserimento,hostinserimento,utente_inserimento) values ('$id_prenota','$id_clienti_osp','$n_num_ordine','$parentela','$datainserimento','$HOSTNAME','$id_utente_ins') ");
-} # fine if (!$osp_presente[$id_clienti_osp])
+} # fine if (emtpy($osp_presente[$id_clienti_osp]))
 else {
 $num_ordine = risul_query($ospiti,($osp_presente[$id_clienti_osp] - 1),'num_ordine');
 if ($num_ordine != $n_num_ordine) {
 esegui_query("update $tablerclientiprenota set num_ordine = '$n_num_ordine' where idprenota = '$id_prenota' and idclienti = '$id_clienti_osp' ");
 esegui_query("update $tablerclientiprenota set parentela = '' where (idprenota = '$id_prenota'$lista_parentela_cambiata) or (idprenota = '$id_prenota' and num_ordine < 3) ");
 } # fine if ($num_ordine != $n_num_ordine)
-} # fine else if (numlin_query($osp_presente) == 0)
+} # fine else if (emtpy($osp_presente[$id_clienti_osp]))
 $d_max_num_ordine = esegui_query("select idclienti_compagni,max_num_ordine from $tableclienti where idclienti = '$id_clienti_osp' ");
 $d_idclienti_compagni = risul_query($d_max_num_ordine,0,'idclienti_compagni');
 $d_max_num_ordine = risul_query($d_max_num_ordine,0,'max_num_ordine');
@@ -480,8 +481,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_ospiti.ph
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota_int\">
 <input type=\"hidden\" name=\"modifica\" value=\"SI\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixset($tipo_tabella))."\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixset($origine))."\">";
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixstr($tipo_tabella))."\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">";
 
 if ($inserimento_nuovi_clienti == "SI") {
 mostra_funzjs_cpval();
@@ -505,17 +506,17 @@ if ($dnazionalita) $nazione_def = $dnazionalita;
 elseif ($dnazione) $nazione_def = $dnazione;
 elseif ($dnazionedoc) $nazione_def = $dnazionedoc;
 elseif ($dnazionenascita) $nazione_def = $dnazionenascita;
-$nazione_def = addslashes($nazione_def);
+$nazione_def = addslashes(fixstr($nazione_def));
 if ($dregionenascita) $regione_def = $dregionenascita;
 elseif ($dregione) $regione_def = $dregione;
 elseif ($dregionedoc) $regione_def = $dregionedoc;
 elseif ($dregionenascita) $regione_def = $dregionenascita;
-$regione_def = addslashes(fixset($regione_def));
+$regione_def = addslashes(fixstr($regione_def));
 if ($dcittanascita) $citta_def = $dcittanascita;
 elseif ($dcitta) $citta_def = $dcitta;
 elseif ($dcittadoc) $citta_def = $dcittadoc;
 elseif ($dcittanascita) $citta_def = $dcittanascita;
-$citta_def = addslashes(fixset($citta_def));
+$citta_def = addslashes(fixstr($citta_def));
 
 $ospiti = esegui_query("select * from $tablerclientiprenota where idprenota = '$id_prenota' order by num_ordine ");
 $num_ospiti = numlin_query($ospiti);
@@ -670,7 +671,7 @@ $idclienti_compagni = explode(",",$idclienti_compagni);
 $num_idclienti_compagni = count($idclienti_compagni);
 for ($num1 = 0 ; $num1 < $num_idclienti_compagni ; $num1++) {
 $id_clienti_osp = $idclienti_compagni[$num1];
-if ($presente_id[$id_clienti_osp] != "SI") {
+if (!isset($presente_id[$id_clienti_osp]) or $presente_id[$id_clienti_osp] != "SI") {
 $presente_id[$id_clienti_osp] = "SI";
 $dati_ospite = esegui_query("select cognome,nome,sesso,datanascita,utente_inserimento from $tableclienti where idclienti = '$id_clienti_osp' ");
 $dati_osp .= "<input name=\"altro_ospite$id_prenota"."_$id_clienti_osp\" value=\"SI\" type=\"checkbox\">\
@@ -683,7 +684,7 @@ if ($ccsesso == "f") $O = "a";
 if ($ccnome) $dati_osp .=  "$ccnome ";
 if ($ccdatanascita) $dati_osp .= mex("nat$O il",$pag)." ".formatta_data($ccdatanascita,$stile_data)." ";
 $dati_osp .= "<br>";
-} # fine if ($presente_id[$id_clienti_osp] != "SI")
+} # fine if (!isset($presente_id[$id_clienti_osp]) or $presente_id[$id_clienti_osp] != "SI")
 } # fine for $num1
 if ($dati_osp) {
 echo "
