@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -40,7 +40,8 @@ $var_pag[11] = 'ini_periodo_passa';
 $var_pag[12] = 'fine_periodo_passa';
 $var_pag[13] = 'aggiungi';
 $var_pag[14] = 'sottrai';
-$n_var_pag = 15;
+$var_pag[15] = 'canc_incassa';
+$n_var_pag = 16;
 $num2 = 0;
 if (isset($_POST['num_costi_passa'])) $num2 = (int) $_POST['num_costi_passa'];
 elseif (isset($_GET['num_costi_passa'])) $num2 = (int) $_GET['num_costi_passa'];
@@ -223,7 +224,7 @@ if (!isset($id_prenota)) $id_prenota = null;
 if (!isset($id_costi)) $id_costi = null;
 if ($inprenota and $id_prenota) {
 $tabelle_lock = array($tableprenota,$tablecostiprenota,$tablerelinventario);
-$altre_tab_lock = array($tableperiodi,$tablecasse);
+$altre_tab_lock = array($tableperiodi,$tablecontratti,$tablepersonalizza,$tablecasse);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 } # fine if ($inprenota and $id_prenota)
 
@@ -317,7 +318,7 @@ $azione = 1;
 $incassa = 0;
 } # fine if (!empty($canc_incassa))
 
-if (!empty($agg_costo) and (strcmp($dati_ca['id'][$agg_costo],"") or substr($agg_costo,0,1) == "c") and !$azione) {
+if (!empty($agg_costo) and (strcmp((string) $dati_ca['id'][$agg_costo],"") or substr($agg_costo,0,1) == "c") and !$azione) {
 $azione = 1;
 if (substr($agg_costo,0,1) != "c") {
 if ($id_costi) $id_costi .= ",";
@@ -332,16 +333,16 @@ $id_costi .= $dati_ca[$num1]['id'];
 } # fine if ($dati_ca[$num1]['combina'] == "s" and...
 } # fine for $num1
 } # fine else if (substr($agg_costo,0,1) != "c")
-} # fine if (!empty($agg_costo) and (strcmp($dati_ca['id'][$agg_costo],"") or...
+} # fine if (!empty($agg_costo) and (strcmp((string) $dati_ca['id'][$agg_costo],"") or...
 
-if (isset($canc_costo) and strcmp($canc_costo,"") and !$azione) {
+if (isset($canc_costo) and strcmp((string) $canc_costo,"") and !$azione) {
 $azione = 1;
 $costi = explode(",",$id_costi);
 $num_costi = count($costi);
 $id_costi = "";
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) if ($num1 != $canc_costo) $id_costi .= $costi[$num1].",";
 $id_costi = substr($id_costi,0,-1);
-} # fine if (isset($canc_costo) and strcmp($canc_costo,"") and !$azione)
+} # fine if (isset($canc_costo) and strcmp((string) $canc_costo,"") and !$azione)
 
 if (((!empty($moltiplica) and controlla_num_pos($moltiplica) != "NO") or (!empty($aggiungi) and controlla_num_pos($aggiungi) != "NO") or (!empty($sottrai) and controlla_num_pos($sottrai) != "NO")) and !empty($id_costi) and !$azione) {
 $azione = 1;
@@ -406,7 +407,7 @@ $molt_costo = fixset($id_costo[1]);
 $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['moltiplica'] != "c") $molt_costo = "";
-if (strcmp($numca,"")) {
+if (strcmp((string) $numca,"")) {
 if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$id_costo] == "SI") {
 
 $molt_costo_orig = $molt_costo;
@@ -556,7 +557,7 @@ if ($molt_costo_orig) $testo_costi .= " x$molt_costo_orig";
 
 $num_costo++;
 } # fine if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$id_costo] == "SI")
-} # fine if (strcmp($numca,""))
+} # fine if (strcmp((string) $numca,""))
 } # fine for $num1
 
 
@@ -822,11 +823,11 @@ else {
 if ($num_casse_attive == 1) $id_cassa = $id_casse[1];
 else $id_cassa = $id_cassa_sel;
 $nome_cassa = $nomi_casse[$id_cassa];
-if (strcmp($metodo_pagamento_sel,"")) {
+if (strcmp((string) $metodo_pagamento_sel,"")) {
 if (@get_magic_quotes_gpc()) $metodo_pagamento_sel = stripslashes($metodo_pagamento_sel);
 $metodo_pagamento_sel = htmlspecialchars($metodo_pagamento_sel);
 if (str_replace(",$metodo_pagamento_sel,",",",",$metodi_pagamento,") == ",$metodi_pagamento,") $metodo_pagamento_sel = "";
-} # fine if (strcmp($metodo_pagamento_sel,""))
+} # fine if (strcmp((string) $metodo_pagamento_sel,""))
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $val_entrata = formatta_soldi($val_tot);
 $persona_costo = "";
@@ -838,7 +839,7 @@ $provenienza_costo = "";
 $idcosti = esegui_query("select max(idcosti) from $tablecosti");
 $idcosti = risul_query($idcosti,0,0) + 1;
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,tipo_costo,nome_cassa,persona_costo,provenienza_costo,metodo_pagamento,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti','".aggslashdb($testo_costi)."','$val_entrata','e','".aggslashdb($nome_cassa)."','".aggslashdb($persona_costo)."','".aggslashdb($provenienza_costo)."','".aggslashdb($metodo_pagamento_sel)."','$datainserimento','$HOSTNAME','$id_utente') ");
-if ($altre_valute['num'] and isset($altre_valute['id'][$valuta_pagamento_sel]) and strcmp($altre_valute['id'][$valuta_pagamento_sel],"")) {
+if ($altre_valute['num'] and isset($altre_valute['id'][$valuta_pagamento_sel]) and strcmp((string) $altre_valute['id'][$valuta_pagamento_sel],"")) {
 $valuta_corr = $altre_valute['id'][$valuta_pagamento_sel];
 $val_entrata_valuta = (double) $val_entrata * (double) $altre_valute[$valuta_corr]['cambio'];
 $val_entrata_valuta = $val_entrata_valuta / (double) $altre_valute[$valuta_corr]['arrotond'];
@@ -1090,7 +1091,7 @@ $testo_costi .= "</td><td$redclass>".$dati_ca[$numca]['nome']."$molt_costo</td>
 <td style=\"width: 40px; text-align: right;\">$val_costo_vedi</td></tr>";
 } # fine for $num1
 
-if (isset($n_categoria) and strcmp($n_categoria,"")) $categoria = $n_categoria;
+if (isset($n_categoria) and strcmp((string) $n_categoria,"")) $categoria = $n_categoria;
 if (!empty($no_categoria)) $categoria = "";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"punto_vendita.php#finetab\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -1098,7 +1099,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"punto_vendita.php#
 <input type=\"hidden\" name=\"num_costi_passa\" value=\"$num_costi\">
 <input type=\"hidden\" id=\"id_costi\" name=\"id_costi\" value=\"$id_costi\">
 <input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota\">
-<input type=\"hidden\" id=\"nomecat\" name=\"categoria\" value=\"".htmlspecialchars(fixset($categoria))."\">";
+<input type=\"hidden\" id=\"nomecat\" name=\"categoria\" value=\"".htmlspecialchars(fixstr($categoria))."\">";
 for ($numca2 = 0 ; $numca2 < $num_costi ; $numca2++) if (!empty(${"id_periodi_costo".$numca2})) echo "<input type=\"hidden\" name=\"id_periodi_costo$numca2\" value=\"".htmlspecialchars(${"id_periodi_costo".$numca2})."\">";
 echo "<div style=\"float: left; border: 1px solid black; width: 300px; height: 385px; margin: 0 2px 1px 1px;\">
 <div style=\" height: 276px; overflow: auto;\">
@@ -1344,7 +1345,7 @@ echo "<hr class=\"pos\">";
 } # fine if (@is_array($costi_agg_raggr))
 
 echo "<div id=\"cattxt\">";
-if (strcmp($categoria,"") and $testo_categoria[$categoria]) echo $testo_categoria[$categoria];
+if (strcmp((string) $categoria,"") and $testo_categoria[$categoria]) echo $testo_categoria[$categoria];
 else echo $testo_no_categoria;
 echo "</div>";
 
