@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -24,7 +24,14 @@ $pag = "storia_soldi.php";
 $titolo = "HotelDruid: Storico Entrate";
 
 $var_pag = array();
-$n_var_pag = 0;
+$var_pag[0] = 'senza_colori';
+$var_pag[1] = 'metodo_selezionato';
+$var_pag[2] = 'cerca_prenota';
+$var_pag[3] = 'cerca_inizioperiodo';
+$var_pag[4] = 'cerca_anno_inizioperiodo';
+$var_pag[5] = 'cerca_fineperiodo';
+$var_pag[6] = 'cerca_anno_fineperiodo';
+$n_var_pag = 7;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -123,18 +130,13 @@ if (!empty($pagina_prenota) and controlla_num_pos($pagina_prenota) != "SI") $pag
 if (isset($azzera_soldi) and $azzera_soldi == "SI" and $id_utente == 1) {
 if (empty($continua)) {
 $mostra_tabella = "NO";
-$tabelle_lock = array("$tableversioni","$tabletransazioni");
-$altre_tab_lock = array("$tablepersonalizza");
+$tabelle_lock = array($tableversioni,$tabletransazioni);
+$altre_tab_lock = array($tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-$versione_transazione = prendi_numero_versione($tableversioni);
-$adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-list($usec, $sec) = explode(' ', microtime());
-mt_srand((float) $sec + ((float) $usec * 100000));
-$val_casuale = mt_rand(100000,999999);
+$id_transazione = crea_id_sessione("",$tableversioni,8);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 global $REMOTE_ADDR;
 $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
-$id_transazione = $adesso.$val_casuale.$versione_transazione;
 esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_transazione,ultimo_accesso) values ('$id_transazione','$id_sessione','can_s','$ultimo_accesso')");
 unlock_tabelle($tabelle_lock);
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"storia_soldi.php\"><div>
@@ -184,8 +186,8 @@ echo "<table class=\"buttonbar\"><tr><td align=\"left\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"storia_soldi.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"senza_colori\" value=\"".htmlspecialchars(fixset($senza_colori))."\">
-<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars(fixset($metodo_selezionato))."\">
+<input type=\"hidden\" name=\"senza_colori\" value=\"".htmlspecialchars(fixstr($senza_colori))."\">
+<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars(fixstr($metodo_selezionato))."\">
 <input class=\"sbutton\" type=\"submit\" name=\"cerca_prenota\" value=\"".mex("Vedi le modifiche",$pag)."\">
  ".mex("dal",$pag)." <select name=\"cerca_inizioperiodo\">
 <option value=\"\">----</option>";
@@ -241,8 +243,8 @@ echo "<td align=\"right\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"storia_soldi.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"pagina_prenota\" value=\"".htmlspecialchars(fixset($pagina_prenota))."\">
-<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars(fixset($metodo_selezionato))."\">";
+<input type=\"hidden\" name=\"pagina_prenota\" value=\"".htmlspecialchars(fixstr($pagina_prenota))."\">
+<input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars(fixstr($metodo_selezionato))."\">";
 if (!$senza_colori) {
 echo "<input type=\"hidden\" name=\"senza_colori\" value=\"SI\">
 <input class=\"sbutton\" type=\"submit\" name=\"cambia_colori\" value=\"".mex("Senza colori",$pag)."\">";
