@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -50,7 +50,8 @@ $var_pag[18] = 'tipo_commento';
 $var_pag[19] = 'n_commento';
 $var_pag[20] = 'n_cancella_commento';
 $var_pag[21] = 'tableprenota_da_aggiornare';
-$n_var_pag = 22;
+$var_pag[22] = 'torna_indietro';
+$n_var_pag = 23;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -73,6 +74,7 @@ $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_ut
 if ($id_utente) {
 
 if ($id_utente != 1) {
+$prendi_gruppi = "";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
@@ -327,7 +329,7 @@ else $d_inizio_settimana = 0;
 function colore_prenotazione ($prenota,$num_pren) {
 global $tableprenota,$colore_trasp,$colore_giallo,$colore_arancione,$colore_rosso;
 $pagato = risul_query($prenota,$num_pren,'pagato',$tableprenota);
-$confermato = risul_query($prenota,$num_pren,'conferma',$tableprenota);
+$confermato = (string) risul_query($prenota,$num_pren,'conferma',$tableprenota);
 $confermato = substr($confermato,0,1);
 if (!$pagato) $pagato = 0;
 $caparra = risul_query($prenota,$num_pren,'caparra',$tableprenota);
@@ -638,7 +640,7 @@ $tariffa_sconto_valuta = converti_valuta(($costo_tariffa - $sconto),$cambio_tari
 $costo_agg_tot = round(((double) $tariffa_tot - (double) $costo_tariffa + (double) $sconto),2);
 if ($costo_agg_tot) {
 $altre_valute = altre_valute();
-if (!strcmp($altre_valute['id'][$valuta_tariffa],"")) $costi_agg_valuta = converti_valuta($costo_agg_tot,$cambio_tariffa,$arrotond_tariffa);
+if (!strcmp((string) $altre_valute['id'][$valuta_tariffa],"")) $costi_agg_valuta = converti_valuta($costo_agg_tot,$cambio_tariffa,$arrotond_tariffa);
 else  $costi_agg_valuta = converti_valuta($costo_agg_tot,$altre_valute[$altre_valute['id'][$valuta_tariffa]]['cambio'],$altre_valute[$altre_valute['id'][$valuta_tariffa]]['arrotond']);
 } # fine if ($costo_agg_tot)
 $tariffa_valuta_tot = round(($tariffa_sconto_valuta + $costi_agg_valuta),2);
@@ -650,7 +652,7 @@ $dati_xml .= "\n-".mex("Pagato",$pag).": ".punti_in_num($pagato,$stile_soldi)."
 $da_pagare = $tariffa_tot - $pagato;
 if ($da_pagare and $da_pagare != $tariffa_tot) {
 $dati_xml .= "\n-".mex("Ancora da pagare",$pag).": ".punti_in_num($da_pagare,$stile_soldi)." $Euro ";
-if (strcmp($valuta_tariffa,"")) {
+if (strcmp((string) $valuta_tariffa,"")) {
 $resto_tarsco_valuta = round(((double) $costo_tariffa - (double) $sconto - (double) $pagato),2);
 if ($resto_tarsco_valuta >= 0) {
 $dapagare_tarsco_valuta = converti_valuta($resto_tarsco_valuta,$cambio_tariffa,$arrotond_tariffa);
@@ -661,12 +663,12 @@ $dapagare_tarsco_valuta = 0;
 $dapagare_cosagg_valuta = round(((double) $costo_agg_tot + (double) $resto_tarsco_valuta),2);
 } # fine else if ($resto_tarsco_valuta >= 0)
 if ($dapagare_cosagg_valuta) {
-if (!strcmp($altre_valute['id'][$valuta_tariffa],"")) $dapagare_cosagg_valuta = converti_valuta($dapagare_cosagg_valuta,$cambio_tariffa,$arrotond_tariffa);
+if (!strcmp((string) $altre_valute['id'][$valuta_tariffa],"")) $dapagare_cosagg_valuta = converti_valuta($dapagare_cosagg_valuta,$cambio_tariffa,$arrotond_tariffa);
 else $dapagare_cosagg_valuta = converti_valuta($dapagare_cosagg_valuta,$altre_valute[$altre_valute['id'][$valuta_tariffa]]['cambio'],$altre_valute[$altre_valute['id'][$valuta_tariffa]]['arrotond']);
 } # fine if ($dapagare_cosagg_valuta)
 $da_pagare_valuta = round(($dapagare_tarsco_valuta + $dapagare_cosagg_valuta),2);
 $dati_xml .= "= ".virgola_in_num($da_pagare_valuta,$stile_soldi)." $valuta_tariffa ";
-} # fine if (strcmp($valuta_tariffa,""))
+} # fine if (strcmp((string) $valuta_tariffa,""))
 } # fine if ($da_pagare and $da_pagare != $tariffa_tot)
 } # fine if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i")
 $dati_xml .= "</txt>";
@@ -704,7 +706,7 @@ if ($priv_mod_prenotazioni != "n") {
 $inserire = "SI";
 $cancellata = "NO";
 prepara_modifiche_prenotazione($id_prenota_idpr,$num_id_prenota,$prenota_in_anno_succ,$dati_da_anno_prec,$tra_anni,$anno,$PHPR_TAB_PRE,"");
-esegui_modifiche_prenotazione($inserire,$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_valuta_caparra,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE,"");
+esegui_modifiche_prenotazione($inserire,$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_valuta_caparra,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,fixset($tipo_sposta),$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE,"");
 } # fine if ($priv_mod_prenotazioni != "n")
 } # fine if (isset($modificaprenotazione) and $modificaprenotazione == "Continua")
 
@@ -734,7 +736,7 @@ echo "<small><small>".mex("situazione alle",$pag)." $ora ".mex("del",$pag)." $og
 
 $lista_prenota_contr = "";
 
-if (controlla_num_pos($mese) != "SI") $mese = 1;
+if (controlla_num_pos($mese) != "SI") $mese = date('n');
 if (isset($anno_succ) and $anno_succ == "SI") $mese = $mese + 12;
 
 $data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
@@ -1021,7 +1023,7 @@ if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] !=
 $casella_app = "";
 if (num_caratteri_testo($id_appartamento) > 2) $casella_app .= "<small><small>";
 if ($num1 >= $num_appartamenti) $casella_app .= "<div style=\"display: inline; color: red;\">";
-if (strcmp($id_appartamento,"")) $casella_app .= "$id_appartamento";
+if (strcmp((string) $id_appartamento,"")) $casella_app .= "$id_appartamento";
 else $casella_app .= mex("ERRORE",$pag);
 if ($num1 >= $num_appartamenti) $casella_app .= "</div>";
 if (num_caratteri_testo($id_appartamento) > 2) $casella_app .= "</small></small>";
@@ -1292,7 +1294,7 @@ unlock_tabelle($tabelle_lock);
 
 if ($allinea_tab_mesi != "SI") {
 echo "<tr class=\"ra_r\"><td style=\"height: 0; padding: 0; border: 0;\"></td>";
-for ($num1 = 0 ; $num1 < $num_colonne ; $num1++) echo "<td style=\"height: 0; padding: 0; border: 0;\"></td><td style=\"height: 0; padding: 0; border: 0;\"></td>";
+for ($num1 = 0 ; $num1 < $num_colonne ; $num1++) echo "<td style=\"height: 0; padding: 0; border: 0; min-width: 5px;\"></td><td style=\"height: 0; padding: 0; border: 0; min-width: 5px;\"></td>";
 echo "<td style=\"height: 0; padding: 0; border: 0;\"></td></tr>";
 } # fine if ($allinea_tab_mesi != "SI")
 
