@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -39,7 +39,9 @@ $t1dropout = "#297929";
 
 # head
 $body_bgcolor = "#dddddd";
-if ($senza_colori == "SI" or $pag == "visualizza_contratto.php") $body_bgcolor = "#ffffff";
+global $vers_hinc,$mobile_device;
+if (!isset($show_bar)) $show_bar = "";
+if (isset($senza_colori) or $pag == "visualizza_contratto.php") $body_bgcolor = "#ffffff";
 if ($pag == "punto_vendita.php") $iscale = "0.8";
 else $iscale = "1.0";
 if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") $titolo = "";
@@ -56,13 +58,16 @@ if (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)
 ";
 elseif (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
 ";
-if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
+if (isset($base_js)) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
 ";
 echo "<style type=\"text/css\">
 :root { --t1color: $t1color; }
 .t1color { background-color: $t1color; }
-</style>
+";
+if (empty($cookie_sess)) echo "a:link { user-select: none; -moz-user-select: none; -webkit-user-select: none; -ms-user-select: none; }
+";
+echo "</style>
 <link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\">
 <link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/snj/inc/stylesheet.css$vers_hinc\" media=\"all\">
 ";
@@ -72,7 +77,7 @@ if ($mobile_device and defined('C_FILE_MOB_CSS_PERS') and C_FILE_MOB_CSS_PERS !=
 ";
 echo "</head>
 <body";
-if ($drag_drop) echo " ondragover=\"event.preventDefault();\" ondragenter=\"event.preventDefault();\" ondrop=\"event.preventDefault();drp_out();\"";
+if (isset($drag_drop)) echo " ondragover=\"event.preventDefault();\" ondragenter=\"event.preventDefault();\" ondrop=\"event.preventDefault();drp_out();\"";
 echo " style=\"background-color: $body_bgcolor;\">";
 
 if ($pag != "visualizza_contratto.php") echo "<table style=\"height: 97%; width: 99%; background-color: #000000; margin-right: auto; margin-left: auto; margin-top: 5px; margin-bottom: 5px; border-width: 1px; border-color: black;\" cellpadding=\"0\" cellspacing=\"1\">
@@ -92,44 +97,44 @@ if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else $anno_utente_attivato = "SI";
 } # fine if (!$anno_utente_attivato)
 if ($anno_utente_attivato == "SI") {
-if (!$privilegi_globali_utente) $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
-if (!$priv_mod_pers) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
+if (!isset($privilegi_globali_utente)) $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
+if (!isset($priv_mod_pers)) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) == "s" and !$modifica_pers) $modifica_pers = "SI";
-if (!$priv_crea_backup) $priv_crea_backup = substr($priv_mod_pers,1,1);
-if (!$priv_ins_clienti) $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
+if (!isset($priv_crea_backup)) $priv_crea_backup = substr($priv_mod_pers,1,1);
+if (!isset($priv_ins_clienti)) $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 if (substr($priv_ins_clienti,0,1) != "s" and !$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "NO";
 if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p" and !$modifica_clienti) $modifica_clienti = "NO";
 if (substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p" and !$vedi_clienti) $vedi_clienti = "NO";
-if (!$priv_ins_prenota) $priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
-if (!$priv_ins_nuove_prenota) $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
-if (!$priv_ins_costi) $priv_ins_costi = risul_query($privilegi_annuali_utente,0,'priv_ins_costi');
-if (!$priv_ins_spese) $priv_ins_spese = substr($priv_ins_costi,0,1);
-if (!$priv_ins_entrate) $priv_ins_entrate = substr($priv_ins_costi,1,1);
-if (!$priv_vedi_tab) $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
-if (!$priv_vedi_tab_mesi) $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
-if (!$priv_vedi_tab_prenotazioni) $priv_vedi_tab_prenotazioni = substr($priv_vedi_tab,1,1);
-if (!$priv_vedi_tab_costi) $priv_vedi_tab_costi = substr($priv_vedi_tab,2,1);
-if (!$priv_vedi_tab_periodi) $priv_vedi_tab_periodi = substr($priv_vedi_tab,3,1);
-if (!$priv_vedi_tab_regole) $priv_vedi_tab_regole = substr($priv_vedi_tab,4,1);
-if (!$priv_vedi_tab_appartamenti) $priv_vedi_tab_appartamenti = substr($priv_vedi_tab,5,1);
+if (!isset($priv_ins_prenota)) $priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
+if (!isset($priv_ins_nuove_prenota)) $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
+if (!isset($priv_ins_costi)) $priv_ins_costi = risul_query($privilegi_annuali_utente,0,'priv_ins_costi');
+if (!isset($priv_ins_spese)) $priv_ins_spese = substr($priv_ins_costi,0,1);
+if (!isset($priv_ins_entrate)) $priv_ins_entrate = substr($priv_ins_costi,1,1);
+if (!isset($priv_vedi_tab)) $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
+if (!isset($priv_vedi_tab_mesi)) $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
+if (!isset($priv_vedi_tab_prenotazioni)) $priv_vedi_tab_prenotazioni = substr($priv_vedi_tab,1,1);
+if (!isset($priv_vedi_tab_costi)) $priv_vedi_tab_costi = substr($priv_vedi_tab,2,1);
+if (!isset($priv_vedi_tab_periodi)) $priv_vedi_tab_periodi = substr($priv_vedi_tab,3,1);
+if (!isset($priv_vedi_tab_regole)) $priv_vedi_tab_regole = substr($priv_vedi_tab,4,1);
+if (!isset($priv_vedi_tab_appartamenti)) $priv_vedi_tab_appartamenti = substr($priv_vedi_tab,5,1);
 } # fine if ($anno_utente_attivato == "SI")
 } # fine if ($id_utente != 1)
 else {
-if (!$anno_utente_attivato) $anno_utente_attivato = "SI";
-if (!$modifica_pers) $modifica_pers = "SI";
-if (!$priv_crea_backup) $priv_crea_backup = "s";
-if (!$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "SI";
-if (!$modifica_clienti) $modifica_clienti = "SI";
-if (!$vedi_clienti) $vedi_clienti = "SI";
-if (!$priv_ins_nuove_prenota) $priv_ins_nuove_prenota = "s";
-if (!$priv_ins_spese) $priv_ins_spese = "s";
-if (!$priv_ins_entrate) $priv_ins_entrate = "s";
-if (!$priv_vedi_tab_mesi) $priv_vedi_tab_mesi = "s";
-if (!$priv_vedi_tab_prenotazioni) $priv_vedi_tab_prenotazioni = "s";
-if (!$priv_vedi_tab_costi) $priv_vedi_tab_costi = "s";
-if (!$priv_vedi_tab_periodi) $priv_vedi_tab_periodi = "s";
-if (!$priv_vedi_tab_regole) $priv_vedi_tab_regole = "s";
-if (!$priv_vedi_tab_appartamenti) $priv_vedi_tab_appartamenti = "s";
+if (!isset($anno_utente_attivato)) $anno_utente_attivato = "SI";
+if (!isset($modifica_pers)) $modifica_pers = "SI";
+if (!isset($priv_crea_backup)) $priv_crea_backup = "s";
+if (!isset($inserimento_nuovi_clienti)) $inserimento_nuovi_clienti = "SI";
+if (!isset($modifica_clienti)) $modifica_clienti = "SI";
+if (!isset($vedi_clienti)) $vedi_clienti = "SI";
+if (!isset($priv_ins_nuove_prenota)) $priv_ins_nuove_prenota = "s";
+if (!isset($priv_ins_spese)) $priv_ins_spese = "s";
+if (!isset($priv_ins_entrate)) $priv_ins_entrate = "s";
+if (!isset($priv_vedi_tab_mesi)) $priv_vedi_tab_mesi = "s";
+if (!isset($priv_vedi_tab_prenotazioni)) $priv_vedi_tab_prenotazioni = "s";
+if (!isset($priv_vedi_tab_costi)) $priv_vedi_tab_costi = "s";
+if (!isset($priv_vedi_tab_periodi)) $priv_vedi_tab_periodi = "s";
+if (!isset($priv_vedi_tab_regole)) $priv_vedi_tab_regole = "s";
+if (!isset($priv_vedi_tab_appartamenti)) $priv_vedi_tab_appartamenti = "s";
 } # fine else if ($id_utente != 1)
 
 if ($anno_utente_attivato == "SI") {
@@ -150,14 +155,14 @@ if ($mese_attuale == 12) $MESE_ATT = "DICEMBRE";
 
 
 
-if ($pag == "tabella.php" or $pag == "tabella2.php" or $pag == "tabella3.php" or $pag == "visualizza_tabelle.php" or $pag == "storia_soldi.php") $mostra_X = "SI";
+if ($pag == "tabella.php" or $pag == "tabella2.php" or $pag == "tabella3.php" or $pag == "visualizza_tabelle.php" or $pag == "storia_soldi.php") $mostra_X = 1;
 
 
 echo "<table class=\"nav_bar\" style=\"text-align: center; background: $t1color url(./themes/snj/img/bar_bg_top.png) repeat-x left top;\" width=\"100%\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\">
 <tr style=\"background: url(./themes/snj/img/bar_bg_bot.png) repeat-x left bottom;\">";
 
-if ($mostra_X == "SI") echo "<td style=\"width: 10px;\"></td>";
-if ($idprenota_origine) $anno = $anno + 1;
+if (isset($mostra_X)) echo "<td style=\"width: 10px;\"></td>";
+if (!empty($idprenota_origine)) $anno = $anno + 1;
 if ($id_sessione) {
 $sessione_anno_var = "id_sessione=$id_sessione";
 if (substr($id_sessione,0,4) != $anno) $sessione_anno_var .= "&amp;anno=$anno";
@@ -185,9 +190,10 @@ echo "&nbsp;&nbsp;<a id=\"nb_roo\" href=\"./visualizza_tabelle.php?$sessione_ann
 } # fine if ($priv_vedi_tab_mesi != "n" or $priv_vedi_tab_prenotazioni != "n" or...
 echo "</td>";
 
-if ($idprenota_origine) $anno = $anno - 1;
+if (!empty($idprenota_origine)) $anno = $anno - 1;
 
-if ($mostra_X == "SI") {
+if (isset($mostra_X)) {
+$lista_var_X = "";
 if (@is_array($_POST)) reset($_POST);
 for($num1 = 0 ; $num1 < count($_POST); $num1++) {
 $lista_var_X .= "&amp;".urlencode(key($_POST))."=".urlencode($_POST[key($_POST)]);
@@ -204,7 +210,7 @@ echo "<td style=\"width: 10px; color: #666666; font-family: Verdana, Arial, Helv
 <b><a style=\"color: #666666;\" href=\"$pag$lista_var_X\">X</a></b></td>";
 } # fine if ($lista_var_X)
 else echo "<td style=\"width: 10px;\"></td>";
-} # fine if ($mostra_X == "SI")
+} # fine if (isset($mostra_X))
 
 echo "</tr>
 </table>
