@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -44,7 +44,9 @@ $var_pag[15] = 'data_fine_selezione';
 $var_pag[16] = 'idclienti';
 $var_pag[17] = 'cont_salva';
 $var_pag[18] = 'contr_corr';
-$n_var_pag = 19;
+$var_pag[19] = 'manda_mail';
+$var_pag[20] = 'numero_email';
+$n_var_pag = 21;
 $num2 = 1;
 if (isset($_POST['num_ripeti'])) $num2 = (int) $_POST['num_ripeti'];
 elseif (isset($_GET['num_ripeti'])) $num2 = (int) $_GET['num_ripeti'];
@@ -116,6 +118,7 @@ $var_pag[$n_var_pag++] = "promemoria_entrata_$num1";
 $var_pag[$n_var_pag++] = "promemoria_uscita_$num1";
 $var_pag[$n_var_pag++] = "metodo_pagamento_caparra_$num1";
 $var_pag[$n_var_pag++] = "num_costi_aggiuntivi_$num1";
+$var_pag[$n_var_pag++] = "num_comm_pers_passa_$num1";
 $num4 = 0;
 if (isset($_POST["num_costi_aggiuntivi_$num1"])) $num4 = (int) $_POST["num_costi_aggiuntivi_$num1"];
 elseif (isset($_GET["num_costi_aggiuntivi_$num1"])) $num4 = (int) $_GET["num_costi_aggiuntivi_$num1"];
@@ -143,6 +146,26 @@ $var_pag[$n_var_pag++] = "valuta_paga$num3"."_$num1";
 $var_pag[$n_var_pag++] = "tasso_cambio_paga$num3"."_$num1";
 $var_pag[$n_var_pag++] = "valore_valuta_paga$num3"."_$num1";
 } # fine for $num3
+$num4 = 0;
+if (isset($_POST["num_comm_pers_passa_$num1"])) $num4 = (int) $_POST["num_comm_pers_passa_$num1"];
+elseif (isset($_GET["num_comm_pers_passa_$num1"])) $num4 = (int) $_GET["num_comm_pers_passa_$num1"];
+for ($num3 = 0 ; $num3 < $num4 ; $num3++) {
+$var_pag[$n_var_pag++] = "nome_comm_pers_passa_$num3"."_$num1";
+$num5 = "";
+if (isset($_POST["nome_comm_pers_passa_$num3"."_$num1"])) $num5 = (string) $_POST["nome_comm_pers_passa_$num3"."_$num1"];
+elseif (isset($_GET["nome_comm_pers_passa_$num3"."_$num1"])) $num5 = (string) $_GET["nome_comm_pers_passa_$num3"."_$num1"];
+if (strcmp($num5,"")) $var_pag[$n_var_pag++] = "commento_personalizzato_$num5"."_$num1";
+} # fine for $num3
+} # fine for $num1
+$num2 = 0;
+if (isset($_POST['numero_email'])) $num2 = (int) $_POST['numero_email'];
+elseif (isset($_GET['numero_email'])) $num2 = (int) $_GET['numero_email'];
+for ($num1 = 1 ; $num1 <= $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "mittente_email$num1";
+$var_pag[$n_var_pag++] = "destinatario_email$num1";
+$var_pag[$n_var_pag++] = "oggetto_email$num1";
+$var_pag[$n_var_pag++] = "allega$num1";
+$var_pag[$n_var_pag++] = "testo_email$num1";
 } # fine for $num1
 
 include("./costanti.php");
@@ -152,6 +175,7 @@ $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB
 include("./includes/funzioni.php");
 include("./includes/funzioni_contratti.php");
 include("./includes/funzioni_testo.php");
+include("./includes/funzioni_email.php");
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tableprenotacanc = $PHPR_TAB_PRE."prenotacanc".$anno;
@@ -175,6 +199,7 @@ $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $tablerelclienti = $PHPR_TAB_PRE."relclienti";
 $tablecasse = $PHPR_TAB_PRE."casse";
 $tablecosti = $PHPR_TAB_PRE."costi".$anno;
+$tablecache = $PHPR_TAB_PRE."cache";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -382,17 +407,18 @@ $nome_mittente_email = $mittente_email[5];
 $mittente_email = $mittente_email[2];
 if ($nome_mittente_email) $mittente_email = "$nome_mittente_email <$mittente_email>";
 } # fine if ($modifica_pers == "NO")
-$maschera_envelope = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'maschera_email' and idutente = '1'");
-$maschera_envelope = risul_query($maschera_envelope,0,'valpersonalizza');
+#$maschera_envelope = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'maschera_email' and idutente = '1'");
+#$maschera_envelope = risul_query($maschera_envelope,0,'valpersonalizza');
+$dati_allegato = array('val' => "");
 $allegato_email = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'allegato'");
 $allegato_email = risul_query($allegato_email,0,'testo');
 if ($allegato_email) {
 $allegato_email = esegui_query("select * from $tablecontratti where numero = '$allegato_email' and tipo = 'file_all'");
 $allegato_email = risul_query($allegato_email,0,'testo');
 $allegato_email_v = explode(",",$allegato_email);
-$nome_allegato = $allegato_email_v[0];
-$tipo_allegato = $allegato_email_v[1];
-$allegato_email = substr($allegato_email,strlen($nome_allegato.",".$tipo_allegato.","));
+$dati_allegato['nome'] = $allegato_email_v[0];
+$dati_allegato['tipo'] = $allegato_email_v[1];
+$dati_allegato['val'] = substr($allegato_email,strlen($dati_allegato['nome'].",".$dati_allegato['tipo'].","));
 } # fine if ($allegato_email)
 $opz_eml = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'opzeml'");
 $opz_eml = risul_query($opz_eml,0,'testo');
@@ -401,67 +427,40 @@ $cont_type = "text/plain";
 if ($opz_eml[0] == "html") $cont_type = "text/html";
 $bcc_mittente = $opz_eml[1];
 $bcc_indirizzo = $opz_eml[2];
+if (defined('C_MASSIMO_NUM_EMAIL_GIORNALIERE') and C_MASSIMO_NUM_EMAIL_GIORNALIERE > 0) {
+$dati_manda_email['num_app'] = esegui_query("select idappartamenti from $tableappartamenti ");
+$dati_manda_email['num_app'] = numlin_query($dati_manda_email['num_app']);
+} # fine if (defined('C_MASSIMO_NUM_EMAIL_GIORNALIERE') and C_MASSIMO_NUM_EMAIL_GIORNALIERE > 0)
 
 for ($num1 = 1 ; $num1 <= $numero_email ; $num1++) {
 if (${"destinatario_email".$num1} and strstr(${"destinatario_email".$num1},"@")) {
-$inviato = "";
 if ($modifica_pers != "NO") $mittente_email = ${"mittente_email".$num1};
 $destinatario_email = ${"destinatario_email".$num1};
 if (@get_magic_quotes_gpc()) {
 ${"oggetto_email".$num1} = stripslashes(${"oggetto_email".$num1});
 ${"testo_email".$num1} = stripslashes(${"testo_email".$num1});
 } # fine if (@get_magic_quotes_gpc())
-switch (strtoupper(substr(PHP_OS,0,3))) {
-case "WIN": $mailh_nl = "\r\n"; break;
-case "MAC": $mailh_nl = "\r"; break;
-default: $mailh_nl = "\n"; break;
-} # fine switch (strtoupper(substr(PHP_OS,0,3)))
-if (strstr($mittente_email,"<")) {
-$headers = "From: $mittente_email$mailh_nl";
-$mittente_email = explode("<",$mittente_email);
-$mittente_email = explode(">",$mittente_email[1]);
-$mittente_email = $mittente_email[0];
-} # fine if (strstr($mittente_email,"<"))
-else $headers = "From: <$mittente_email>$mailh_nl";
-if ($bcc_mittente == "SI") $headers .= "Bcc: $mittente_email$mailh_nl";
-if ($bcc_indirizzo) $headers .= "Bcc: $bcc_indirizzo$mailh_nl";
-$testo_email = chunk_split(base64_encode(${"testo_email".$num1}));
-if ($allegato_email and ${"allega".$num1} == "SI") {
-$boundary = "--".md5(uniqid(rand()));
-$headers .= "MIME-Version: 1.0$mailh_nl";
-$headers .= "Content-Type: multipart/mixed;$mailh_nl";
-$headers .= " boundary=\"$boundary\"$mailh_nl";
-$headers .= "X-Sender: $mittente_email$mailh_nl";
-$headers .= "X-Mailer: PHP$mailh_nl";
-$headers .= "X-Priority: 3$mailh_nl";
-$headers .= "Return-Path: $mittente_email$mailh_nl";
-$testo_email = "This is a multi-part message in MIME format.\n--$boundary\nContent-type: $cont_type; charset=utf-8\nContent-Transfer-Encoding: base64\n\n$testo_email";
-$testo_email .= "\n--$boundary\n";
-$testo_email .= "Content-Type: $tipo_allegato;\n";
-$testo_email .= " name=\"$nome_allegato\"\n";
-$testo_email .= "Content-Transfer-Encoding: base64\n";
-$testo_email .= "Content-Disposition: attachment;\n";
-$testo_email .= " filename=\"$nome_allegato\"\n\n";
-$testo_email .= $allegato_email;
-if (substr($testo_email,-1) == "\n") $testo_email .= "--$boundary--";
-else $testo_email .= "\n--$boundary--";
-} # fine if ($allegato_email and ${"allega".$num1} == "SI")
-else {
-if ($cont_type != "text/plain") $headers .= "MIME-Version: 1.0$mailh_nl";
-$headers .= "Content-type: $cont_type; charset=utf-8$mailh_nl";
-$headers .= "Content-Transfer-Encoding: base64$mailh_nl";
-$headers .= "X-Sender: $mittente_email$mailh_nl";
-$headers .= "X-Mailer: PHP$mailh_nl";
-$headers .= "X-Priority: 3$mailh_nl";
-$headers .= "Return-Path: $mittente_email$mailh_nl";
-} # fine else if ($allegato_email and ${"allega".$num1} == "SI")
-#echo nl2br($headers.$testo_email)."QUI<br>";
 if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") {
-if (defined("C_MASCHERA_EMAIL") and C_MASCHERA_EMAIL != "") $maschera_envelope = C_MASCHERA_EMAIL;
-if ($maschera_envelope == "SI") $inviato = mail($destinatario_email,${"oggetto_email".$num1},$testo_email,$headers,"-f$mittente_email");
-else $inviato = mail($destinatario_email,${"oggetto_email".$num1},$testo_email,$headers);
+$inviato = manda_email($mittente_email,"","",$destinatario_email,"",$bcc_mittente,$bcc_indirizzo,${"oggetto_email".$num1},${"testo_email".$num1},$cont_type,$dati_allegato,fixset(${"allega".$num1}),$tablepersonalizza,$tablecache);
 } # fine if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI")
-if ($inviato) {
+else $inviato = array('ok' => 0);
+if (!empty($inviato['err_spf'])) {
+echo "<br><small>&nbsp;".mex("Non si è potuto mascherare il mittente dell'email perchè attualmente <b class=\"colwarn\">SPF non è configurato correttamente</b> sul dominio della email",$pag)." <b>$mittente_email</b>.
+ ".mex("L'utente amministratore può cambiare questa inpostazione in",$pag)." \"";
+if ($id_utente == 1) echo "<a href=\"./personalizza.php?id_sessione=$id_sessione&anno=$anno#sistema\">";
+echo mex("configura e personalizza",$pag);
+if ($id_utente == 1) echo "</a>";
+echo "\".</small><br>";
+} # fine if (!empty($inviato['err_spf']))
+if (!empty($inviato['err_max_email'])) {
+echo "<br>".mex("È stato raggiunto il numero massimo di email giornaliere",$pag)." (<span class=\"colred\">".$inviato['err_max_email']."</span>).
+ ".mex("Per mandare altre email l'utente amministratore può impostare un server remoto in",$pag)." ";
+if ($id_utente == 1) echo "<a href=\"./personalizza.php?id_sessione=$id_sessione&anno=$anno#sistema\">";
+echo mex("configura e personalizza",$pag);
+if ($id_utente == 1) echo "</a>";
+echo ".<br>";
+} # fine if (!empty($inviato['err_max_email']))
+if ($inviato['ok']) {
 echo "<br>&nbsp;".mex("L'email a",$pag)." <b>".htmlspecialchars($destinatario_email)."</b> ".mex("è stata inviata",$pag);
 if ($bcc_mittente == "SI" or $bcc_indirizzo) echo " (".mex("bcc a",$pag)." ";
 if ($bcc_mittente == "SI") echo $mittente_email;
@@ -481,20 +480,23 @@ if (str_replace("@","",$destinatario_email) != $destinatario_email) {
 $clienti = esegui_query("select * from $tableclienti where email $ILIKE '$destinatario_email%' or email $ILIKE '% $destinatario_email%' or email $ILIKE '%,$destinatario_email%' ");
 for ($num4 = 0 ; $num4 < numlin_query($clienti) ; $num4++) {
 $idclienti = risul_query($clienti,$num4,'idclienti');
-$doc_inviati = risul_query($clienti,$num4,'doc_inviati');
-if (str_replace("#@?".${"oggetto_email".$num1}."#|?","",$doc_inviati) == $doc_inviati) {
+$doc_inviati = (string) risul_query($clienti,$num4,'doc_inviati');
+if (str_replace("#@?".htmlspecialchars(${"oggetto_email".$num1})."#|?","",$doc_inviati) == $doc_inviati) {
 if (!$doc_inviati) $doc_inviati = "#@?";
-$doc_inviati .= str_replace("#|?","",str_replace("#@?","",${"oggetto_email".$num1}))."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?";
-} # fine if (str_replace(${"oggetto_email".$num1},"",$doc_inviati) == $doc_inviati)
-else $doc_inviati = preg_replace("/#@\?".${"oggetto_email".$num1}."#\|\?[^#]*#@\?/","#@?".${"oggetto_email".$num1}."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?",$doc_inviati);
+$doc_inviati .= str_replace("#|?","",str_replace("#@?","",htmlspecialchars(${"oggetto_email".$num1})))."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?";
+} # fine if (str_replace("#@?".htmlspecialchars(${"oggetto_email".$num1})."#|?","",$doc_inviati) == $doc_inviati)
+else $doc_inviati = preg_replace("/#@\?".str_replace('$','\$',str_replace("^","\^",str_replace("{","\{",str_replace("[","\[",str_replace("|","\|",str_replace(")","\)",str_replace("(","\(",str_replace("?","\?",str_replace("+","\+",str_replace(".","\.",str_replace("*","\*",str_replace("/","\/",${"oggetto_email".$num1}))))))))))))."#\|\?[^#]*#@\?/","#@?".htmlspecialchars(${"oggetto_email".$num1})."#|?".date("Y-m-d",(time() + (C_DIFF_ORE * 3600)))."#@?",$doc_inviati);
 esegui_query("update $tableclienti set doc_inviati = '".aggslashdb($doc_inviati)."' where idclienti = '$idclienti' ");
 } # fine for $num4
 } # fine if (str_replace("@","",$destinatario_email) != $destinatario_email)
 } # fine for $num3
 } # fine for $num2
 unlock_tabelle($tabelle_lock);
-} # fine if ($inviato)
-else echo "<br>&nbsp;".mex("Non si è potuto inviare l'email a",$pag)." <b style=\"font-weight: normal; color: red;\">$destinatario_email</b>.<br>";
+} # fine if ($inviato['ok'])
+else {
+if (!empty($inviato['err'])) echo "<br>".htmlspecialchars($inviato['err'])."<br>";
+echo "<br>&nbsp;".mex("Non si è potuto inviare l'email a",$pag)." <b class=\"colred\">$destinatario_email</b>.<br>";
+} # fine else if ($inviato['ok'])
 } # fine if (${"destinatario_email".$num1} and strstr(${"destinatario_email".$num1},"@"))
 } # fine for $num1
 
@@ -581,6 +583,7 @@ else $contratto = "";
 } # fine else if (empty($id_transazione))
 
 if ($messaggio_di_errore) {
+$dir_salva = "";
 $tipo_contratto = "contrhtm";
 $contratto = "<div style=\"padding: 5px;\">
 <br><span class=\"colred\">".mex("Errore",$pag)."</span>:<br>
